@@ -37,11 +37,7 @@ void penguin_move_in_dock (CairoDockModuleInstance *myApplet)
 	g_return_if_fail (pAnimation != NULL);
 	int iPreviousPositionX = myData.iCurrentPositionX, iPreviousPositionY = myData.iCurrentPositionY;
 	
-	Icon *pFirstDrawnIcon = NULL;
-	if (myDock->pFirstDrawnElement != NULL)
-		pFirstDrawnIcon = myDock->pFirstDrawnElement->data;
-	if (pFirstDrawnIcon == NULL && myDock->icons != NULL)
-		pFirstDrawnIcon = myDock->icons->data;
+	Icon *pFirstDrawnIcon = cairo_dock_get_first_icon (myDock->icons);
 	int iXMin = (pFirstDrawnIcon != NULL ? pFirstDrawnIcon->fXAtRest : 0);
 	iXMin = 0;
 	int iXMax = iXMin + myDock->fFlatDockWidth;
@@ -246,7 +242,7 @@ void penguin_move_in_icon (CairoDockModuleInstance *myApplet)
 		}
 		
 		//\________________ les reflets.
-		CD_APPLET_UPDATE_REFLECT_ON_MY_ICON;
+		///CD_APPLET_UPDATE_REFLECT_ON_MY_ICON;
 	}
 	
 	CD_APPLET_REDRAW_MY_ICON;
@@ -335,11 +331,11 @@ void penguin_advance_to_next_frame (CairoDockModuleInstance *myApplet, PenguinAn
 			{
 				cairo_dock_erase_cairo_context (myDrawContext);  // CD_APPLET_SET_SURFACE_ON_MY_ICON (NULL)
 				
-				if (myIcon->pReflectionBuffer != NULL)
+				/**if (myIcon->pReflectionBuffer != NULL)
 				{
 					cairo_surface_destroy (myIcon->pReflectionBuffer);
 					myIcon->pReflectionBuffer = NULL;
-				}
+				}*/
 				if (CAIRO_DOCK_CONTAINER_IS_OPENGL (myContainer))
 					cairo_dock_update_icon_texture (myIcon);
 			}
@@ -462,8 +458,6 @@ void penguin_set_new_animation (CairoDockModuleInstance *myApplet, int iNewAnima
 	//cd_message ("%s (%d)", __func__, iNewAnimation);
 	PenguinAnimation *pPreviousAnimation = penguin_get_current_animation ();
 	int iPreviousWidth = (pPreviousAnimation != NULL ? pPreviousAnimation->iFrameWidth : 0);
-	int iPreviousHeight = (pPreviousAnimation != NULL ? pPreviousAnimation->iFrameHeight : 0);
-	int iPreviousDirection = (pPreviousAnimation != NULL ? pPreviousAnimation->iDirection : 0);
 	
 	myData.iCurrentAnimation = iNewAnimation;
 	myData.iCurrentFrame = 0;
@@ -533,8 +527,8 @@ void penguin_start_animating (CairoDockModuleInstance *myApplet)
 	penguin_remove_notfications();
 	if (myConfig.bFree)
 	{
-		cairo_dock_register_notification_on_object (myContainer, NOTIFICATION_UPDATE_DOCK_SLOW, (CairoDockNotificationFunc) penguin_update_container, CAIRO_DOCK_RUN_AFTER, myApplet);
-		cairo_dock_register_notification_on_object (myContainer, NOTIFICATION_RENDER_DOCK, (CairoDockNotificationFunc) penguin_render_on_container, CAIRO_DOCK_RUN_AFTER, myApplet);
+		cairo_dock_register_notification_on_object (myContainer, NOTIFICATION_UPDATE_SLOW, (CairoDockNotificationFunc) penguin_update_container, CAIRO_DOCK_RUN_AFTER, myApplet);
+		cairo_dock_register_notification_on_object (myContainer, NOTIFICATION_RENDER, (CairoDockNotificationFunc) penguin_render_on_container, CAIRO_DOCK_RUN_AFTER, myApplet);
 	}
 	else
 	{
@@ -554,12 +548,11 @@ static gboolean _penguin_restart_delayed (CairoDockModuleInstance *myApplet)
 		
 		if (myConfig.bFree)  // attention : c'est un hack moyen; il faudrait pouvoir indiquer a cairo-dock de ne pas inserer notre icone...
 		{
-			cairo_dock_detach_icon_from_dock (myIcon, myDock, myIconsParam.iSeparateIcons);
-			cairo_dock_update_dock_size (myDock);
+			cairo_dock_detach_icon_from_dock (myIcon, myDock);
 		}
 		else
 		{
-			cairo_dock_insert_icon_in_dock (myIcon, myDock, CAIRO_DOCK_UPDATE_DOCK_SIZE, ! CAIRO_DOCK_ANIMATE_ICON);
+			cairo_dock_insert_icon_in_dock (myIcon, myDock, ! CAIRO_DOCK_ANIMATE_ICON);
 		}
 		cairo_dock_launch_animation (myContainer);
 	}
