@@ -30,7 +30,7 @@ CD_APPLET_ON_CLICK_BEGIN
 	if (myData.pItems == NULL)
 	{
 		cairo_dock_remove_dialog_if_any (myIcon);
-		cairo_dock_show_temporary_dialog_with_icon (D_("No items yet."), myIcon, myContainer, 2000, "same icon");
+		cairo_dock_show_temporary_dialog_with_icon (D_("The clipboard history is empty."), myIcon, myContainer, 3000, "same icon");
 	}
 	else
 	{
@@ -86,12 +86,9 @@ static void _cd_clipper_paste_all (GtkMenuItem *menu_item, gpointer data)
 	CD_APPLET_LEAVE();
 }
 CD_APPLET_ON_BUILD_MENU_BEGIN
-	// Sub-Menu
-	GtkWidget *pSubMenu = CD_APPLET_CREATE_MY_SUB_MENU ();
-		CD_APPLET_ADD_IN_MENU_WITH_STOCK ("Clear clipboard History", GTK_STOCK_CLEAR, _cd_clipper_clear_history, pSubMenu);
-		CD_APPLET_ADD_IN_MENU_WITH_STOCK ("Paste all copied items", GTK_STOCK_PASTE, _cd_clipper_paste_all, pSubMenu);
-		CD_APPLET_ADD_SEPARATOR_IN_MENU (pSubMenu);
-		CD_APPLET_ADD_ABOUT_IN_MENU (pSubMenu);
+	CD_APPLET_ADD_IN_MENU_WITH_STOCK (D_("Clear clipboard History"), GTK_STOCK_CLEAR, _cd_clipper_clear_history, CD_APPLET_MY_MENU);
+	
+	CD_APPLET_ADD_IN_MENU_WITH_STOCK (D_("Paste all copied items"), GTK_STOCK_PASTE, _cd_clipper_paste_all, CD_APPLET_MY_MENU);
 CD_APPLET_ON_BUILD_MENU_END
 
 
@@ -136,3 +133,20 @@ CD_APPLET_ON_DROP_DATA_BEGIN
 		g_string_free (pString, TRUE);
 	}
 CD_APPLET_ON_DROP_DATA_END
+
+
+void cd_clipper_on_keybinding_pull (const char *keystring, gpointer user_data)
+{
+	if (myData.pItems == NULL)
+	{
+		gchar *cIconPath = g_strdup_printf ("%s/%s", MY_APPLET_SHARE_DATA_DIR, MY_APPLET_ICON_FILE);
+		cairo_dock_show_temporary_dialog_with_icon (D_("No items yet."), myIcon, myContainer, 2000, cIconPath);
+		g_free (cIconPath);
+	}
+	else
+	{
+		GtkWidget *pMenu = cd_clipper_build_items_menu ();
+		
+		cd_clipper_popup_menu (pMenu);
+	}
+}
