@@ -48,7 +48,7 @@ dbus-send --session --dest=org.cairodock.CairoDock /org/cairodock/CairoDock org.
 #include "interface-applet-signals.h"
 #include "applet-dbus.h"
 
-#define DISTANT_DIR "3.0.0"
+#define DISTANT_DIR "3.1.0"
 #define GETTEXT_NAME_EXTRAS "cairo-dock-plugins-extra"
 #define LOCALE_DIR_NAME "locale"
 
@@ -274,7 +274,7 @@ static void _get_package_path (gchar *cModuleName)
 		cUserPackagesDir,
 		cDistantPackagesDir,
 		CAIRO_DOCK_UPDATED_PACKAGE);
-	cd_debug ("*** update of the applet '%s' -> got '%s'\n", cModuleName, cPath);
+	cd_debug ("*** update of the applet '%s' -> got '%s'", cModuleName, cPath);
 	g_free (cPath);
 	g_free (cUserPackagesDir);
 	//g_free (cDistantPackagesDir);
@@ -369,7 +369,6 @@ void cd_dbus_clean_up_processes (gboolean bAll)
 {
 	static gchar cFilePathBuffer[23+1];  // /proc/12345/cmdline + 4octets de marge.
 	static gchar cContent[512+1];
-	gboolean bIsRunning = FALSE;
 	
 	GError *erreur = NULL;
 	GDir *dir = g_dir_open ("/proc", 0, &erreur);
@@ -381,7 +380,6 @@ void cd_dbus_clean_up_processes (gboolean bAll)
 	}
 	
 	int iPid, iPPid;
-	gchar *str, *sp;
 	const gchar *cPid;
 	while ((cPid = g_dir_read_name (dir)) != NULL)
 	{
@@ -483,7 +481,7 @@ void cd_dbus_launch_service (void)
 		gchar *cUserAppletsFolder = g_strdup_printf ("%s/"CD_DBUS_APPLETS_FOLDER, g_cCairoDockDataDir);
 		if (! g_file_test (cUserAppletsFolder, G_FILE_TEST_EXISTS))
 		{
-			if (g_mkdir (cUserAppletsFolder, 7*8*8+7*8+5) != 0)  // create an empty folder; since there is no date file, the "locale" package will be seen as "to be updated" by the package manager, and will therefore download it.
+			if (g_mkdir (cUserAppletsFolder, 7*8*8+7*8+5) != 0)  // create an empty folder; since there is no date file, the "locale" package will be seen as "to be updated" by the package manager, which will therefore download it.
 				cd_warning ("couldn't create '%s'; third-party applets can't be added", cUserAppletsFolder);
 		}
 		g_free (cUserAppletsFolder);
@@ -509,6 +507,11 @@ void cd_dbus_launch_service (void)
 			NULL);  // table
 		g_free (cUserPackagesDir);
 	}
+	
+	//\____________ Start the bridge to Unity Launcher API.
+	#ifdef DBUSMENU_GTK_FOUND // need SetMenu => DBusMenu
+	cairo_dock_launch_command (CD_PLUGINS_DIR"/cairo-dock-unity-bridge");  // launch it asap, because if another Unity claims the bus before us, the messages will be emited on the bus, and we might miss them.
+	#endif
 }
 
 
