@@ -33,6 +33,7 @@ dbus-send --session --dest=org.cairodock.CairoDock /org/cairodock/CairoDock org.
 #include "cairo-dock.h"
 #include "interface-main-methods.h"
 
+
 #define nullify_argument(string) do {\
 	if (string != NULL && (*string == '\0' || strcmp (string, "any") == 0 || strcmp (string, "none") == 0))\
 		string = NULL; } while (0)
@@ -598,7 +599,7 @@ static void _set_container_props (CairoContainer *pContainer, GHashTable *h)
 	}
 	v = g_new0 (GValue, 1);
 	g_value_init (v, G_TYPE_INT);
-	g_value_set_int (v, pContainer->iWindowPositionX);
+	g_value_set_int (v, x);
 	g_hash_table_insert (h, g_strdup ("x"), v);
 	
 	v = g_new0 (GValue, 1);
@@ -849,7 +850,7 @@ gboolean cd_dbus_main_add_launcher (dbusMainObject *pDbusCallback, const gchar *
 		fOrder = CAIRO_DOCK_LAST_ORDER;
 	Icon *pNewIcon;
 	if (iLauncherType != -1)
-		pNewIcon = cairo_dock_add_new_launcher_by_type (iLauncherType, pParentDock, fOrder, CAIRO_DOCK_LAUNCHER);
+		pNewIcon = cairo_dock_add_new_launcher_by_type (iLauncherType, pParentDock, fOrder);
 	else
 		pNewIcon = cairo_dock_add_new_launcher_by_uri (cDesktopFilePath, pParentDock, fOrder);
 	if (pNewIcon != NULL)
@@ -1014,11 +1015,11 @@ gboolean cd_dbus_main_add_temporary_icon (dbusMainObject *pDbusCallback, GHashTa
 			fOrder);
 		pIcon->iTrueType = CAIRO_DOCK_ICON_TYPE_CONTAINER;
 		cairo_dock_set_subdock_content_renderer (pIcon, iSubdockViewType);
-		pIcon->pSubDock = cairo_dock_create_subdock_from_scratch (NULL, pIcon->cName, pParentDock);  // NULL <=> default sub-docks view.
+		pIcon->pSubDock = cairo_dock_create_subdock (pIcon->cName, NULL, pParentDock, NULL);  // NULL <=> default sub-docks view.
 	}
 	else if (strcmp (cType, "Separator") == 0)
 	{
-		pIcon = cairo_dock_create_separator_icon (CAIRO_DOCK_LAUNCHER, NULL);  // NULL because we'll load the icon ourselves later.
+		pIcon = cairo_dock_create_separator_icon (CAIRO_DOCK_LAUNCHER);
 	}
 	else
 	{
@@ -1028,10 +1029,9 @@ gboolean cd_dbus_main_add_temporary_icon (dbusMainObject *pDbusCallback, GHashTa
 	pIcon->cParentDockName = g_strdup (cParentDockName);
 	
 	//\_______________ load it inside the dock.
-	cairo_dock_load_icon_buffers (pIcon, CAIRO_CONTAINER (pParentDock));
+	cairo_dock_insert_icon_in_dock (pIcon, pParentDock, CAIRO_DOCK_ANIMATE_ICON);
 	
-	cairo_dock_insert_icon_in_dock (pIcon, pParentDock, CAIRO_DOCK_UPDATE_DOCK_SIZE, CAIRO_DOCK_ANIMATE_ICON);
-	cairo_dock_start_icon_animation (pIcon, pParentDock);
+	///cairo_dock_load_icon_buffers (pIcon, CAIRO_CONTAINER (pParentDock));
 	
 	if (pIcon->cClass != NULL)
 	{
@@ -1041,6 +1041,7 @@ gboolean cd_dbus_main_add_temporary_icon (dbusMainObject *pDbusCallback, GHashTa
 	return TRUE;
 }
 
+/* Not used
 static void _find_launcher_in_dock (Icon *pIcon, CairoDock *pDock, gpointer *data)
 {
 	gchar *cDesktopFile = data[0];
@@ -1051,6 +1052,7 @@ static void _find_launcher_in_dock (Icon *pIcon, CairoDock *pDock, gpointer *dat
 		*pFoundIcon = pIcon;
 	}
 }
+* 
 static Icon *cd_dbus_find_launcher (const gchar *cDesktopFile)
 {
 	Icon *pIcon = NULL;
@@ -1060,7 +1062,7 @@ static Icon *cd_dbus_find_launcher (const gchar *cDesktopFile)
 	cairo_dock_foreach_icons_in_docks ((CairoDockForeachIconFunc) _find_launcher_in_dock, data);
 	return pIcon;
 }
-
+*/
 gboolean cd_dbus_main_reload_icon (dbusMainObject *pDbusCallback, gchar *cIconQuery, GError **error)
 {
 	if (! myConfig.bEnableTweakingLauncher)
@@ -1104,6 +1106,7 @@ gboolean cd_dbus_main_reload_icon (dbusMainObject *pDbusCallback, gchar *cIconQu
 static gboolean _on_icon_deleted (GList *ic, Icon *pIcon)
 {
 	ic->data = NULL;
+	return CAIRO_DOCK_LET_PASS_NOTIFICATION;
 }
 gboolean cd_dbus_main_remove_icon (dbusMainObject *pDbusCallback, gchar *cIconQuery, GError **error)
 {
@@ -1122,7 +1125,7 @@ gboolean cd_dbus_main_remove_icon (dbusMainObject *pDbusCallback, gchar *cIconQu
 	{
 		pIcon = ic->data;
 		cairo_dock_register_notification_on_object (pIcon,
-			NOTIFICATION_STOP_ICON,
+			NOTIFICATION_DESTROY,
 			(CairoDockNotificationFunc) _on_icon_deleted,
 			CAIRO_DOCK_RUN_FIRST, ic);
 	}
@@ -1135,7 +1138,7 @@ gboolean cd_dbus_main_remove_icon (dbusMainObject *pDbusCallback, gchar *cIconQu
 			continue;
 		
 		cairo_dock_remove_notification_func_on_object (pIcon,
-			NOTIFICATION_STOP_ICON,
+			NOTIFICATION_DESTROY,
 			(CairoDockNotificationFunc) _on_icon_deleted,
 			ic);  // remove it now, since maybe this icon won't be deleted.
 		
@@ -1177,7 +1180,7 @@ gboolean cd_dbus_main_set_quick_info (dbusMainObject *pDbusCallback, const gchar
 	
 	GList *pList = cd_dbus_find_matching_icons (cIconQuery);
 	if (pList == NULL)
-		return FALSE;
+		return TRUE;
 	
 	nullify_argument (cQuickInfo);
 	
@@ -1206,7 +1209,7 @@ gboolean cd_dbus_main_set_label (dbusMainObject *pDbusCallback, const gchar *cLa
 	
 	GList *pList = cd_dbus_find_matching_icons (cIconQuery);
 	if (pList == NULL)
-		return FALSE;
+		return TRUE;
 	
 	nullify_argument (cLabel);
 	
@@ -1234,7 +1237,7 @@ gboolean cd_dbus_main_set_icon (dbusMainObject *pDbusCallback, const gchar *cIma
 	
 	GList *pList = cd_dbus_find_matching_icons (cIconQuery);
 	if (pList == NULL)
-		return FALSE;
+		return TRUE;
 	
 	Icon *pIcon;
 	CairoContainer *pContainer;
@@ -1266,7 +1269,7 @@ gboolean cd_dbus_main_set_emblem (dbusMainObject *pDbusCallback, const gchar *cI
 	
 	GList *pList = cd_dbus_find_matching_icons (cIconQuery);
 	if (pList == NULL)
-		return FALSE;
+		return TRUE;
 	
 	Icon *pIcon;
 	CairoContainer *pContainer;
@@ -1283,20 +1286,16 @@ gboolean cd_dbus_main_set_emblem (dbusMainObject *pDbusCallback, const gchar *cI
 		
 		if (cImage == NULL || *cImage == '\0' || strcmp (cImage, "none") == 0)
 		{
-			cairo_dock_remove_overlay_at_position (pIcon, iPosition);
+			cairo_dock_remove_overlay_at_position (pIcon, iPosition < CAIRO_OVERLAY_NB_POSITIONS ? iPosition : iPosition - CAIRO_OVERLAY_NB_POSITIONS, myApplet);  // for ease of use, handle both case similarily.
 		}
 		else
 		{
-			if (iPosition < 0)  // [-N, -1]
-				cairo_dock_print_overlay_on_icon (pIcon, pContainer, cImage, - iPosition - 1);
-			else  // [0, N-1]
-				cairo_dock_add_overlay_from_image (pIcon, cImage, iPosition);
+			if (iPosition >= CAIRO_OVERLAY_NB_POSITIONS)  // [N; 2N-1] => print the overlay
+				cairo_dock_print_overlay_on_icon_from_image (pIcon, pContainer, cImage, iPosition - CAIRO_OVERLAY_NB_POSITIONS);
+			else  // [0, N-1] => add it
+				cairo_dock_add_overlay_from_image (pIcon, cImage, iPosition, myApplet);  // use 'myApplet' to identify the overlays set by the Dbus plug-in (since the plug-in can't be deactivated, 'myApplet' is constant).
 		}
-		/**CairoEmblem *pEmblem = cairo_dock_make_emblem (cImage, pIcon);
-		pEmblem->iPosition = iPosition;
-		cairo_dock_draw_emblem_on_icon (pEmblem, pIcon, pContainer);
-		cairo_dock_free_emblem (pEmblem);*/
-
+		
 		cairo_dock_redraw_icon (pIcon, pContainer);
 	}
 	
@@ -1311,7 +1310,7 @@ gboolean cd_dbus_main_animate (dbusMainObject *pDbusCallback, const gchar *cAnim
 	
 	GList *pList = cd_dbus_find_matching_icons (cIconQuery);
 	if (pList == NULL)
-		return FALSE;
+		return TRUE;
 	
 	Icon *pIcon;
 	CairoContainer *pContainer;
@@ -1336,7 +1335,7 @@ gboolean cd_dbus_main_demands_attention (dbusMainObject *pDbusCallback, gboolean
 	
 	GList *pList = cd_dbus_find_matching_icons (cIconQuery);
 	if (pList == NULL)
-		return FALSE;
+		return TRUE;
 	
 	Icon *pIcon;
 	CairoContainer *pContainer;
@@ -1389,3 +1388,195 @@ gboolean cd_dbus_main_show_dialog (dbusMainObject *pDbusCallback, const gchar *m
 	g_list_free (pList);
 	return TRUE;
 }
+
+
+#ifdef DBUSMENU_GTK_FOUND
+static void _on_menu_destroyed (GtkWidget *menu, CDIconData *pData)
+{
+	//g_print ("\n+++ %s ()\n\n", __func__);
+	if (pData != NULL && pData->menu_items_list != NULL)
+	{
+		GList *mi;
+		for (mi = pData->menu_items_list; mi != NULL; mi = mi->next)
+		{
+			DbusmenuMenuitem *pDbusMenuItem = mi->data;
+			GtkMenuItem *pMenuItem = dbusmenu_gtkclient_menuitem_get (pData->client, pDbusMenuItem);
+			if (gtk_widget_get_parent (GTK_WIDGET (pMenuItem)) != NULL)  // it might not be in the menu if it has been added after the menu was built.
+				gtk_container_remove (GTK_CONTAINER (menu), GTK_WIDGET (pMenuItem));
+		}
+	}
+}
+static gboolean cd_dbus_main_emit_on_build_menu (gpointer data, Icon *pClickedIcon, CairoContainer *pClickedContainer, GtkWidget *pMenu)
+{
+	if (pClickedIcon == NULL)
+		return CAIRO_DOCK_LET_PASS_NOTIFICATION;
+	
+	CDIconData *pData = CD_APPLET_GET_MY_ICON_DATA (pClickedIcon);
+	if (pData != NULL && pData->menu_items_list != NULL)
+	{
+		GList *mi;
+		for (mi = pData->menu_items_list; mi != NULL; mi = mi->next)
+		{
+			DbusmenuMenuitem *pDbusMenuItem = mi->data;
+			GtkMenuItem *pMenuItem = dbusmenu_gtkclient_menuitem_get (pData->client, pDbusMenuItem);
+			gtk_menu_shell_append (GTK_MENU_SHELL(pMenu), GTK_WIDGET (pMenuItem));
+			gtk_widget_show (GTK_WIDGET (pMenuItem));
+		}
+		
+		// when the menu is destroyed, the menu-items are destroyed too (even if we set a reference on them, their content will be unvalidated); so we must remove them from the menu before that happens.
+		g_signal_connect (G_OBJECT (pMenu),
+			"destroy",
+			G_CALLBACK (_on_menu_destroyed),
+			pData);
+	}
+	return CAIRO_DOCK_LET_PASS_NOTIFICATION;
+}
+
+
+static void root_child_added (DbusmenuMenuitem * root, DbusmenuMenuitem * child, guint position, CDIconData *pData)
+{
+	cd_debug ("%s (%d)", __func__, position);
+	pData->menu_items_list = g_list_insert (pData->menu_items_list, child, position);  // simply add it to the list, the associated menu-item will appear in the menu the next time the user right-clicks (we don't bother to refresh the menu in real-time).
+}
+
+static void root_child_moved (DbusmenuMenuitem * root, DbusmenuMenuitem * child, guint newposition, guint oldposition, CDIconData *pData)
+{
+	cd_debug ("%s (%d -> %d)", __func__, oldposition, newposition);
+	GList *mi = g_list_nth (pData->menu_items_list, oldposition);
+	pData->menu_items_list = g_list_remove_link (pData->menu_items_list, mi);
+	pData->menu_items_list = g_list_insert (pData->menu_items_list, child, newposition);  // same remark
+}
+
+static void root_child_delete (DbusmenuMenuitem * root, DbusmenuMenuitem * child, CDIconData *pData)
+{
+	cd_debug ("%s ()", __func__);
+	pData->menu_items_list = g_list_remove (pData->menu_items_list, child);  // same remark
+}
+
+static void root_changed (DbusmenuGtkClient * client, DbusmenuMenuitem * newroot, CDIconData *pData)
+{
+	cd_debug ("%s (%p", __func__, newroot);
+	if (newroot == NULL)
+	{
+		return;
+	}
+	
+	// get the current childs
+	GList * child = NULL;
+	for (child = dbusmenu_menuitem_get_children(newroot); child != NULL; child = g_list_next(child))
+	{
+		pData->menu_items_list = g_list_append (pData->menu_items_list, child->data);
+	}
+	
+	// watch for any new/updated/removed child
+	g_signal_connect(G_OBJECT(newroot), DBUSMENU_MENUITEM_SIGNAL_CHILD_ADDED, G_CALLBACK(root_child_added), pData);
+	g_signal_connect(G_OBJECT(newroot), DBUSMENU_MENUITEM_SIGNAL_CHILD_MOVED, G_CALLBACK(root_child_moved), pData);
+	g_signal_connect(G_OBJECT(newroot), DBUSMENU_MENUITEM_SIGNAL_CHILD_REMOVED, G_CALLBACK(root_child_delete), pData);
+}
+
+gboolean cd_dbus_main_set_menu (dbusMainObject *pDbusCallback, const gchar *cBusName, const gchar *cMenuPath, gchar *cIconQuery, GError **error)
+{
+	GList *pList = cd_dbus_find_matching_icons (cIconQuery);
+	if (pList == NULL)
+		return TRUE;
+	
+	cd_debug ("%s (%s , %s)", __func__, cBusName, cMenuPath);
+	static gboolean s_bInit = FALSE;
+	if (! s_bInit)  // register for right-click events once.
+	{
+		s_bInit = TRUE;
+		cairo_dock_register_notification_on_object (&myContainersMgr,
+			NOTIFICATION_BUILD_ICON_MENU,
+			(CairoDockNotificationFunc) cd_dbus_main_emit_on_build_menu,
+			CAIRO_DOCK_RUN_FIRST,
+			NULL);
+	}
+	
+	if (cBusName && *cBusName == '\0')  // nullify empty object and path
+		cBusName = NULL;
+	if (cMenuPath && *cMenuPath == '\0')
+		cMenuPath = NULL;
+	
+	Icon *pIcon;
+	GList *ic;
+	for (ic = pList; ic != NULL; ic = ic->next)
+	{
+		pIcon = ic->data;
+		CDIconData *pData = CD_APPLET_GET_MY_ICON_DATA (pIcon);
+		if (pData == NULL)
+		{
+			pData = g_new0 (CDIconData, 1);
+			CD_APPLET_SET_MY_ICON_DATA (pIcon, pData);
+		}
+		
+		if (! cairo_dock_strings_differ (pData->cMenuPath, cMenuPath)
+		&& ! cairo_dock_strings_differ (pData->cBusName, cBusName))
+			continue;  // same menu -> nothing to do
+		
+		// remove any previous menu
+		if (pData->cBusName)
+		{
+			cd_debug ("menu %s (%s) is removed", pData->cBusName, pData->cMenuPath);
+			g_free (pData->cBusName);
+			g_free (pData->cMenuPath);
+			
+			g_list_free (pData->menu_items_list);
+			pData->menu_items_list = NULL;
+			
+			g_object_unref (pData->client);
+			pData->client = NULL;
+		}
+		
+		// remember the current menu
+		pData->cBusName = g_strdup (cBusName);
+		pData->cMenuPath = g_strdup (cMenuPath);
+		
+		// if a menu is set, build the client and wait for the root child to appear on our side of the bus.
+		if (cBusName && cMenuPath && *cMenuPath != '\0')
+		{
+			cd_debug ("new menu %s (%s)", cBusName, cMenuPath);
+			pData->client = dbusmenu_gtkclient_new(pData->cBusName, pData->cMenuPath);
+			g_signal_connect(G_OBJECT(pData->client), DBUSMENU_GTKCLIENT_SIGNAL_ROOT_CHANGED, G_CALLBACK(root_changed), pData);
+		}
+	}
+	
+	g_list_free (pList);
+	return TRUE;
+}
+#else
+gboolean cd_dbus_main_set_menu (dbusMainObject *pDbusCallback, const gchar *cBusName, const gchar *cMenuPath, gchar *cIconQuery, GError **error)
+{
+	g_set_error (error, 1, 1, "Cairo-Dock has not been compiled with DbusMenu support, so The 'SetMenu' method won't work.", NULL);
+	return FALSE;
+}
+#endif
+
+
+gboolean cd_dbus_main_set_progress (dbusMainObject *dbusMainObject, double fPercent, gchar *cIconQuery, GError **error)
+{
+	GList *pList = cd_dbus_find_matching_icons (cIconQuery);
+	if (pList == NULL)
+		return TRUE;
+	
+	Icon *pIcon;
+	GList *ic;
+	for (ic = pList; ic != NULL; ic = ic->next)
+	{
+		pIcon = ic->data;
+		
+		if (cairo_dock_get_icon_data_renderer (pIcon) == NULL)
+		{
+			CairoProgressBarAttribute attr;
+			memset (&attr, 0, sizeof (CairoProgressBarAttribute));
+			CairoDataRendererAttribute *pRenderAttr = CAIRO_DATA_RENDERER_ATTRIBUTE (&attr);
+			pRenderAttr->cModelName = "progressbar";
+			cairo_dock_add_new_data_renderer_on_icon (pIcon, pIcon->pContainer, pRenderAttr);
+		}
+		
+		if (fPercent < 0)
+			fPercent = CAIRO_DATA_RENDERER_UNDEF_VALUE;
+		cairo_dock_render_new_data_on_icon (pIcon, pIcon->pContainer, NULL, &fPercent);
+	}
+	g_list_free (pList);
+	return TRUE;
+}
