@@ -30,7 +30,7 @@ gboolean _new_xml_to_conf (CairoDockModuleInstance *myApplet, gchar *cReceivedDa
 //~ CD_APPLET_ON_CLICK_H
 //~ CD_APPLET_ON_DOUBLE_CLICK_H
 
-CD_APPLET_ON_BUILD_MENU_H
+// CD_APPLET_ON_BUILD_MENU_H
 
 //~ CD_APPLET_ON_SCROLL_H
 CD_APPLET_ON_DROP_DATA_H
