@@ -96,6 +96,7 @@ CD_APPLET_ON_MIDDLE_CLICK_END
 
 //\___________ Define here the entries you want to add to the menu when the user right-clicks on your icon or on its subdock or your desklet. The icon and the container that were clicked are available through the macros CD_APPLET_CLICKED_ICON and CD_APPLET_CLICKED_CONTAINER. CD_APPLET_CLICKED_ICON may be NULL if the user clicked in the container but out of icons. The menu where you can add your entries is available throught the macro CD_APPLET_MY_MENU; you can add sub-menu to it if you want.
 
+#define MARGIN 3
 static void _cd_folders_show_file_properties (GtkMenuItem *pMenuItem, gpointer *data)
 {
 	Icon *icon = data[0];
@@ -112,7 +113,7 @@ static void _cd_folders_show_file_properties (GtkMenuItem *pMenuItem, gpointer *
 			GTK_DIALOG_DESTROY_WITH_PARENT,
 			GTK_MESSAGE_INFO,
 			GTK_BUTTONS_OK,
-			"Properties :");
+			D_("Properties:"));
 
 		GString *sInfo = g_string_new ("");
 		g_string_printf (sInfo, "<b>%s</b>", icon->cName);
@@ -122,21 +123,21 @@ static void _cd_folders_show_file_properties (GtkMenuItem *pMenuItem, gpointer *
 		gtk_label_set_markup (GTK_LABEL (pLabel), sInfo->str);
 
 		GtkWidget *pFrame = gtk_frame_new (NULL);
-		gtk_container_set_border_width (GTK_CONTAINER (pFrame), 3);
+		gtk_container_set_border_width (GTK_CONTAINER (pFrame), MARGIN);
 		gtk_frame_set_label_widget (GTK_FRAME (pFrame), pLabel);
+		gtk_container_add (GTK_CONTAINER (gtk_dialog_get_content_area (GTK_DIALOG(pDialog))), pFrame);
 		gtk_frame_set_shadow_type (GTK_FRAME (pFrame), GTK_SHADOW_OUT);
-		gtk_container_add (GTK_CONTAINER (GTK_DIALOG (pDialog)->vbox), pFrame);
 
-		GtkWidget *pVBox = gtk_vbox_new (FALSE, 3);
+		GtkWidget *pVBox = _gtk_vbox_new (MARGIN);
 		gtk_container_add (GTK_CONTAINER (pFrame), pVBox);
 
 		pLabel = gtk_label_new (NULL);
 		gtk_label_set_use_markup (GTK_LABEL (pLabel), TRUE);
-		g_string_printf (sInfo, "<u>Size</u> : %"G_GUINT64_FORMAT" bytes", iSize);
+		g_string_printf (sInfo, "<u>%s</u>: %"G_GUINT64_FORMAT" %s", D_("Size"), iSize, D_("bytes"));
 		if (iSize > 1024*1024)
-			g_string_append_printf (sInfo, " (%.1f MB)", 1. * iSize / 1024 / 1024);
+			g_string_append_printf (sInfo, " (%.1f %s)", 1. * iSize / 1024 / 1024, D_("MB"));
 		else if (iSize > 1024)
-			g_string_append_printf (sInfo, " (%.1f KB)", 1. * iSize / 1024);
+			g_string_append_printf (sInfo, " (%.1f %s)", 1. * iSize / 1024, D_("KB"));
 		gtk_label_set_markup (GTK_LABEL (pLabel), sInfo->str);
 		gtk_container_add (GTK_CONTAINER (pVBox), pLabel);
 
@@ -146,7 +147,7 @@ static void _cd_folders_show_file_properties (GtkMenuItem *pMenuItem, gpointer *
 		localtime_r (&iLastModificationTime, &epoch_tm);  // et non pas gmtime_r.
 		gchar *cTimeChain = g_new0 (gchar, 100);
 		strftime (cTimeChain, 100, "%F, %T", &epoch_tm);
-		g_string_printf (sInfo, "<u>Last Modification</u> : %s", cTimeChain);
+		g_string_printf (sInfo, "<u>%s</u>: %s", D_("Last Modification"), cTimeChain);
 		g_free (cTimeChain);
 		gtk_label_set_markup (GTK_LABEL (pLabel), sInfo->str);
 		gtk_container_add (GTK_CONTAINER (pVBox), pLabel);
@@ -155,17 +156,21 @@ static void _cd_folders_show_file_properties (GtkMenuItem *pMenuItem, gpointer *
 		{
 			pLabel = gtk_label_new (NULL);
 			gtk_label_set_use_markup (GTK_LABEL (pLabel), TRUE);
-			g_string_printf (sInfo, "<u>Mime Type</u> : %s", cMimeType);
+			g_string_printf (sInfo, "<u>%s</u>: %s", D_("Mime Type"), cMimeType);
 			gtk_label_set_markup (GTK_LABEL (pLabel), sInfo->str);
 			gtk_container_add (GTK_CONTAINER (pVBox), pLabel);
 		}
 
+		#if (GTK_MAJOR_VERSION < 3)
 		GtkWidget *pSeparator = gtk_hseparator_new ();
+		#else
+		GtkWidget *pSeparator = gtk_separator_new (GTK_ORIENTATION_HORIZONTAL);
+		#endif
 		gtk_container_add (GTK_CONTAINER (pVBox), pSeparator);
 
 		pLabel = gtk_label_new (NULL);
 		gtk_label_set_use_markup (GTK_LABEL (pLabel), TRUE);
-		g_string_printf (sInfo, "<u>User ID</u> : %d / <u>Group ID</u> : %d", iUID, iGID);
+		g_string_printf (sInfo, "<u>%s</u>: %d \t <u>%s</u>: %d", D_("User ID"), iUID, D_("Group ID"), iGID);
 		gtk_label_set_markup (GTK_LABEL (pLabel), sInfo->str);
 		gtk_container_add (GTK_CONTAINER (pVBox), pLabel);
 
@@ -174,19 +179,20 @@ static void _cd_folders_show_file_properties (GtkMenuItem *pMenuItem, gpointer *
 		int iOwnerPermissions = iPermissionsMask >> 6;  // 8*8.
 		int iGroupPermissions = (iPermissionsMask - (iOwnerPermissions << 6)) >> 3;
 		int iOthersPermissions = (iPermissionsMask % 8);
-		g_string_printf (sInfo, "<u>Permissions</u> : read:%s / write:%s / execute:%s",
-			iOwnerPermissions?"yes":"no",
-			iGroupPermissions?"yes":"no",
-			iOthersPermissions?"yes":"no");
+		g_string_printf (sInfo, "<u>%s</u>: %s: %s / %s: %s / %s: %s",
+			D_("Permissions"), D_("Read"),
+			iOwnerPermissions ? D_("Yes") : D_("No"), D_("Write"),
+			iGroupPermissions ? D_("Yes") : D_("No"), D_("Execute"),
+			iOthersPermissions ? D_("Yes") : D_("No"));
 		gtk_label_set_markup (GTK_LABEL (pLabel), sInfo->str);
 		gtk_container_add (GTK_CONTAINER (pVBox), pLabel);
 
 		gtk_window_set_type_hint (GTK_WINDOW (pDialog), GDK_WINDOW_TYPE_HINT_DOCK);  // sinon le dialogue sera toujours derriere le sous-dock, meme avec un 'set_keep_above'. en contrepartie, le dialgue n'aura pas de bordure (du moins avec Compiz).
 		gtk_window_set_keep_above (GTK_WINDOW (pDialog), TRUE);
 		
-		gtk_widget_show_all (GTK_DIALOG (pDialog)->vbox);
+		gtk_widget_show_all (gtk_dialog_get_content_area (GTK_DIALOG(pDialog)));
 		gtk_window_set_position (GTK_WINDOW (pDialog), GTK_WIN_POS_CENTER_ALWAYS);
-		int answer = gtk_dialog_run (GTK_DIALOG (pDialog));
+		gtk_dialog_run (GTK_DIALOG (pDialog));
 		gtk_widget_destroy (pDialog);
 
 		g_string_free (sInfo, TRUE);
@@ -246,7 +252,7 @@ static void _cd_folders_move_file (GtkMenuItem *pMenuItem, gpointer *data)
 	cd_message ("%s (%s)", __func__, icon->cName);
 	
 	GtkWidget* pFileChooserDialog = gtk_file_chooser_dialog_new (
-		"Pick up a folder",
+		_("Pick up a directory"),
 		GTK_WINDOW (pContainer->pWidget),
 		GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER,
 		GTK_STOCK_OK,
@@ -354,16 +360,12 @@ CD_APPLET_ON_BUILD_MENU_BEGIN
 	
 	if (CD_APPLET_CLICKED_ICON == myIcon || CD_APPLET_CLICKED_ICON == NULL)  // click on main icon or on the container.
 	{
-		GtkWidget *pSubMenu = CD_APPLET_CREATE_MY_SUB_MENU ();
 		if (myConfig.bShowFiles)
 		{
 			gchar *cLabel = g_strdup_printf ("%s (%s)", D_("Open the folder"), D_("middle-click"));
 			CD_APPLET_ADD_IN_MENU_WITH_STOCK_AND_DATA (cLabel, GTK_STOCK_OPEN, _cd_folders_open_folder, CD_APPLET_MY_MENU, myApplet);
 			g_free (cLabel);
-			if (pSubMenu == CD_APPLET_MY_MENU)
-				CD_APPLET_ADD_SEPARATOR_IN_MENU (CD_APPLET_MY_MENU);
 		}
-		CD_APPLET_ADD_ABOUT_IN_MENU (pSubMenu);
 	}
 	else  // clic on a file.
 	{
@@ -383,6 +385,7 @@ CD_APPLET_ON_BUILD_MENU_BEGIN
 			gchar **pAppInfo;
 			gchar *cIconPath;
 			gpointer *app;
+			gint iDesiredIconSize = cairo_dock_search_icon_size (GTK_ICON_SIZE_LARGE_TOOLBAR); // 24px
 			for (a = pApps; a != NULL; a = a->next)
 			{
 				pAppInfo = a->data;
@@ -396,7 +399,7 @@ CD_APPLET_ON_BUILD_MENU_BEGIN
 				myData.pAppList = g_list_prepend (myData.pAppList, app);
 				
 				if (pAppInfo[2] != NULL)
-					cIconPath = cairo_dock_search_icon_s_path (pAppInfo[2]);
+					cIconPath = cairo_dock_search_icon_s_path (pAppInfo[2], iDesiredIconSize);
 				else
 					cIconPath = NULL;
 				CD_APPLET_ADD_IN_MENU_WITH_STOCK_AND_DATA (pAppInfo[0], cIconPath, _cd_folders_launch_with, pSubMenu, app);
@@ -431,6 +434,7 @@ CD_APPLET_ON_BUILD_MENU_END
 typedef struct {
 	gchar *cReceivedData;
 	double fOrder;
+	gchar *cDockName;
 } CDDropData;
 
 static void _on_answer_import (int iClickedButton, GtkWidget *pInteractiveWidget, CDDropData *data, CairoDialog *pDialog)
@@ -449,6 +453,7 @@ static void _on_answer_import (int iClickedButton, GtkWidget *pInteractiveWidget
 		G_TYPE_STRING, "Configuration", "dir path", cReceivedData,
 		G_TYPE_BOOLEAN, "Configuration", "show files", bImportFiles,
 		G_TYPE_DOUBLE, "Icon", "order", fOrder,
+		G_TYPE_STRING, "Icon", "dock name", data->cDockName,
 		G_TYPE_INVALID);
 	
 	// instanciate the module from this conf file.
@@ -474,6 +479,7 @@ static void _on_answer_import (int iClickedButton, GtkWidget *pInteractiveWidget
 static void _free_dialog_data (CDDropData *data)
 {
 	g_free (data->cReceivedData);
+	g_free (data->cDockName);
 	g_free (data);
 }
 gboolean cd_folders_on_drop_data (gpointer data, const gchar *cReceivedData, Icon *icon, double fOrder, CairoContainer *pContainer)
@@ -518,6 +524,8 @@ gboolean cd_folders_on_drop_data (gpointer data, const gchar *cReceivedData, Ico
 		CDDropData *data = g_new0 (CDDropData, 1);
 		data->cReceivedData = g_strdup (cReceivedData);
 		data->fOrder = fOrder;
+		if (CAIRO_DOCK_IS_DOCK (pContainer))
+			data->cDockName = g_strdup (cairo_dock_search_dock_name (CAIRO_DOCK (pContainer)));
 		cairo_dock_show_dialog_full (D_("Do you want to import the content of the folder too?"),
 			pIcon, pContainer,
 			0,
