@@ -25,9 +25,6 @@
 #include "applet-util.h"
 #include "applet-menu.h"
 
-static GSList *image_menu_items = NULL;
-static GHashTable *loaded_icons = NULL;
-
 
 GtkWidget * add_menu_separator (GtkWidget *menu)
 {
@@ -74,15 +71,21 @@ GtkWidget * create_fake_menu (GMenuTreeDirectory *directory)
 
 void image_menu_destroy (GtkWidget *image, gpointer data)
 {
-	image_menu_items = g_slist_remove (image_menu_items, image);
+	myData.image_menu_items = g_slist_remove (myData.image_menu_items, image);
+	if (myConfig.bLoadIconsAtStartup)
+	{
+		int sid = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (image), "cd-preload-icon"));
+		if (sid != 0)
+			g_source_remove (sid);
+	}
 }
 
 
-static void reload_image_menu_items (void)
+void reload_image_menu_items (void)
 {
 	GSList *l;
 
-	for (l = image_menu_items; l; l = l->next) {
+	for (l = myData.image_menu_items; l; l = l->next) {
 		GtkWidget *image = l->data;
 		gboolean   is_mapped;
       
@@ -105,8 +108,8 @@ remove_pixmap_from_loaded (gpointer data, GObject *where_the_object_was)
 {
 	char *key = data;
 
-	if (loaded_icons != NULL)
-		g_hash_table_remove (loaded_icons, key);
+	if (myData.loaded_icons != NULL)
+		g_hash_table_remove (myData.loaded_icons, key);
 
 	g_free (key);
 }
@@ -140,8 +143,8 @@ GdkPixbuf * panel_make_menu_icon (GtkIconTheme *icon_theme,
 
 	key = g_strdup_printf ("%d:%s", size, file);
 
-	if (loaded_icons != NULL &&
-	    (pb = g_hash_table_lookup (loaded_icons, key)) != NULL) {
+	if (myData.loaded_icons != NULL &&
+	    (pb = g_hash_table_lookup (myData.loaded_icons, key)) != NULL) {
 		if (pb != NULL)
 			g_object_ref (G_OBJECT (pb));
 	}
@@ -205,12 +208,12 @@ GdkPixbuf * panel_make_menu_icon (GtkIconTheme *icon_theme,
 	}
 
 	if (loaded) {
-		if (loaded_icons == NULL)
-			loaded_icons = g_hash_table_new_full
+		if (myData.loaded_icons == NULL)
+			myData.loaded_icons = g_hash_table_new_full
 				(g_str_hash, g_str_equal,
 				 (GDestroyNotify) g_free,
 				 (GDestroyNotify) g_object_unref);
-		g_hash_table_replace (loaded_icons,
+		g_hash_table_replace (myData.loaded_icons,
 				      g_strdup (key),
 				      g_object_ref (G_OBJECT (pb)));
 		g_object_weak_ref (G_OBJECT (pb),
@@ -228,6 +231,23 @@ GdkPixbuf * panel_make_menu_icon (GtkIconTheme *icon_theme,
 	return pb;
 }
 
+
+static gboolean _image_menu_shown_in_idle (gpointer *data)
+{
+	GtkWidget *image = data[0];
+	IconToLoad *icon = data[1];
+	/* if the applet is disabled, it's not interesting to continue...
+	 * (and all g_timeout are not stopped if the applet is disabled)
+	 */
+	if (myApplet && &myData)
+		image_menu_shown (image, icon);
+	
+	g_free (data);
+	g_object_set_data (G_OBJECT (image), "cd-preload-icon", NULL);
+	
+	return FALSE;
+}
+
 void panel_load_menu_image_deferred (GtkWidget   *image_menu_item,
 				GtkIconSize  icon_size,
 				///const char  *stock_id,
@@ -261,27 +281,34 @@ void panel_load_menu_image_deferred (GtkWidget   *image_menu_item,
 	icon->fallback_image = g_strdup (fallback_image_filename);
 	icon->icon_size      = icon_size;
 
-	gtk_widget_show (image);
-
 	/**g_object_set_data_full (G_OBJECT (image_menu_item),
 				"Panel:Image",
 				g_object_ref (image),
 				(GDestroyNotify) g_object_unref);*/
- 
-	if (myConfig.bHasIcons)
-	{
-		_gtk_image_menu_item_set_image (
-			GTK_IMAGE_MENU_ITEM (image_menu_item), image);
-	}
 
 	g_signal_connect_data (image, "map",
 			       G_CALLBACK (image_menu_shown), icon,
 			       (GClosureNotify) icon_to_load_free, 0);
 
+	// pre-load all icons
+	if (myConfig.bLoadIconsAtStartup)
+	{
+		gpointer *data = g_new0 (gpointer, 2);
+		data[0] = image;
+		data[1] = icon;
+		gint sid = g_timeout_add_seconds (5, (GSourceFunc) _image_menu_shown_in_idle, data);
+		g_object_set_data (G_OBJECT (image), "cd-preload-icon", GINT_TO_POINTER (sid));
+	}
+ 
+	_gtk_image_menu_item_set_image (
+		GTK_IMAGE_MENU_ITEM (image_menu_item), image);
+
+	gtk_widget_show (image);
+
 	g_signal_connect (image, "destroy",
 			  G_CALLBACK (image_menu_destroy), NULL);
 
-	image_menu_items = g_slist_prepend (image_menu_items, image);
+	myData.image_menu_items = g_slist_prepend (myData.image_menu_items, image);
 }
 GtkWidget * create_submenu_entry (GtkWidget          *menu,
 		      GMenuTreeDirectory *directory)
@@ -510,11 +537,8 @@ void setup_menuitem (GtkWidget   *menuitem,
 					g_object_ref (image),
 					(GDestroyNotify) g_object_unref);
 		gtk_widget_show (image);
-		if (myConfig.bHasIcons)
-		{
-			_gtk_image_menu_item_set_image (
-				GTK_IMAGE_MENU_ITEM (menuitem), image);
-		}
+		_gtk_image_menu_item_set_image (
+			GTK_IMAGE_MENU_ITEM (menuitem), image);
 	} else if (icon_size != GTK_ICON_SIZE_INVALID)
 		g_signal_connect (menuitem, "size_request",
 				  G_CALLBACK (image_menuitem_size_request),
@@ -581,7 +605,7 @@ GtkWidget * populate_menu_from_directory (GtkWidget          *menu,
 
 
 
-void icon_theme_changed (GtkIconTheme *icon_theme,
+/**void icon_theme_changed (GtkIconTheme *icon_theme,
 		    gpointer      data)
 {
 	reload_image_menu_items ();
@@ -602,13 +626,14 @@ static inline GtkWidget * panel_create_menu (void)
 	retval = gtk_menu_new ();
 	
 	return retval;
-}
+}*/
 GtkWidget * create_empty_menu (void)
 {
 	GtkWidget *retval;
 
-	retval = panel_create_menu ();
-
+	///retval = panel_create_menu ();
+	retval = gtk_menu_new ();
+	
 	return retval;
 }
 
@@ -694,7 +719,7 @@ GtkWidget * create_main_menu (CairoDockModuleInstance *myApplet)
 		GDir *dir = g_dir_open (XDG_MENUS_PATH, 0, NULL);
 		if (dir)
 		{
-			while (cFileName = g_dir_read_name (dir))
+			while ((cFileName = g_dir_read_name (dir)))
 			{
 				if (g_str_has_suffix (cFileName, "-applications.menu"))
 				{
@@ -718,7 +743,5 @@ GtkWidget * create_main_menu (CairoDockModuleInstance *myApplet)
 		"panel-menu-append-callback-data",
 		myApplet);
 	
-	myData.bIconsLoaded = myConfig.bHasIcons;
-	
 	return main_menu;
 }
