@@ -29,7 +29,7 @@ recent_documents_activate_cb (GtkRecentChooser *chooser,
 {
 	GtkRecentInfo *recent_info = gtk_recent_chooser_get_current_item (chooser);
 	const char *uri = gtk_recent_info_get_uri (recent_info);
-	cd_debug ("%s (%s) : %s\n", __func__, uri, gtk_recent_info_get_display_name(recent_info));
+	cd_debug ("%s (%s) : %s", __func__, uri, gtk_recent_info_get_display_name(recent_info));
 	cairo_dock_fm_launch_uri (uri);
 	gtk_recent_info_unref (recent_info);
 }
@@ -70,7 +70,14 @@ void cd_menu_append_recent_to_menu (GtkWidget *top_menu, CairoDockModuleInstance
 	
 	//\_____________ On construit le menu des fichiers recents.
 	GtkWidget *recent_menu = gtk_recent_chooser_menu_new_for_manager (myData.pRecentManager);
-	gtk_recent_chooser_set_show_icons (GTK_RECENT_CHOOSER (recent_menu), myConfig.bHasIcons);
+	
+	gtk_recent_chooser_set_show_icons (GTK_RECENT_CHOOSER (recent_menu), TRUE);
+	gtk_recent_chooser_set_local_only (GTK_RECENT_CHOOSER (recent_menu), FALSE);
+	gtk_recent_chooser_set_show_tips (GTK_RECENT_CHOOSER (recent_menu), TRUE);
+	gtk_recent_chooser_set_sort_type (GTK_RECENT_CHOOSER (recent_menu), GTK_RECENT_SORT_MRU);  // most recently used
+	gtk_recent_chooser_set_limit (GTK_RECENT_CHOOSER (recent_menu), myConfig.iNbRecentItems);
+	myData.iNbRecentItems = myConfig.iNbRecentItems;
+	
 	if (myData.pRecentFilter != NULL)
 	{
 		gtk_recent_chooser_add_filter (GTK_RECENT_CHOOSER (recent_menu), myData.pRecentFilter);
@@ -86,14 +93,6 @@ void cd_menu_append_recent_to_menu (GtkWidget *top_menu, CairoDockModuleInstance
 		G_CALLBACK (panel_recent_manager_changed_cb),
 		 myData.pRecentMenuItem, 0);
 	
-	//\_____________ On le personnalise un peu.
-	gtk_recent_chooser_set_local_only (GTK_RECENT_CHOOSER (recent_menu),
-		 FALSE);
-	gtk_recent_chooser_set_show_tips (GTK_RECENT_CHOOSER (recent_menu),
-		TRUE);
-	gtk_recent_chooser_set_sort_type (GTK_RECENT_CHOOSER (recent_menu),
-		GTK_RECENT_SORT_MRU);  // most recently used
-	
 	//\_____________ On l'insere dans notre entree.
 	gtk_menu_item_set_submenu (GTK_MENU_ITEM (myData.pRecentMenuItem), recent_menu);
 	
@@ -133,8 +132,6 @@ void cd_menu_init_recent (CairoDockModuleInstance *myApplet)
 			(GtkRecentFilterFunc) _recent_uri_filter,
 			myApplet,
 			NULL);
-		if (myConfig.iRecentAge != 0)
-			gtk_recent_filter_add_age (myData.pRecentFilter, myConfig.iRecentAge);
 	}
 }
 
