@@ -56,27 +56,29 @@ typedef enum _CDGMenuShowQuit {
 
 //\___________ structure containing the applet's configuration parameters.
 struct _AppletConfig {
-	gboolean bHasIcons;
-	gboolean bShowRecent;
 	gchar *cMenuShortkey;
 	gchar *cQuickLaunchShortkey;
 	gchar *cConfigureMenuCommand;
-	gchar *cRecentRootDirFilter;
-	gint iRecentAge;
+	gboolean bShowRecent;
+	gboolean bLoadIconsAtStartup;
+	gint iNbRecentItems;
 	CDGMenuShowQuit iShowQuit;
+	gchar *cRecentRootDirFilter;
 	} ;
 
 //\___________ structure containing the applet's data, like surfaces, dialogs, results of calculus, etc.
 struct _AppletData {
 	// menu
 	GtkWidget *pMenu;
-	gboolean bIconsLoaded;
 	CDGMenuShowQuit iShowQuit;
 	gint iPanelDefaultMenuIconSize;
+	GSList *image_menu_items;
+	GHashTable *loaded_icons;
 	// recent files sub-menu
 	GtkRecentManager *pRecentManager;
 	GtkWidget *pRecentMenuItem;
 	GtkRecentFilter *pRecentFilter;
+	gint iNbRecentItems;
 	// quick-launcher
 	CairoDialog *pQuickLaunchDialog;
 	GHashTable *dir_hash;
