@@ -33,9 +33,9 @@ CD_APPLET_ON_CLICK_END
 
 
 //\___________ Same as ON_CLICK, but with middle-click.
-CD_APPLET_ON_MIDDLE_CLICK_BEGIN
+/*CD_APPLET_ON_MIDDLE_CLICK_BEGIN
 	
-CD_APPLET_ON_MIDDLE_CLICK_END
+CD_APPLET_ON_MIDDLE_CLICK_END*/
 
 
 //\___________ Define here the entries you want to add to the menu when the user right-clicks on your icon or on its subdock or your desklet. The icon and the container that were clicked are available through the macros CD_APPLET_CLICKED_ICON and CD_APPLET_CLICKED_CONTAINER. CD_APPLET_CLICKED_ICON may be NULL if the user clicked in the container but out of icons. The menu where you can add your entries is available throught the macro CD_APPLET_MY_MENU; you can add sub-menu to it if you want.
@@ -135,6 +135,7 @@ static void _on_find_related_events (ZeitgeistResultSet *pEvents, Icon *pIcon)
 				 * (we can set the widget as insensitive but why?
 				 *  If we add it, it's just an useless entry)
 				 */
+				g_hash_table_insert (pHashTable, (gchar*)cEventURI, NULL);  // since we've checked it, insert it, even if we don't display it.
 				g_free (cPath);
 				continue;
 			}
@@ -171,7 +172,7 @@ CD_APPLET_ON_BUILD_MENU_PROTO
 {
 	cd_debug ("%s (%s...)", __func__, CD_APPLET_CLICKED_ICON && CD_APPLET_CLICKED_ICON->pMimeTypes ?CD_APPLET_CLICKED_ICON->pMimeTypes[0] : "");
 	CD_APPLET_ENTER;
-	GtkWidget *pMenuItem, *image;
+	GtkWidget *pMenuItem;
 	
 	if (CD_APPLET_CLICKED_ICON != NULL)
 	{
