@@ -43,7 +43,7 @@ static inline gboolean _cd_do_icon_match (Icon *pIcon, const gchar *cCommandPref
 			if (str && *(str-1) != ' ')  // on verifie qu'il n'est pas un tiret d'option
 			{
 				str ++;
-				bMatch = (g_strncasecmp (str, cCommandPrefix, length) == 0);
+				bMatch = (g_ascii_strncasecmp (str, cCommandPrefix, length) == 0);
 			}
 			if (!bMatch && pIcon->cName)
 				bMatch = (g_ascii_strncasecmp (cCommandPrefix, pIcon->cName, length) == 0);
@@ -77,13 +77,13 @@ void cd_do_search_matching_icons (void)
 {
 	if (myData.sCurrentText->len == 0)
 		return;
-	cd_debug ("%s (%s)\n", __func__, myData.sCurrentText->str);
+	cd_debug ("%s (%s)", __func__, myData.sCurrentText->str);
 	gchar *str = strchr (myData.sCurrentText->str, ' ');  // on ne compte pas les arguments d'une eventuelle commande deja tapee.
 	guint length = myData.sCurrentText->len;
 	if (str != NULL)
 	{
 		g_string_set_size (myData.sCurrentText, str - myData.sCurrentText->str + 1);
-		cd_debug (" on ne cherchera que '%s' (len=%d)\n", myData.sCurrentText->str, myData.sCurrentText->len);
+		cd_debug (" on ne cherchera que '%s' (len=%d)", myData.sCurrentText->str, myData.sCurrentText->len);
 	}
 		
 	if (myData.pMatchingIcons == NULL)
@@ -157,7 +157,6 @@ void cd_do_select_previous_next_matching_icon (gboolean bNext)
 		// on arme l'animation de decalage.
 		myData.iMatchingGlideCount = 10;  // on rembobine l'animation.
 		myData.iPreviousMatchingOffset = myData.iCurrentMatchingOffset;  // on part du point courant.
-		CairoDock *pParentDock = cairo_dock_search_dock_from_name (pIcon->cParentDockName);
 		int iWidth, iHeight;
 		cairo_dock_get_icon_extent (pIcon, &iWidth, &iHeight);
 		if (iHeight != 0)
