@@ -69,13 +69,17 @@ void cd_do_free_listing_backup (CDListingBackup *pBackup)
 	g_free (pBackup);
 }
 
-static gboolean on_expose_listing (GtkWidget *pWidget, GdkEventExpose *pExpose, CDListing *pListing)
+static gboolean on_expose_listing (GtkWidget *pWidget,
+	#if (GTK_MAJOR_VERSION < 3)
+	GdkEventExpose *pExpose,
+	#else
+	cairo_t *ctx,
+	#endif
+	CDListing *pListing)
 {
-	if (g_bUseOpenGL && pListing->container.glContext)
+	/**if (g_bUseOpenGL && pListing->container.glContext)
 	{
-		GdkGLContext *pGlContext = gtk_widget_get_gl_context (pWidget);
-		GdkGLDrawable *pGlDrawable = gtk_widget_get_gl_drawable (pWidget);
-		if (!gdk_gl_drawable_gl_begin (pGlDrawable, pGlContext))
+		if (! gldi_glx_begin_draw_container (CAIRO_CONTAINER (pListing)))
 			return FALSE;
 		
 		if (pExpose->area.x + pExpose->area.y != 0)
@@ -88,18 +92,15 @@ static gboolean on_expose_listing (GtkWidget *pWidget, GdkEventExpose *pExpose,
 				(int) pExpose->area.height);
 		}
 		
-		cairo_dock_notify_on_object (CAIRO_CONTAINER (pListing), NOTIFICATION_RENDER_DEFAULT_CONTAINER, pListing, NULL);
+		cairo_dock_notify_on_object (CAIRO_CONTAINER (pListing), NOTIFICATION_RENDER, pListing, NULL);
 		
 		glDisable (GL_SCISSOR_TEST);
 		
-		if (gdk_gl_drawable_is_double_buffered (pGlDrawable))
-			gdk_gl_drawable_swap_buffers (pGlDrawable);
-		else
-			glFlush ();
-		gdk_gl_drawable_gl_end (pGlDrawable);
+		gldi_glx_end_draw_container (CAIRO_CONTAINER (pListing));
 	}
-	else
+	else*/
 	{
+		#if (GTK_MAJOR_VERSION < 3)
 		cairo_t *pCairoContext;
 		if (pExpose->area.x > 0 || pExpose->area.y > 0)
 		{
@@ -111,9 +112,12 @@ static gboolean on_expose_listing (GtkWidget *pWidget, GdkEventExpose *pExpose,
 			pCairoContext = cairo_dock_create_drawing_context (CAIRO_CONTAINER (pListing));
 		}
 		
-		cairo_dock_notify_on_object (CAIRO_CONTAINER (pListing), NOTIFICATION_RENDER_DEFAULT_CONTAINER, pListing, pCairoContext);
+		cairo_dock_notify_on_object (CAIRO_CONTAINER (pListing), NOTIFICATION_RENDER, pListing, pCairoContext);
 		
 		cairo_destroy (pCairoContext);
+		#else
+		cairo_dock_notify_on_object (CAIRO_CONTAINER (pListing), NOTIFICATION_RENDER, pListing, ctx);
+		#endif
 	}
 	return FALSE;
 }
@@ -142,18 +146,14 @@ static gboolean on_configure_listing (GtkWidget* pWidget, GdkEventConfigure* pEv
 		
 		if (g_bUseOpenGL && pListing->container.glContext)
 		{
-			GdkGLContext* pGlContext = gtk_widget_get_gl_context (pWidget);
-			GdkGLDrawable* pGlDrawable = gtk_widget_get_gl_drawable (pWidget);
 			GLsizei w = pEvent->width;
 			GLsizei h = pEvent->height;
-			if (!gdk_gl_drawable_gl_begin (pGlDrawable, pGlContext))
+			if (! gldi_glx_begin_draw_container (CAIRO_CONTAINER (pListing)))
 				return FALSE;
 			
 			glViewport(0, 0, w, h);
 			
 			cairo_dock_set_ortho_view (CAIRO_CONTAINER (pListing));
-			
-			gdk_gl_drawable_gl_end (pGlDrawable);
 		}
 	}
 	return FALSE;
@@ -193,7 +193,7 @@ static inline void _place_listing (CDListing *pListing)
 		iX = g_pMainDock->container.iWindowPositionY + (g_pMainDock->container.bDirectionUp ? - pListing->container.iWidth : g_pMainDock->container.iHeight);
 		iY = g_pMainDock->container.iWindowPositionX + g_pMainDock->container.iWidth/2 - pListing->container.iHeight/2;
 	}
-	cd_debug ("(%d;%d) %dx%d\n", iX, iY, pListing->container.iWidth, pListing->container.iHeight);
+	cd_debug ("(%d;%d) %dx%d", iX, iY, pListing->container.iWidth, pListing->container.iHeight);
 	gtk_window_move (GTK_WINDOW (pListing->container.pWidget), iX, iY);
 }
 CDListing *cd_do_create_listing (void)
@@ -209,7 +209,11 @@ CDListing *cd_do_create_listing (void)
 	gtk_window_set_title (GTK_WINDOW (pWindow), "cairo-dock-listing");
 	//gtk_widget_add_events (pWindow, GDK_BUTTON_PRESS_MASK | GDK_POINTER_MOTION_MASK | GDK_POINTER_MOTION_HINT_MASK);
 	g_signal_connect (G_OBJECT (pWindow),
+		#if (GTK_MAJOR_VERSION < 3)
 		"expose-event",
+		#else
+		"draw",
+		#endif
 		G_CALLBACK (on_expose_listing),
 		pListing);
 	g_signal_connect (G_OBJECT (pWindow),
@@ -312,6 +316,7 @@ gboolean cd_do_update_listing_notification (gpointer pUserData, CDListing *pList
 		
 	}
 	cairo_dock_redraw_container (CAIRO_CONTAINER (pListing));
+	return CAIRO_DOCK_LET_PASS_NOTIFICATION;
 }
 
 gboolean cd_do_render_listing_notification (gpointer pUserData, CDListing *pListing, cairo_t *pCairoContext)
@@ -554,6 +559,7 @@ gboolean cd_do_render_listing_notification (gpointer pUserData, CDListing *pList
 	
 	pango_font_description_free (pDesc);
 	g_object_unref (pLayout);
+	return CAIRO_DOCK_LET_PASS_NOTIFICATION;
 }
 
 
@@ -564,12 +570,12 @@ void cd_do_show_listing (void)
 		myData.pListing = cd_do_create_listing ();
 		
 		cairo_dock_register_notification_on_object (CAIRO_CONTAINER (myData.pListing),
-			NOTIFICATION_UPDATE_DEFAULT_CONTAINER,
+			NOTIFICATION_UPDATE,
 			(CairoDockNotificationFunc) cd_do_update_listing_notification,
 			CAIRO_DOCK_RUN_AFTER,
 			NULL);
 		cairo_dock_register_notification_on_object (CAIRO_CONTAINER (myData.pListing),
-			NOTIFICATION_RENDER_DEFAULT_CONTAINER,
+			NOTIFICATION_RENDER,
 			(CairoDockNotificationFunc) cd_do_render_listing_notification,
 			CAIRO_DOCK_RUN_AFTER,
 			NULL);
@@ -581,7 +587,7 @@ void cd_do_show_listing (void)
 		}
 		if (myData.pActiveButtonSurface == NULL)
 		{
-			cd_debug ("load button : %dx%d\n", myDialogsParam.dialogTextDescription.iSize + 2, myData.pListing->container.iWidth);
+			cd_debug ("load button : %dx%d", myDialogsParam.dialogTextDescription.iSize + 2, myData.pListing->container.iWidth);
 			cairo_t* pSourceContext = cairo_dock_create_context_from_container (CAIRO_CONTAINER (g_pMainDock));
 			myData.pActiveButtonSurface = cairo_dock_create_surface_from_image_simple (MY_APPLET_SHARE_DATA_DIR"/active-button.svg",
 				(myData.pListing->container.iWidth - (myDialogsParam.dialogTextDescription.iSize + 2) * 3) / 3,
@@ -658,7 +664,7 @@ void cd_do_load_entries_into_listing (GList *pEntries, int iNbEntries)
 	
 	if (myData.pListing->pEntries != NULL)
 	{
-		cd_debug ("%d entrees precedemment\n", myData.pListing->iNbEntries);
+		cd_debug ("%d entrees precedemment", myData.pListing->iNbEntries);
 		g_list_foreach (myData.pListing->pEntries, (GFunc)cd_do_free_entry, NULL);
 		g_list_free (myData.pListing->pEntries);
 	}
@@ -735,7 +741,7 @@ static inline void _update_scroll (int iNewPosition, int delta)
 	else if (iNewPosition <= myConfig.iNbLinesInListing/2)
 		myData.pListing->fAimedOffset = 0.;
 	else
-		myData.pListing->fAimedOffset = myData.pListing->fAimedOffset = (myData.pListing->iNbVisibleEntries - myConfig.iNbLinesInListing) * (myDialogsParam.dialogTextDescription.iSize + 2);
+		myData.pListing->fAimedOffset = (myData.pListing->iNbVisibleEntries - myConfig.iNbLinesInListing) * (myDialogsParam.dialogTextDescription.iSize + 2);
 	myData.pListing->iScrollAnimationCount = NB_STEPS_FOR_SCROLL;
 }
 static inline void _launch_new_entry_animation (void)
