@@ -55,7 +55,7 @@ static void _cd_cclosure_marshal_VOID__STRING_INT_STRING_STRING_STRING_STRING_ST
 	gpointer invocation_hint G_GNUC_UNUSED,
 	gpointer marshal_data)
 {
-	//cd_debug ("=== %s ()\n", __func__);
+	//cd_debug ("=== %s ()", __func__);
 	typedef void (*GMarshalFunc_VOID__STRING_INT_STRING_STRING_STRING_STRING_STRING) (
 		gpointer     data1,
 		gchar      *arg_1,
@@ -108,7 +108,7 @@ static void _cd_cclosure_marshal_VOID__STRING_INT_STRING_STRING_STRING_STRING_ST
 	gpointer invocation_hint G_GNUC_UNUSED,
 	gpointer marshal_data)
 {
-	//cd_debug ("=== %s ()\n", __func__);
+	//cd_debug ("=== %s ()", __func__);
 	#if (INDICATOR_APPLICATIONADDED_HAS_TITLE == 1)
 	typedef void (*GMarshalFunc_VOID__STRING_INT_STRING_STRING_STRING_STRING_STRING_STRING_STRING_STRING) (
 	#elif (INDICATOR_APPLICATIONADDED_HAS_HINT == 1)
@@ -303,7 +303,7 @@ static void _on_get_applications_from_service (DBusGProxy *proxy, DBusGProxyCall
 			#endif
 			#endif
 			G_TYPE_INVALID));
-	gboolean bSuccess = dbus_g_proxy_end_call (proxy,
+	dbus_g_proxy_end_call (proxy,
 		call_id,
 		&erreur,
 		g_type_ptrarray, &pApplications,
@@ -319,7 +319,7 @@ static void _on_get_applications_from_service (DBusGProxy *proxy, DBusGProxyCall
 	
 	//\______________________ build each items.
 	cd_debug ("=== got %d applications", pApplications->len);
-	guint i, j;
+	guint i;
 	GValueArray *va;
 	GValue *v;
 	CDStatusNotifierItem *pItem = NULL;
