@@ -107,14 +107,14 @@ static CDToolTip *_make_tooltip_from_dbus_struct (GValueArray *pToolTipTab)
 	}
 	return pToolTip;
 }
-
+/* Not used
 static void _show_item_tooltip (Icon *pIcon, CDStatusNotifierItem *pItem)
 {
 	gchar *cText = g_strdup_printf ("<b>%s</b>\n%s", pItem->pToolTip->cTitle, pItem->pToolTip->cMessage);
 	cairo_dock_show_temporary_dialog_with_icon (cText, pIcon, CAIRO_CONTAINER (myIcon->pSubDock), 4000, pItem->pToolTip->cIconName);
 	g_free (cText);
 }
-
+*/
 /*static void _show_item_status (Icon *pIcon, CDStatusNotifierItem *pItem)
 {
 	switch (pItem->iStatus)
@@ -349,14 +349,56 @@ gchar *cd_satus_notifier_search_item_icon_s_path (CDStatusNotifierItem *pItem, g
 	if (cIconPath == NULL)
 	{
 		cIconPath = cairo_dock_search_icon_s_path (cImageName, iSize);
+		if (cIconPath == NULL)  // in case we have a buggy app, try some heuristic
+		{
+			cIconPath = cairo_dock_search_icon_s_path (pItem->cId, iSize);
+			if (cIconPath == NULL)
+				cIconPath = g_strdup (MY_APPLET_SHARE_DATA_DIR"/"MY_APPLET_ICON_FILE);
+		}
 	}
-
-	if (cIconPath == NULL)
-		cIconPath = g_strdup (MY_APPLET_SHARE_DATA_DIR"/"MY_APPLET_ICON_FILE);
-
+	
 	return cIconPath;
 }
 
+static void _cd_cclosure_marshal_VOID__STRING_STRING (GClosure *closure,
+	GValue *return_value G_GNUC_UNUSED,
+	guint n_param_values,
+	const GValue *param_values,
+	gpointer invocation_hint G_GNUC_UNUSED,
+	gpointer marshal_data)
+{
+	typedef void (*GMarshalFunc_VOID__STRING_STRING) (
+		gpointer   data1,
+		gchar      *arg_1,
+		gchar      *arg_2,
+		gpointer   data2);
+	register GMarshalFunc_VOID__STRING_STRING callback;
+	register GCClosure *cc = (GCClosure*) closure;
+	register gpointer data1, data2;
+	g_return_if_fail (n_param_values == 3);  // return_value est NULL ici, car la callback ne renvoit rien.
+
+	if (G_CCLOSURE_SWAP_DATA (closure))
+	{
+		data1 = closure->data;
+		data2 = g_value_peek_pointer (param_values + 0);
+	}
+	else
+	{
+		data1 = g_value_peek_pointer (param_values + 0);
+		data2 = closure->data;
+	}
+	callback = (GMarshalFunc_VOID__STRING_STRING) (marshal_data ? marshal_data : cc->callback);
+	
+	g_return_if_fail (callback != NULL);
+	g_return_if_fail (G_VALUE_HOLDS_STRING (param_values + 1));
+	g_return_if_fail (G_VALUE_HOLDS_STRING (param_values + 2));
+	
+	callback (data1,
+		(char*) g_value_get_string (param_values + 1),
+		(char*) g_value_get_string (param_values + 2),
+		data2);
+}
+
 CDStatusNotifierItem *cd_satus_notifier_create_item (const gchar *cService, const gchar *cObjectPath)
 {
 	g_return_val_if_fail  (cService != NULL, NULL);
@@ -598,6 +640,8 @@ CDStatusNotifierItem *cd_satus_notifier_create_item (const gchar *cService, cons
 		G_CALLBACK(on_new_item_attention_icon), pItem, NULL);
 	
 	// signals supported by Ubuntu.
+	dbus_g_object_register_marshaller(_cd_cclosure_marshal_VOID__STRING_STRING,
+		G_TYPE_NONE, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_INVALID);	
 	dbus_g_proxy_add_signal(pProxyItem, "XAyatanaNewLabel",
 		G_TYPE_STRING, G_TYPE_STRING, G_TYPE_INVALID);
 	dbus_g_proxy_connect_signal(pProxyItem, "XAyatanaNewLabel",
