@@ -145,7 +145,7 @@ CD_APPLET_ON_MIDDLE_CLICK_BEGIN
 	{
 		_emit_click (pItem, CD_APPLET_CLICKED_ICON, CD_APPLET_CLICKED_CONTAINER, "SecondaryActivate");
 	}
-CD_APPLET_ON_CLICK_END
+CD_APPLET_ON_MIDDLE_CLICK_END
 
 
 CD_APPLET_ON_SCROLL_BEGIN
@@ -168,9 +168,9 @@ CD_APPLET_ON_SCROLL_END
 
 
 //\___________ Define here the entries you want to add to the menu when the user right-clicks on your icon or on its subdock or your desklet. The icon and the container that were clicked are available through the macros CD_APPLET_CLICKED_ICON and CD_APPLET_CLICKED_CONTAINER. CD_APPLET_CLICKED_ICON may be NULL if the user clicked in the container but out of icons. The menu where you can add your entries is available throught the macro CD_APPLET_MY_MENU; you can add sub-menu to it if you want.
-CD_APPLET_ON_BUILD_MENU_BEGIN
+/*CD_APPLET_ON_BUILD_MENU_BEGIN
 
-CD_APPLET_ON_BUILD_MENU_END
+CD_APPLET_ON_BUILD_MENU_END*/
 
 
 gboolean cd_status_notifier_on_right_click (CairoDockModuleInstance *myApplet, Icon *pClickedIcon, CairoContainer *pClickedContainer, GtkWidget *pAppletMenu, gboolean *bDiscardMenu)
@@ -256,14 +256,37 @@ gboolean on_mouse_moved (CairoDockModuleInstance *myApplet, CairoContainer *pCon
 		if (pItem == NULL)
 			CD_APPLET_SET_NAME_FOR_MY_ICON (NULL);
 		else
-			CD_APPLET_SET_NAME_FOR_MY_ICON (
-				pItem->cAccessibleDesc && *pItem->cAccessibleDesc != '\0' ? pItem->cAccessibleDesc :
-				pItem->cLabel && *pItem->cLabel != '\0' ? pItem->cLabel :
-				pItem->cTitle && *pItem->cTitle != '\0' ? pItem->cTitle :
-				NULL);
-				// pItem->cId && *pItem->cId != '\0' ? pItem->cId :
-				// maybe better to not display cId, e.g: nm-applet ; dropbox-xxxx ; etc.
-		
+		{
+			GString *sTitle = g_string_new ("");
+			if (pItem->cTitle && *pItem->cTitle != '\0')
+			{
+				gunichar wc = g_utf8_get_char (pItem->cTitle);
+				g_string_append_unichar (sTitle, g_unichar_toupper (wc));  // force the first char to upper
+				g_string_append (sTitle, g_utf8_next_char (pItem->cTitle));
+			}
+			if (pItem->cLabel && *pItem->cLabel != '\0')
+				g_string_append_printf (sTitle, "%s%s", sTitle->len == 0 ? "" : " | ", pItem->cLabel);
+			if (pItem->cAccessibleDesc && *pItem->cAccessibleDesc != '\0')
+				g_string_append_printf (sTitle, "%s%s", sTitle->len == 0 ? "" : " | ", pItem->cAccessibleDesc);
+			if (sTitle->len == 0)  // don't display an empty label
+			{
+				/*
+				 * Let's display the ID if we really have nothing, just to avoid
+				 * having a gap (no label), inconsistency (only on some items),
+				 * and an item that you can't guess until you click on it.
+				 * This is a workaround for applications that don't provide a
+				 * label yet, which should hopefully become rare!
+				 * Since the ID is sometimes too ugly (e.g: dropbox-xxxx,
+				 * emesene-xxxxxxxxx, etc.), we cut the string.
+				 */
+				gchar *cName = cairo_dock_cut_string (pItem->cId, 12);
+				CD_APPLET_SET_NAME_FOR_MY_ICON (cName);
+				g_free (cName);
+			}
+			else
+				CD_APPLET_SET_NAME_FOR_MY_ICON (sTitle->str);
+			g_string_free (sTitle, TRUE);
+		}
 		if (myDock)
 			CAIRO_DOCK_REDRAW_MY_CONTAINER;
 		else
@@ -298,35 +321,45 @@ gboolean on_update_desklet (CairoDockModuleInstance *myApplet, CairoContainer *p
 gboolean on_render_desklet (CairoDockModuleInstance *myApplet, CairoContainer *pContainer, cairo_t *pCairoContext)
 {
 	CD_APPLET_ENTER;
-	int x, y;  // centre du texte.
+	int x, y;  // text center (middle of the icon).
 	x = myIcon->fDrawX + myIcon->fWidth * myIcon->fScale / 2;
 	y = myIcon->fDrawY + myIcon->fHeight * myIcon->fScale / 2;
-	if (x - myIcon->iTextWidth/2 < 0)
+	if (x - myIcon->label.iWidth/2 < 0)
 	{
-		x -= myIcon->iTextWidth/2;
+		x -= myIcon->label.iWidth/2;
 	}
 	if (pCairoContext != NULL)
 	{
-		if (myIcon->pTextBuffer == NULL)
-			CD_APPLET_LEAVE (CAIRO_DOCK_LET_PASS_NOTIFICATION);
-		cairo_save (pCairoContext);
-		cairo_translate (pCairoContext, x, y);
-		cairo_set_source_surface (pCairoContext, myIcon->pTextBuffer, - myIcon->iTextWidth/2, - myIcon->iTextHeight/2);
-		cairo_paint_with_alpha (pCairoContext, myData.fDesktopNameAlpha);
-		cairo_restore (pCairoContext);
+		if (myIcon->label.pSurface != NULL)
+		{
+			/**cairo_save (pCairoContext);
+			cairo_translate (pCairoContext, x, y);
+			cairo_set_source_surface (pCairoContext, myIcon->pTextBuffer, - myIcon->iTextWidth/2, - myIcon->iTextHeight/2);
+			cairo_paint_with_alpha (pCairoContext, myData.fDesktopNameAlpha);
+			cairo_restore (pCairoContext);*/
+			cairo_dock_apply_image_buffer_surface_with_offset (&myIcon->label, pCairoContext,
+				- myIcon->label.iWidth/2, - myIcon->label.iHeight/2, myData.fDesktopNameAlpha);
+		}
 	}
 	else
 	{
-		if (myIcon->iLabelTexture == 0)
-			CD_APPLET_LEAVE (CAIRO_DOCK_LET_PASS_NOTIFICATION);
-		glPushMatrix ();
-		if (myDesklet)
-			glTranslatef (-myDesklet->container.iWidth/2, -myDesklet->container.iHeight/2, -myDesklet->container.iHeight*(sqrt(3)/2));
-		glTranslatef (x - ((myIcon->iTextWidth & 1) ? 0.5 : 0.),
-			y - ((myIcon->iTextHeight & 1) ? 0.5 : 0.),
-			0);
-		cairo_dock_draw_texture_with_alpha (myIcon->iLabelTexture, myIcon->iTextWidth, myIcon->iTextHeight, myData.fDesktopNameAlpha);
-		glPopMatrix ();
+		if (myIcon->label.iTexture != 0)
+		{
+			glPushMatrix ();
+			glTranslatef (-myContainer->iWidth/2, -myContainer->iHeight/2, -myContainer->iHeight*(sqrt(3)/2));
+			/**glTranslatef (x - ((myIcon->iTextWidth & 1) ? 0.5 : 0.),
+				y - ((myIcon->iTextHeight & 1) ? 0.5 : 0.),
+				0);
+			cairo_dock_draw_texture_with_alpha (myIcon->iLabelTexture, myIcon->iTextWidth, myIcon->iTextHeight, myData.fDesktopNameAlpha);*/
+			_cairo_dock_enable_texture ();
+			_cairo_dock_set_blend_alpha ();
+			_cairo_dock_set_alpha (myData.fDesktopNameAlpha);
+			cairo_dock_apply_image_buffer_texture_with_offset (&myIcon->label,
+				x - ((myIcon->label.iWidth & 1) ? 0.5 : 0.),
+				y - ((myIcon->label.iHeight & 1) ? 0.5 : 0.));
+			_cairo_dock_disable_texture ();
+			glPopMatrix ();
+		}
 	}
 	CD_APPLET_LEAVE (CAIRO_DOCK_LET_PASS_NOTIFICATION);
 }
