@@ -21,10 +21,15 @@
 #ifndef __CD_APPLET_STRUCT__
 #define  __CD_APPLET_STRUCT__
 
+#include <cairo-dock.h>
+
+#if (GTK_MAJOR_VERSION < 3) || defined (DBUSMENU_GTK3_NEW)
 #include <libdbusmenu-gtk/menuitem.h>
 #include <libdbusmenu-gtk/menu.h>
-
-#include <cairo-dock.h>
+#else
+#include <libdbusmenu-gtk3/menuitem.h>
+#include <libdbusmenu-gtk3/menu.h>
+#endif
 
 typedef enum {
 	CD_MODE_COMPACT=0,
@@ -38,6 +43,8 @@ struct _AppletConfig {
 	gboolean bCompactMode;  // les items sur l'icone principale ou dans un sous-dock.
 	gboolean bResizeIcon;  // si compact, redimensionner l'icone principale automatiquement.
 	gint iNbLines;  // si compact et redimensionnement auto, nbre de lignes (colonnes en mode vertical).
+	gboolean bHideInactive;
+	gboolean bMenuOnLeftClick;
 	} ;
 
 
@@ -77,12 +84,13 @@ typedef struct {
 	gchar *cLabel;
 	gchar *cLabelGuide;
 	gchar *cMenuPath;
+	gchar *cAccessibleDesc;
 	// additionnal props supported by KDE
 	Window iWindowId;
 	gchar *cAttentionMovieName;
 	gchar *cOverlayIconName;
 	CDToolTip *pToolTip;
-	
+	gboolean bItemIsMenu;
 	gint iPosition;  // donnee par l'indicator service
 	guint iSidPopupTooltip;
 	// data
@@ -91,8 +99,6 @@ typedef struct {
 	gboolean bInvalid;  // item deja en cours de destruction
 	DbusmenuGtkMenu *pMenu;
 	cairo_surface_t *pSurface;
-	/*GLuint iTexture;
-	Icon *pIcon;*/
 } CDStatusNotifierItem;
 
 
@@ -105,6 +111,8 @@ struct _AppletData {
 	DBusGProxy *pProxyIndicatorApplicationService;
 	gboolean bIASWatched;
 	gboolean bBrokenWatcher;
+	gboolean bNoIAS;
+	gboolean bNoWatcher;
 	GList *pItems;  // list of all items.
 	GHashTable *pThemePaths;
 	gint iNbLines, iNbColumns, iItemSize;  // agencement compact.
