@@ -17,11 +17,8 @@
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-
-#include <string.h>
-#include <cairo-dock.h>
-
 #include "applet-struct.h"
+
 #include "applet-backend-alsamixer.h"  // mixer_get_elements_list
 #include "applet-notifications.h"
 #include "applet-config.h"
@@ -58,7 +55,16 @@ CD_APPLET_GET_CONFIG_BEGIN
 	
 	myConfig.iVolumeDisplay = CD_CONFIG_GET_INTEGER ("Configuration", "display volume");
 	
-	myConfig.iVolumeEffect = CD_CONFIG_GET_INTEGER ("Configuration", "effect");
+	myConfig.iVolumeEffect = CD_CONFIG_GET_INTEGER_WITH_DEFAULT ("Configuration", "display icon", -1);
+	if (myConfig.iVolumeEffect >= VOLUME_NB_EFFECTS)  // new option (iVolumeEffect is an unsigned int)
+	{
+		myConfig.iVolumeEffect = CD_CONFIG_GET_INTEGER ("Configuration", "effect");
+		if (myConfig.iVolumeEffect == 1 || myConfig.iVolumeEffect == 2)  // old "zoom" and "transparency" effects
+			myConfig.iVolumeEffect = VOLUME_EFFECT_BAR;
+		else if (myConfig.iVolumeEffect >= 3)  // other options are offseted by 2
+			myConfig.iVolumeEffect -= 2;
+		g_key_file_set_integer (CD_APPLET_MY_KEY_FILE, "Configuration", "display icon", myConfig.iVolumeEffect);
+	}
 	
 	if (myConfig.iVolumeEffect == VOLUME_EFFECT_GAUGE)
 	{
@@ -91,26 +97,26 @@ CD_APPLET_RESET_DATA_BEGIN
 		gtk_widget_destroy (myData.pScale);
 		myData.pScale = NULL;
 	}
-	cairo_surface_destroy (myData.pSurface);
-	if (myData.pMuteSurface)
-		cairo_surface_destroy (myData.pMuteSurface);
 	cairo_dock_dialog_unreference (myData.pDialog);
 CD_APPLET_RESET_DATA_END
 
 
-void cd_mixer_load_custom_widget (CairoDockModuleInstance *myApplet, GKeyFile* pKeyFile)
+void cd_mixer_load_custom_widget (CairoDockModuleInstance *myApplet, GKeyFile* pKeyFile, GSList *pWidgetList)
 {
-	cd_debug ("%s (%s)\n", __func__, myIcon->cName);
+	cd_debug ("%s (%s)", __func__, myIcon->cName);
 	//\____________ On construit la liste des canaux a controler.
 	GList *pList = mixer_get_elements_list ();
 	
 	//\____________ On recupere la combo.
-	GtkWidget *pCombo = CD_APPLET_GET_CONFIG_PANEL_WIDGET ("Configuration", "mixer element");
+	CairoDockGroupKeyWidget *pGroupKeyWidget = cairo_dock_gui_find_group_key_widget_in_list (pWidgetList, "Configuration", "mixer element");
+	
+	GtkWidget *pCombo = cairo_dock_gui_get_first_widget (pGroupKeyWidget);
 	g_return_if_fail (pCombo != NULL);
 	cairo_dock_fill_combo_with_list (pCombo, pList, myConfig.cMixerElementName);
 	
 	//\____________ Idem pour la 2eme, avec une entree vide au debut.
-	pCombo = CD_APPLET_GET_CONFIG_PANEL_WIDGET ("Configuration", "mixer element 2");
+	pGroupKeyWidget = cairo_dock_gui_find_group_key_widget_in_list (pWidgetList, "Configuration", "mixer element 2");
+	pCombo = cairo_dock_gui_get_first_widget (pGroupKeyWidget);
 	g_return_if_fail (pCombo != NULL);
 	pList = g_list_prepend (pList, (gpointer)"");  // on peut caster ici car tous les elements sont des const pour nous.
 	cairo_dock_fill_combo_with_list (pCombo, pList, myConfig.cMixerElementName2);
