@@ -165,6 +165,8 @@ static void _on_drop_data (const gchar *cMyData)
 			
 			gchar *cCommandCopyFileWithComma = g_strdup_printf ("cp '%s' '%s'", cFilePath, myData.cTmpFilePath); // copie du fichier dans tmp.
 			int r = system (cCommandCopyFileWithComma);
+			if (r < 0)
+				cd_warning ("Not able to launch this command: %s", cCommandCopyFileWithComma);
 			g_free (cCommandCopyFileWithComma);
 			g_free (cFilePath);
 			cFilePath = g_strdup (myData.cTmpFilePath);  // on utilise le fichier tmp, il sera efface a la fin de l'upload.
@@ -178,11 +180,13 @@ static void _on_drop_data (const gchar *cMyData)
 		{
 			if (cMimeType != NULL)
 			{
-				cd_debug ("cMimeType : %s (%s)\n", cMimeType, cMyData);
+				cd_debug ("cMimeType : %s (%s)", cMimeType, cMyData);
 				if (strncmp (cMimeType, "image", 5) == 0)
 					iFileType = CD_TYPE_IMAGE;
 				else if (strncmp (cMimeType, "video", 5) == 0)
 					iFileType = CD_TYPE_VIDEO;
+				else if (strncmp (cMimeType, "text", 4) == 0)
+					iFileType = CD_TYPE_TEXT;
 			}
 			g_free (cMimeType);
 		}
@@ -399,8 +403,6 @@ CD_APPLET_ON_MIDDLE_CLICK_END
 
 //\___________ Define here the entries you want to add to the menu when the user right-clicks on your icon or on its subdock or your desklet. The icon and the container that were clicked are available through the macros CD_APPLET_CLICKED_ICON and CD_APPLET_CLICKED_CONTAINER. CD_APPLET_CLICKED_ICON may be NULL if the user clicked in the container but out of icons. The menu where you can add your entries is available throught the macro CD_APPLET_MY_MENU; you can add sub-menu to it if you want.
 CD_APPLET_ON_BUILD_MENU_BEGIN
-	GtkWidget *pModuleSubMenu = CD_APPLET_CREATE_MY_SUB_MENU ();
-	
 	CD_APPLET_ADD_IN_MENU_WITH_STOCK (D_("Send the clipboard's content"), GTK_STOCK_PASTE, _send_clipboard, CD_APPLET_MY_MENU);
 	
 	GtkWidget *pHistoryMenu = gtk_menu_new ();  // we don't use CD_APPLET_ADD_SUB_MENU_WITH_IMAGE, because we want to be able to set the menu-item unsensitive.
@@ -421,10 +423,11 @@ CD_APPLET_ON_BUILD_MENU_BEGIN
 		CDUploadedItem *pItem;
 		GtkWidget *pItemSubMenu;
 		gchar *str;
-		gchar *cName = NULL, *cURI = NULL, *cIconName = NULL;
+		gchar *cName = NULL, *cURI = NULL;
 		gboolean bIsDirectory;
 		int iVolumeID;
 		double fOrder;
+		gint iDesiredIconSize = cairo_dock_search_icon_size (GTK_ICON_SIZE_LARGE_TOOLBAR); // 24px by default
 		int i;
 		GList *it;
 		for (it = myData.pUpoadedItems; it != NULL; it = it->next)
@@ -439,22 +442,22 @@ CD_APPLET_ON_BUILD_MENU_BEGIN
 				if (! g_file_test (cPreview, G_FILE_TEST_EXISTS))
 				{
 					g_free (cPreview);
-					cPreview = cairo_dock_search_icon_s_path ("image-x-generic");;
+					cPreview = cairo_dock_search_icon_s_path ("image-x-generic", iDesiredIconSize);
 				}
 			}
 			else if (pItem->iFileType == CD_TYPE_TEXT)
 			{
-				cPreview = cairo_dock_search_icon_s_path ("text-x-generic");
+				cPreview = cairo_dock_search_icon_s_path ("text-x-generic", iDesiredIconSize);
 			}
 			else if (pItem->iFileType == CD_TYPE_VIDEO)
 			{
-				cPreview = cairo_dock_search_icon_s_path ("video-x-generic");
+				cPreview = cairo_dock_search_icon_s_path ("video-x-generic", iDesiredIconSize);
 			}
 			if (cPreview == NULL)
 			{
 				gchar *cIconName = NULL;
 				cairo_dock_fm_get_file_info (pItem->cLocalPath, &cName, &cURI, &cIconName, &bIsDirectory, &iVolumeID, &fOrder, 0);
-				cPreview = cairo_dock_search_icon_s_path (cIconName);
+				cPreview = cairo_dock_search_icon_s_path (cIconName, iDesiredIconSize);
 				g_free (cIconName);
 				g_free (cName);
 				cName = NULL;
@@ -498,6 +501,4 @@ CD_APPLET_ON_BUILD_MENU_BEGIN
 	if (myConfig.bUseOnlyFileType)
 		gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (pMenuItem), TRUE);
 	g_signal_connect (G_OBJECT (pMenuItem), "toggled", G_CALLBACK (_set_use_only_file_type), NULL);
-
-	CD_APPLET_ADD_ABOUT_IN_MENU (pModuleSubMenu);
 CD_APPLET_ON_BUILD_MENU_END
