@@ -44,8 +44,7 @@ extern gint my_iCurveAmplitude;
 
 extern cairo_surface_t *my_pFlatSeparatorSurface[2];
 
-
-//const guint curveOffsetX = 75;
+// the curve is given by:
 // OM(t) = sum ([k=0..n] Bn,k(t)*OAk)
 // Bn,k(x) = Cn,k*x^k*(1-x)^(n-k)
 
@@ -54,12 +53,12 @@ extern cairo_surface_t *my_pFlatSeparatorSurface[2];
 #define XCurve(W, a, t) (W * xCurve (a, t))
 #define YCurve(h, t) (h * yCurve (t))
 
-#define _define_parameters(h, hi, ti, xi, w, dw)\
+#define _define_parameters(h, hi, ti, xi, dw)\
 	double h = 4./3 * (pDock->iDecorationsHeight + myDocksParam.iDockLineWidth);  /* hauteur de controle de la courbe de Bezier, de telle facon qu'elle atteigne 'iDecorationsHeight'.*/\
 	double hi = .5 * pDock->iMaxIconHeight * pDock->container.fRatio + myDocksParam.iFrameMargin - 1;  /* hauteur de la courbe a la 1ere icone.*/\
 	double ti = .5 * (1. - sqrt (MAX (1. - 4./3 * hi / h, 0.01)));\
 	double xi = xCurve (my_fCurveCurvature, ti);\
-	double w, dw = 0
+	double dw = 0
 
 static void cd_rendering_calculate_reference_curve (double alpha)
 {
@@ -78,7 +77,7 @@ static void cd_rendering_calculate_reference_curve (double alpha)
 		s_pReferenceCurveY = g_new (double, RENDERING_INTERPOLATION_NB_PTS+1);
 	}
 	
-	double s, x, y;
+	double s;
 	int i;
 	for (i = 0; i < RENDERING_INTERPOLATION_NB_PTS+1; i ++)
 	{
@@ -95,10 +94,12 @@ static double cd_rendering_interpol_curve_parameter (double x)
 	return cd_rendering_interpol (x, s_pReferenceCurveX, s_pReferenceCurveS);
 }
 
+/* Not used
 static double cd_rendering_interpol_curve_height (double x)
 {
 	return cd_rendering_interpol (x, s_pReferenceCurveX, s_pReferenceCurveY);
 }
+*/
 
 static void cd_rendering_calculate_max_dock_size_curve (CairoDock *pDock)
 {
@@ -110,7 +111,7 @@ static void cd_rendering_calculate_max_dock_size_curve (CairoDock *pDock)
 	}
 	
 	// on calcule tout ce qu'on peut.
-	pDock->pFirstDrawnElement = cairo_dock_calculate_icons_positions_at_rest_linear (pDock->icons, pDock->fFlatDockWidth, pDock->iScrollOffset);
+	cairo_dock_calculate_icons_positions_at_rest_linear (pDock->icons, pDock->fFlatDockWidth);
 	
 	pDock->iDecorationsHeight = myDocksParam.iFrameMargin + my_iCurveAmplitude + .5 * pDock->iMaxIconHeight;  // de bas en haut.
 	
@@ -119,11 +120,11 @@ static void cd_rendering_calculate_max_dock_size_curve (CairoDock *pDock)
 	double fRatio = (pDock->iRefCount == 0 && pDock->iVisibility == CAIRO_DOCK_VISI_RESERVE ? 1. : pDock->container.fRatio);  // prevent the dock from resizing itself and all the maximized windows each time an icon is removed/inserted.
 	pDock->iMinDockHeight = myDocksParam.iDockLineWidth + myDocksParam.iFrameMargin + my_iCurveAmplitude + pDock->iMaxIconHeight * fRatio;  // de bas en haut.
 	
-	_define_parameters (h, hi, ti, xi, w, dw);
+	_define_parameters (h, hi, ti, xi, dw);
 	
 	// taille max
 	//w
-	w = ceil (cairo_dock_calculate_max_dock_width (pDock, pDock->pFirstDrawnElement, pDock->fFlatDockWidth, 1., 0.));  // etendue max des icones, sans le cadre.
+	double w = ceil (cairo_dock_calculate_max_dock_width (pDock, pDock->fFlatDockWidth, 1., 0.));  // etendue max des icones, sans le cadre.
 	// -> dw
 	dw = w * xi / (1 - 2 * xi);  // abscisse de la 1ere icone pour satisfaire a la contrainte y=hi.
 	// -> pointe
@@ -136,11 +137,11 @@ static void cd_rendering_calculate_max_dock_size_curve (CairoDock *pDock)
 	if (cairo_dock_is_extended_dock (pDock) && w + 2 * dw < Ws)  // alors on etend.
 	{
 		double extra = Ws - w;
-		pDock->iMaxDockWidth = ceil (cairo_dock_calculate_max_dock_width (pDock, pDock->pFirstDrawnElement, pDock->fFlatDockWidth, 1., extra));  // on pourra optimiser, ce qui nous interesse ici c'est les fXMin/fXMax.
+		pDock->iMaxDockWidth = ceil (cairo_dock_calculate_max_dock_width (pDock, pDock->fFlatDockWidth, 1., extra));  // on pourra optimiser, ce qui nous interesse ici c'est les fXMin/fXMax.
 	}
 	else  // rien d'autre a faire
 	{
-		pDock->iMaxDockWidth = ceil (cairo_dock_calculate_max_dock_width (pDock, pDock->pFirstDrawnElement, pDock->fFlatDockWidth, 1., 2 * dw));  // on pourra optimiser, ce qui nous interesse ici c'est les fXMin/fXMax.
+		pDock->iMaxDockWidth = ceil (cairo_dock_calculate_max_dock_width (pDock, pDock->fFlatDockWidth, 1., 2 * dw));  // on pourra optimiser, ce qui nous interesse ici c'est les fXMin/fXMax.
 	}
 	
 	pDock->iDecorationsWidth = pDock->iMaxDockWidth - 4 * fDeltaTip;  // 4 car 2*(interieur+exterieur).
@@ -160,14 +161,13 @@ static void cd_rendering_calculate_max_dock_size_curve (CairoDock *pDock)
 	pDock->iActiveWidth = pDock->iMaxDockWidth;
 	pDock->iActiveHeight = pDock->iMaxDockHeight;
 	if (! pDock->container.bIsHorizontal && myIconsParam.bTextAlwaysHorizontal)
-		pDock->iMaxDockHeight += 6*myIconsParam.iLabelSize;  // vertical dock, add some padding to draw the labels.	
+		pDock->iMaxDockHeight += 8*myIconsParam.iLabelSize;  // vertical dock, add some padding to draw the labels.	
 }
 
 
 static void cd_rendering_make_3D_curve_separator (Icon *icon, cairo_t *pCairoContext, CairoDock *pDock, gboolean bIncludeEdges, gboolean bBackGround)
 {
 	double fLineWidth = myDocksParam.iDockLineWidth;
-	double fMargin = myDocksParam.iFrameMargin;
 	double hi;
 	
 	Icon *pPrevIcon = cairo_dock_get_previous_icon (pDock->icons, icon);
@@ -178,7 +178,7 @@ static void cd_rendering_make_3D_curve_separator (Icon *icon, cairo_t *pCairoCon
 		pNextIcon = icon;
 	
 	double fVanishingDistanceLeft, fVanishingDistanceRight;
-	double fDeltaInterIconLeft, fDeltaInterIconRight;
+	double fDeltaInterIconLeft;
 	if (pDock->container.bDirectionUp)
 	{
 		hi = pDock->container.iHeight - (icon->fDrawY + icon->fHeight * icon->fScale);
@@ -186,7 +186,7 @@ static void cd_rendering_make_3D_curve_separator (Icon *icon, cairo_t *pCairoCon
 		fVanishingDistanceRight = iVanishingPointY + pNextIcon->fDrawY + pNextIcon->fHeight * pNextIcon->fScale;
 		
 		fDeltaInterIconLeft = (pPrevIcon->fDrawY + pPrevIcon->fHeight * pPrevIcon->fScale) - (icon->fDrawY + icon->fHeight * icon->fScale);
-		fDeltaInterIconRight = (icon->fDrawY + icon->fHeight * icon->fScale) - (pNextIcon->fDrawY + pNextIcon->fHeight * pNextIcon->fScale);
+		//fDeltaInterIconRight = (icon->fDrawY + icon->fHeight * icon->fScale) - (pNextIcon->fDrawY + pNextIcon->fHeight * pNextIcon->fScale);
 	}
 	else
 	{
@@ -195,7 +195,7 @@ static void cd_rendering_make_3D_curve_separator (Icon *icon, cairo_t *pCairoCon
 		fVanishingDistanceRight = iVanishingPointY + pDock->container.iHeight - pNextIcon->fDrawY;
 		
 		fDeltaInterIconLeft = (pPrevIcon->fDrawY) - (icon->fDrawY);
-		fDeltaInterIconRight = (icon->fDrawY) - (pNextIcon->fDrawY);
+		//fDeltaInterIconRight = (icon->fDrawY) - (pNextIcon->fDrawY);
 	}
 	double fLeftInclination = (icon->fDrawX - pDock->container.iWidth / 2) / fVanishingDistanceLeft;
 	double fRightInclination = (icon->fDrawX + icon->fWidth * icon->fScale - pDock->container.iWidth / 2) / fVanishingDistanceRight;
@@ -203,7 +203,7 @@ static void cd_rendering_make_3D_curve_separator (Icon *icon, cairo_t *pCairoCon
 	if (bBackGround || ! bIncludeEdges)  // pour s'arreter sur la courbe, on realise un clippage.
 	{
 		//\________________ On se ramene au cas du dessin optimise.
-		double x0, y0, xf, yf, w0, h0;
+		double x0, xf, w0;
 		if (pDock->container.bDirectionUp)
 		{
 			x0 = icon->fDrawX - MAX (0, fLeftInclination * (pPrevIcon->fDrawY + pPrevIcon->fHeight * pPrevIcon->fScale));
@@ -228,10 +228,7 @@ static void cd_rendering_make_3D_curve_separator (Icon *icon, cairo_t *pCairoCon
 			}
 		}
 		//g_print ("x0:%.2f -> xf:%.2f\n", x0, xf);
-		y0 = 0;
-		yf = icon->fDrawY;
 		w0 = xf - x0;
-		h0 = yf - y0;
 		
 		int sens;
 		double fDockOffsetY;  // Offset du coin haut gauche du cadre.
@@ -254,7 +251,7 @@ static void cd_rendering_make_3D_curve_separator (Icon *icon, cairo_t *pCairoCon
 		double xi = xCurve (my_fCurveCurvature, ti);
 		double curveOffsetX = fDockWidth * xi / (1 - 2 * xi);
 		
-		Icon *pFirstIcon = cairo_dock_get_first_drawn_icon (pDock);
+		Icon *pFirstIcon = cairo_dock_get_first_icon (pDock->icons);
 		double fDockOffsetX = (pFirstIcon != NULL ? pFirstIcon->fDrawX - curveOffsetX : fLineWidth / 2);
 		
 		
@@ -367,7 +364,12 @@ static void cd_rendering_make_3D_curve_separator (Icon *icon, cairo_t *pCairoCon
 		{
 			if (! pDock->container.bDirectionUp)
 				cairo_scale (pCairoContext, 1, -1);
-			cairo_set_source_surface (pCairoContext, my_pFlatSeparatorSurface[CAIRO_DOCK_HORIZONTAL], MIN (0, (fHeight + hi) * fLeftInclination), 0);
+			/**cairo_set_source_surface (pCairoContext, my_pFlatSeparatorSurface[CAIRO_DOCK_HORIZONTAL], MIN (0, (fHeight + hi) * fLeftInclination), 0);*/
+			
+			cairo_clip (pCairoContext);
+			cairo_translate (pCairoContext, MIN (0, (fHeight + hi) * fLeftInclination), 0);
+			cairo_scale (pCairoContext, (fLittleWidth + MAX (fabs (fDeltaXRight), fabs (fDeltaXLeft)))/1, 1.);
+			cairo_set_source_surface (pCairoContext, my_pFlatSeparatorSurface[CAIRO_DOCK_HORIZONTAL], 0, 0);
 		}
 	}
 	else
@@ -384,7 +386,12 @@ static void cd_rendering_make_3D_curve_separator (Icon *icon, cairo_t *pCairoCon
 		{
 			if (! pDock->container.bDirectionUp)
 				cairo_scale (pCairoContext, -1, 1);
-			cairo_set_source_surface (pCairoContext, my_pFlatSeparatorSurface[CAIRO_DOCK_VERTICAL], 0, MIN (0, (fHeight + hi) * fLeftInclination));
+			/**cairo_set_source_surface (pCairoContext, my_pFlatSeparatorSurface[CAIRO_DOCK_VERTICAL], 0, MIN (0, (fHeight + hi) * fLeftInclination));*/
+			
+			cairo_clip (pCairoContext);
+			cairo_translate (pCairoContext, 0, MIN (0, (fHeight + hi) * fLeftInclination));
+			cairo_scale (pCairoContext, 1., (fLittleWidth + MAX (fabs (fDeltaXRight), fabs (fDeltaXLeft)))/1);
+			cairo_set_source_surface (pCairoContext, my_pFlatSeparatorSurface[CAIRO_DOCK_VERTICAL], 0, 0);
 		}
 	}
 }
@@ -415,9 +422,9 @@ static void cd_rendering_draw_3D_curve_separator_edge (Icon *icon, cairo_t *pCai
 	double fRightInclination = (icon->fDrawX + icon->fWidth * icon->fScale - pDock->container.iWidth / 2) / fVanishingDistanceRight;
 	
 	
-	double fHeight, fBigWidth, fLittleWidth;
+	double fHeight, fLittleWidth;
 	fHeight = (bBackGround ? pDock->iDecorationsHeight - hi - 0.5*myDocksParam.iDockLineWidth : hi + 1.5*myDocksParam.iDockLineWidth);
-	fBigWidth = fabs (fRightInclination - fLeftInclination) * (bBackGround ? iVanishingPointY : iVanishingPointY + fHeight);
+	//fBigWidth = fabs (fRightInclination - fLeftInclination) * (bBackGround ? iVanishingPointY : iVanishingPointY + fHeight);
 	fLittleWidth = fabs (fRightInclination - fLeftInclination) * (bBackGround ? iVanishingPointY - fHeight : iVanishingPointY);
 	
 	double fDeltaXLeft = fHeight * fLeftInclination;
@@ -482,6 +489,7 @@ static void cd_rendering_draw_3D_curve_separator (Icon *icon, cairo_t *pCairoCon
 	else
 	{
 		cairo_fill (pCairoContext);
+		cairo_paint (pCairoContext);
 	}
 }
 
@@ -520,10 +528,9 @@ static void cd_rendering_render_curve (cairo_t *pCairoContext, CairoDock *pDock)
 {
 	//\____________________ On definit la position du cadre.
 	double fLineWidth = myDocksParam.iDockLineWidth;
-	double fMargin = myDocksParam.iFrameMargin;
 	
-	_define_parameters (h, hi, ti, xi, w, dw);
-	w = cairo_dock_get_current_dock_width_linear (pDock) - 2 * myDocksParam.iFrameMargin;
+	_define_parameters (h, hi, ti, xi, dw);
+	double w = cairo_dock_get_current_dock_width_linear (pDock) - 2 * myDocksParam.iFrameMargin;
 	
 	int sens;
 	double dx, dy;  // position de la pointe gauche.
@@ -536,7 +543,7 @@ static void cd_rendering_render_curve (cairo_t *pCairoContext, CairoDock *pDock)
 	else
 	{
 		dw = w * xi / (1 - 2 * xi);
-		Icon *pFirstIcon = cairo_dock_get_first_drawn_icon (pDock);
+		Icon *pFirstIcon = cairo_dock_get_first_icon (pDock->icons);
 		dx = (pFirstIcon != NULL ? pFirstIcon->fDrawX - dw : fLineWidth / 2);
 	}
 	if (pDock->container.bDirectionUp)
@@ -654,24 +661,25 @@ static gboolean _cd_separator_is_impacted (Icon *icon, CairoDock *pDock, double
 	double fLeftInclination = fabs (icon->fDrawX - pDock->container.iWidth / 2) / iVanishingPointY;
 	double fRightInclination = fabs (icon->fDrawX + icon->fWidth * icon->fScale - pDock->container.iWidth / 2) / iVanishingPointY;
 	
-	double fHeight, fBigWidth, fLittleWidth;
+	double fHeight;
 	if (bIncludeEdges)
 	{
 		fHeight = (bBackGround ? pDock->iDecorationsHeight - hi : hi) + (bIncludeEdges ? myDocksParam.iDockLineWidth : 0);
-		fBigWidth = fabs (fRightInclination - fLeftInclination) * (bBackGround ? iVanishingPointY : iVanishingPointY + fHeight);
-		fLittleWidth = fabs (fRightInclination - fLeftInclination) * (bBackGround ? iVanishingPointY - fHeight : iVanishingPointY);
+		//fBigWidth = fabs (fRightInclination - fLeftInclination) * (bBackGround ? iVanishingPointY : iVanishingPointY + fHeight);
+		//fLittleWidth = fabs (fRightInclination - fLeftInclination) * (bBackGround ? iVanishingPointY - fHeight : iVanishingPointY);
 	}
 	else
 	{
 		fHeight = pDock->iDecorationsHeight;
-		fBigWidth = fabs (fRightInclination - fLeftInclination) * (iVanishingPointY + fHeight);
-		fLittleWidth = fabs (fRightInclination - fLeftInclination) * (iVanishingPointY - fHeight);
+		//fBigWidth = fabs (fRightInclination - fLeftInclination) * (iVanishingPointY + fHeight);
+		//fLittleWidth = fabs (fRightInclination - fLeftInclination) * (iVanishingPointY - fHeight);
 	}
-	double fDeltaXLeft = fHeight * fLeftInclination;
-	double fDeltaXRight = fHeight * fRightInclination;
-	double fDeltaX = MAX (fDeltaXLeft, fDeltaXRight);
+	//double fDeltaXLeft = fHeight * fLeftInclination;
+	//double fDeltaXRight = fHeight * fRightInclination;
+	//double fDeltaX = MAX (fDeltaXLeft, fDeltaXRight);
 	//g_print ("fBigWidth : %.2f ; fLittleWidth : %.2f\n", fBigWidth, fLittleWidth);
-	
+
+	/*
 	int sens;
 	double fDockOffsetX, fDockOffsetY;
 	if (pDock->container.bDirectionUp)
@@ -695,6 +703,7 @@ static gboolean _cd_separator_is_impacted (Icon *icon, CairoDock *pDock, double
 			fDockOffsetX = icon->fDrawX - (bBackGround ? fHeight * fLeftInclination : 0);
 		else
 			fDockOffsetX = icon->fDrawX - (fHeight - hi) * fLeftInclination;
+	*/
 	double fXLeft, fXRight;
 	if (icon->fDrawX + icon->fWidth * icon->fScale / 2 > pDock->container.iWidth / 2)  // on est a droite.
 	{
@@ -746,10 +755,9 @@ static void cd_rendering_render_optimized_curve (cairo_t *pCairoContext, CairoDo
 {
 	//\____________________ On trace le cadre.
 	double fLineWidth = myDocksParam.iDockLineWidth;
-	double fMargin = myDocksParam.iFrameMargin;
-	_define_parameters (h, hi, ti, xi, w, dw);
+	_define_parameters (h, hi, ti, xi, dw);
 	int sens;
-	double dx, dy;
+	double dx, dy, w;
 	
 	w = cairo_dock_get_current_dock_width_linear (pDock) - 2 * myDocksParam.iFrameMargin;
 	if (cairo_dock_is_extended_dock (pDock))
@@ -761,7 +769,7 @@ static void cd_rendering_render_optimized_curve (cairo_t *pCairoContext, CairoDo
 	else
 	{
 		dw = w * xi / (1 - 2 * xi);
-		Icon *pFirstIcon = cairo_dock_get_first_drawn_icon (pDock);
+		Icon *pFirstIcon = cairo_dock_get_first_icon (pDock->icons);
 		dx = (pFirstIcon != NULL ? pFirstIcon->fX - dw : fLineWidth / 2);  // la gauche du cadre suit la 1ere icone.
 	}
 	
@@ -776,20 +784,16 @@ static void cd_rendering_render_optimized_curve (cairo_t *pCairoContext, CairoDo
 		dy = .5 * fLineWidth;
 	}
 	
-	int x0, y0, w0, h0;
+	int x0, w0;
 	if (pDock->container.bIsHorizontal)
 	{
 		x0 = pArea->x;
-		y0 = pArea->y;
 		w0 = pArea->width;
-		h0 = pArea->height;
 	}
 	else
 	{
 		x0 = pArea->y;
-		y0 = pArea->x;
 		w0 = pArea->height;
-		h0 = pArea->width;
 	}
 	
 	//\________________ On approche le morceau de courbe de Bezier par des trapezes.
@@ -887,7 +891,7 @@ static void cd_rendering_render_optimized_curve (cairo_t *pCairoContext, CairoDo
 	//g_print ("x : %.2f => t : %.2f\n", x, t);*/
 	
 	//\____________________ On dessine les icones impactees.
-	GList *pFirstDrawnElement = (pDock->pFirstDrawnElement != NULL ? pDock->pFirstDrawnElement : pDock->icons);
+	GList *pFirstDrawnElement = pDock->icons;
 	if (pFirstDrawnElement != NULL)
 	{
 		double fXMin = (pDock->container.bIsHorizontal ? pArea->x : pArea->y), fXMax = (pDock->container.bIsHorizontal ? pArea->x + pArea->width : pArea->y + pArea->height);
@@ -926,10 +930,7 @@ static void cd_rendering_render_optimized_curve (cairo_t *pCairoContext, CairoDo
 					
 					if (fXLeft <= fXMax && floor (fXRight) > fXMin)
 					{
-						//if (icon->fDrawX >= 0 && icon->fDrawX + icon->fWidth * icon->fScale <= pDock->container.iWidth)
-							icon->fAlpha = 1;
-						//else
-						//	icon->fAlpha = .25;
+						icon->fAlpha = 1;
 						
 						cairo_save (pCairoContext);
 						
@@ -971,10 +972,7 @@ static void cd_rendering_render_optimized_curve (cairo_t *pCairoContext, CairoDo
 				
 				if (fXLeft <= fXMax && floor (fXRight) > fXMin)
 				{
-					//if (icon->fDrawX >= 0 && icon->fDrawX + icon->fWidth * icon->fScale <= pDock->container.iWidth)
-						icon->fAlpha = 1;
-					//else
-					//	icon->fAlpha = .25;
+					icon->fAlpha = 1;
 					
 					cairo_save (pCairoContext);
 					
@@ -991,7 +989,7 @@ static void cd_rendering_render_optimized_curve (cairo_t *pCairoContext, CairoDo
 
 Icon *cd_rendering_calculate_icons_curve (CairoDock *pDock)
 {
-	Icon *pPointedIcon = cairo_dock_apply_wave_effect (pDock);
+	Icon *pPointedIcon = cairo_dock_apply_wave_effect_linear (pDock);
 	
 	cairo_dock_check_if_mouse_inside_linear (pDock);
 	
@@ -999,7 +997,7 @@ Icon *cd_rendering_calculate_icons_curve (CairoDock *pDock)
 	if(pDock->icons  == NULL)
 		return NULL;
 	gint sens = pDock->container.bDirectionUp ? 1 : -1;
-	double fReflectionOffsetY = - sens * myIconsParam.fReflectSize;
+	//double fReflectionOffsetY = - sens * /**myIconsParam.fReflectSize*/pDock->iIconSize * myIconsParam.fReflectHeightRatio;
 	// On va calculer une parabole pour approcher la courbe de bézier : 
 	// Soient A: (xa,ya) B: (xb,yb) C: (xc,yc) trois points qui appartiennent à la parabole. xa, xb et xc sont distincts.
 	// P1(x)=(x-xb)(x-xc)
@@ -1011,7 +1009,7 @@ Icon *cd_rendering_calculate_icons_curve (CairoDock *pDock)
 	gdouble xa, xb, xc, ya, yb, yc, k1, k2, k3;
 	if (cairo_dock_is_extended_dock (pDock))  // A et C correspondent aux extremites du cadre
 	{
-		_define_parameters (h, hi, ti, xi, w, dw);
+		_define_parameters (h, hi, ti, xi, dw);
 		double Ws = pDock->container.iWidth;  // = w + 2*dw = dw / xi * (1 - 2 * xi) + 2*dw = dw / xi
 		dw = Ws * xi;  // on neglige la pointe.
 		xa = dw;
@@ -1021,8 +1019,8 @@ Icon *cd_rendering_calculate_icons_curve (CairoDock *pDock)
 	}
 	else  // A et C correspondent au bas des icones extremes
 	{
-		Icon *pFirstIcon = cairo_dock_get_first_drawn_icon (pDock);
-		Icon *pLastIcon = cairo_dock_get_last_drawn_icon (pDock);
+		Icon *pFirstIcon = cairo_dock_get_first_icon (pDock->icons);
+		Icon *pLastIcon = cairo_dock_get_last_icon (pDock->icons);
 		xa = pFirstIcon->fX ; // icone de gauche
 		ya = 0;
 		xc = pLastIcon->fX;  // icone de droite
@@ -1058,11 +1056,7 @@ Icon *cd_rendering_calculate_icons_curve (CairoDock *pDock)
 		icon->fHeightFactor = 1.;
 		///icon->fDeltaYReflection = 0.;
 		icon->fOrientation = 0.;
-		//if (icon->fDrawX >= 0 && icon->fDrawX + icon->fWidth * icon->fScale <= pDock->container.iWidth)
-			icon->fAlpha = 1;
-		//else
-		//	icon->fAlpha = .25;
-		//g_print ("fDrawX:%.2f / %d (%.2f)\n", icon->fDrawX, pDock->container.iWidth, icon->fAlpha);
+		icon->fAlpha = 1;
 	}
 	
 	cairo_dock_check_can_drop_linear (pDock);
@@ -1072,14 +1066,12 @@ Icon *cd_rendering_calculate_icons_curve (CairoDock *pDock)
 
 
 #define DELTA_ROUND_DEGREE 1
-#define RADIAN (G_PI / 180.0)  // Conversion Radian/Degres
 #define P(t,p,q,r,s) (1-t) * (1-t) * (1-t) * p + 3 * t * (1-t) * (1 - t) * q + 3 * t * t * (1-t) * r + t * t * t * s
 const CairoDockGLPath *cairo_dock_generate_curve_path (double fRelativeControlHeight)
 {
 	static CairoDockGLPath *pPath = NULL;
 	
 	double w = 1. / 2;
-	double h = 1. / 2;
 	double xp = -w, xq = - my_fCurveCurvature * w, xr = - xq, xs = - xp;
 	double yp = 0., yq = fRelativeControlHeight, yr = yq, ys = yp;
 	int iNbPoints = 180/DELTA_ROUND_DEGREE;
@@ -1088,41 +1080,11 @@ const CairoDockGLPath *cairo_dock_generate_curve_path (double fRelativeControlHe
 		pPath = cairo_dock_new_gl_path (iNbPoints+1, xp, yp, 1., 1.);
 	else
 	{
-		cairo_dock_gl_path_move_to (pPath, xp, yp);
+		cairo_dock_gl_path_move_to (pPath, xp, yp);  // drawing from the middle of the bottom rectilinear line sounds better for the GL_TRIANGLE_FAN, however in practice I haven't noticed any difference.
 	}
 	
 	cairo_dock_gl_path_curve_to (pPath, iNbPoints, xq, yq, xr, yr, xs, ys);
 	return pPath;
-	/** //static GLfloat pVertexTab[((180/DELTA_ROUND_DEGREE+1)+1)*3];
-	_cairo_dock_define_static_vertex_tab ((180/DELTA_ROUND_DEGREE+1)+1);
-	0, 0
-	(1 - my_fCurveCurvature) * fFrameWidth / 2, -sens * fControlHeight,
-	(1 + my_fCurveCurvature) * fFrameWidth / 2, -sens * fControlHeight,
-	fFrameWidth, 0
-	double w = 1. / 2;
-	double h = 1. / 2;
-	double xp = -w, xq = - my_fCurveCurvature * w, xr = - xq, xs = - xp;
-	double yp = 0., yq = fRelativeControlHeight, yr = yq, ys = yp;
-	
-	//g_print ("%s (%.2f)\n", __func__, yq);
-	int iPrecision = DELTA_ROUND_DEGREE;
-	int i=0, t;
-	for (t = 0; t <= 180; t += iPrecision, i++)
-	{
-		_cairo_dock_set_vertex_xy (i,
-			P (t/180., xp, xq, xr, xs),
-			P (t/180., yp, yq, yr, ys) - h);
-		//vx(i) = P (t/180., xp, xq, xr, xs);
-		//vy(i) = P (t/180., yp, yq, yr, ys) - h;
-	}
-	
-	// on trace la ligne du bas.
-	_cairo_dock_close_path (i);  // on boucle.
-	//vx(i) = vx(0);  // on boucle.
-	//vy(i) = vy(0);
-	
-	*iNbPoints = i+1;
-	_cairo_dock_return_vertex_tab ();*/
 }
 
 
@@ -1131,13 +1093,12 @@ static void cd_rendering_render_curve_opengl (CairoDock *pDock)
 {
 	//\____________________ On definit la position du cadre.
 	double fLineWidth = myDocksParam.iDockLineWidth;
-	double fMargin = myDocksParam.iFrameMargin;
 	
-	_define_parameters (h, hi, ti, xi, w, dw);
-	w = cairo_dock_get_current_dock_width_linear (pDock) - 2 * myDocksParam.iFrameMargin;
+	_define_parameters (h, hi, ti, xi, dw);
+	double w = cairo_dock_get_current_dock_width_linear (pDock) - 2 * myDocksParam.iFrameMargin;
 	dw = w * xi / (1 - 2 * xi);
 	
-	double dx, dy;  // position de la pointe gauche.
+	double dx;  // position de la pointe gauche.
 	if (cairo_dock_is_extended_dock (pDock))  // mode panel etendu.
 	{
 		dx = 0;
@@ -1146,11 +1107,10 @@ static void cd_rendering_render_curve_opengl (CairoDock *pDock)
 	}
 	else
 	{
-		Icon *pFirstIcon = cairo_dock_get_first_drawn_icon (pDock);
+		Icon *pFirstIcon = cairo_dock_get_first_icon (pDock->icons);
 		dx = (pFirstIcon != NULL ? pFirstIcon->fDrawX - dw : fLineWidth / 2);
 	}
 	
-	dy = pDock->iDecorationsHeight + 1.5 * fLineWidth;
 	double fFrameHeight = pDock->iDecorationsHeight + fLineWidth;
 	
 	//\_____________ On genere les coordonnees du contour.
@@ -1174,11 +1134,6 @@ static void cd_rendering_render_curve_opengl (CairoDock *pDock)
 	glScalef (w + 2 * dw, fFrameHeight + fLineWidth + fEpsilon, 1.);
 	cairo_dock_fill_gl_path (pFramePath, 0);
 	
-	/*cairo_dock_draw_frame_background_opengl (0,
-		w + 2 * dw, fFrameHeight + fLineWidth + fEpsilon,
-		dx, dy + (fLineWidth+fEpsilon)/2,
-		pVertexTab, iNbVertex,
-		pDock->container.bIsHorizontal, pDock->container.bDirectionUp, pDock->fDecorationsOffsetX);  // le cadre est trace au milieu de la ligne, donc on augmente de l la hauteur (et donc de l/2 pixels la hauteur du cadre, car [-.5, .5]), et pour compenser on se translate de l/2.*/
 	glPopMatrix ();
 	
 	glColorMask (TRUE, TRUE, TRUE, TRUE);
@@ -1194,11 +1149,6 @@ static void cd_rendering_render_curve_opengl (CairoDock *pDock)
 		0.);
 	glScalef (w + 2 * dw, fFrameHeight, 1.);
 	cairo_dock_fill_gl_path (pFramePath, pDock->backgroundBuffer.iTexture);
-	/*cairo_dock_draw_frame_background_opengl (pDock->backgroundBuffer.iTexture,
-		w + 2 * dw, fFrameHeight,
-		dx, dy,
-		pVertexTab, iNbVertex,
-		pDock->container.bIsHorizontal, pDock->container.bDirectionUp, pDock->fDecorationsOffsetX);*/
 	
 	//\____________________ On dessine le cadre.
 	if (fLineWidth > 0)
