@@ -25,7 +25,7 @@
 #include "rendering-3D-plane.h"
 #include "rendering-rainbow.h"
 //#include "rendering-diapo.h"
-#include "rendering-diapo-simple.h"
+#include "rendering-slide.h"
 #include "rendering-curve.h"
 #include "rendering-panel.h"
 #include "rendering-commons.h"
@@ -120,8 +120,9 @@ gint my_iCurveAmplitude;
 gdouble my_fPanelRadius;
 gdouble my_fPanelInclination;
 gdouble my_fPanelRatio;
+gboolean my_bPanelPhysicalSeparator;
 
-gint my_iDrawSeparator3D = 0;
+CairoDockSpeparatorType my_iDrawSeparator3D = CAIRO_DOCK_NORMAL_SEPARATOR;
 gdouble my_fSeparatorColor[4];
 
 
