@@ -87,7 +87,7 @@ static void cd_rendering_set_subdock_position_parabole (Icon *pPointedIcon, Cair
 			Icon *icon = pSubDock->icons->data;
 			iX += (pPointedIcon->fWidth * pPointedIcon->fScale - icon->fWidth) / 2;
 		}
-		//cd_debug ("recalage : %.2f (%d)\n", -iMouseX + pPointedIcon->fDrawX + pPointedIcon->fWidth * pPointedIcon->fScale / 2, pSubDock->iMaxLabelWidth);
+		//cd_debug ("recalage : %.2f (%d)", -iMouseX + pPointedIcon->fDrawX + pPointedIcon->fWidth * pPointedIcon->fScale / 2, pSubDock->iMaxLabelWidth);
 		pSubDock->fAlign = 0;
 		pSubDock->iGapY = (pDock->iGapY + pDock->iActiveHeight);
 		pSubDock->iGapX = iX + pDock->container.iWindowPositionX - (pDock->container.bIsHorizontal ? pDock->iScreenOffsetX : pDock->iScreenOffsetY) - pSubDock->iMaxLabelWidth;
@@ -106,7 +106,7 @@ static void cd_rendering_set_subdock_position_parabole (Icon *pPointedIcon, Cair
 		pSubDock->iGapX =  pDock->container.iWindowPositionX - (pDock->container.bIsHorizontal ? pDock->iScreenOffsetX : pDock->iScreenOffsetY) + iX - g_desktopGeometry.iScreenWidth[pDock->container.bIsHorizontal] + pSubDock->iMaxLabelWidth;
 		
 	}
-	//cd_debug ("pSubDock->iGapY : %d\n", pSubDock->iGapY);
+	//cd_debug ("pSubDock->iGapY : %d", pSubDock->iGapY);
 }
 
 
@@ -243,17 +243,17 @@ double cd_rendering_interpol_curvilign_abscisse (double x, double y, double lamb
 {
 	double w = g_desktopGeometry.iScreenHeight[CAIRO_DOCK_HORIZONTAL] / my_fParaboleRatio;  // aie, au changement de resolution ...
 	double lambda_reference = my_fParaboleRatio * pow (w, 1 - alpha);
-	//cd_debug ("%s (%.2f / %.2f)\n", __func__, lambda, lambda_reference);
+	//cd_debug ("%s (%.2f / %.2f)", __func__, lambda, lambda_reference);
 	if (my_fParaboleRatio < 1)
 	{
 		double coef = pow (lambda / lambda_reference, 1. / (alpha - 1));
-		//cd_debug (" xcoef : %.2f\n", coef);
+		//cd_debug (" xcoef : %.2f", coef);
 		return cd_rendering_interpol (x * coef, s_pReferenceParaboleX, s_pReferenceParaboleS) / coef;
 	}
 	else
 	{
 		double coef = pow (lambda / lambda_reference, - 1. / alpha);
-		//cd_debug (" ycoef : %.2f\n", coef);
+		//cd_debug (" ycoef : %.2f", coef);
 		return cd_rendering_interpol (y * coef, s_pReferenceParaboleY, s_pReferenceParaboleS) / coef;
 	}
 }
@@ -281,12 +281,12 @@ static void cd_rendering_calculate_max_dock_size_parabole (CairoDock *pDock)
 		//cd_debug ("  fXAtRest : %.2f; [%.2f;%.2f]", icon->fXAtRest, icon->fXMin, icon->fXMax);
 		icon->fXMax = icon->fXAtRest + 1e4;
 		icon->fXMin = icon->fXAtRest - 1e4;
-		pDock->iMaxLabelWidth = MAX (pDock->iMaxLabelWidth, icon->iTextWidth);
+		pDock->iMaxLabelWidth = MAX (pDock->iMaxLabelWidth, icon->label.iWidth);
 	}
 	//cd_debug ("> iMaxLabelWidth : %d+%d", pDock->iMaxLabelWidth, my_iParaboleTextGap);
 	pDock->iMaxLabelWidth += my_iParaboleTextGap;
 	
-	double alpha = my_fParaboleCurvature, lambda;
+	//double alpha = my_fParaboleCurvature;
 	double h=0, w=0, h_, w_;
 	if (my_fParaboleRatio > 1)
 	{
@@ -295,7 +295,7 @@ static void cd_rendering_calculate_max_dock_size_parabole (CairoDock *pDock)
 		{
 			h = h_;
 			w = h / my_fParaboleRatio;
-			lambda = h / pow (w, alpha);
+			//lambda = h / pow (w, alpha);
 			//cd_debug ("-> %.2fx%.2f , %.2f", w, h, lambda);
 			
 			h_ = cd_rendering_interpol (iMaxDockWidth, s_pReferenceParaboleS, s_pReferenceParaboleY);
@@ -305,7 +305,7 @@ static void cd_rendering_calculate_max_dock_size_parabole (CairoDock *pDock)
 		
 		h = h_;
 		w = w_;
-		lambda = h / pow (w, alpha);
+		//lambda = h / pow (w, alpha);
 		//cd_debug ("=> %.2fx%.2f , %.2f", w, h, lambda);
 	}
 	
@@ -349,6 +349,7 @@ static void cd_rendering_render_parabole (cairo_t *pCairoContext, CairoDock *pDo
 		return;
 	
 	double fDockMagnitude = 1;  // pour le rendu des icones, on utilise la magnitude max.
+	double fAlpha = (1 - pDock->fFoldingFactor) * (1 - pDock->fFoldingFactor);
 	gboolean bHorizontal = pDock->container.bIsHorizontal;
 	Icon *icon;
 	GList *ic = pFirstDrawnElement;
@@ -360,7 +361,7 @@ static void cd_rendering_render_parabole (cairo_t *pCairoContext, CairoDock *pDo
 		cairo_dock_render_one_icon (icon, pDock, pCairoContext, fDockMagnitude, FALSE);
 		cairo_restore (pCairoContext);
 		
-		if (icon->pTextBuffer != NULL && (my_bDrawTextWhileUnfolding || pDock->fFoldingFactor == 0))
+		if (icon->label.pSurface != NULL && (my_bDrawTextWhileUnfolding || pDock->fFoldingFactor == 0))
 		{
 			cairo_save (pCairoContext);
 			if (bHorizontal)
@@ -371,39 +372,59 @@ static void cd_rendering_render_parabole (cairo_t *pCairoContext, CairoDock *pDo
 			if (pDock->fAlign == 1)
 			{
 				if (bHorizontal)
-					cairo_set_source_surface (pCairoContext,
+				{
+					/**cairo_set_source_surface (pCairoContext,
 						icon->pTextBuffer,
 						icon->fWidth * icon->fScale + my_iParaboleTextGap,
-						(icon->fHeight * icon->fScale - icon->iTextHeight)/2);
+						(icon->fHeight * icon->fScale - icon->label.iHeight)/2);*/
+					cairo_dock_apply_image_buffer_surface_with_offset (&icon->label, pCairoContext,
+						icon->fWidth * icon->fScale + my_iParaboleTextGap,
+						(icon->fHeight * icon->fScale - icon->label.iHeight)/2,
+						fAlpha);
+				}
 				else
 				{
 					cairo_rotate (pCairoContext, G_PI/2);
-					cairo_set_source_surface (pCairoContext,
+					/**cairo_set_source_surface (pCairoContext,
 						icon->pTextBuffer,
 						icon->fWidth * icon->fScale + my_iParaboleTextGap,
-						(-icon->fHeight * icon->fScale - icon->iTextHeight)/2);
+						(-icon->fHeight * icon->fScale - icon->label.iHeight)/2);*/
+					cairo_dock_apply_image_buffer_surface_with_offset (&icon->label, pCairoContext,
+						icon->fWidth * icon->fScale + my_iParaboleTextGap,
+						(-icon->fHeight * icon->fScale - icon->label.iHeight)/2,
+						fAlpha);
 				}
 			}
 			else
 			{
 				if (bHorizontal)
-					cairo_set_source_surface (pCairoContext,
+				{
+					/**cairo_set_source_surface (pCairoContext,
 						icon->pTextBuffer,
-						- (icon->iTextWidth + my_iParaboleTextGap),
-						(icon->fHeight * icon->fScale - icon->iTextHeight)/2);
+						- (icon->label.iWidth + my_iParaboleTextGap),
+						(icon->fHeight * icon->fScale - icon->label.iHeight)/2);*/
+					cairo_dock_apply_image_buffer_surface_with_offset (&icon->label, pCairoContext,
+						- (icon->label.iWidth + my_iParaboleTextGap),
+						(icon->fHeight * icon->fScale - icon->label.iHeight)/2,
+						fAlpha);
+				}
 				else
 				{
 					cairo_rotate (pCairoContext, G_PI/2);
-					cairo_set_source_surface (pCairoContext,
+					/**cairo_set_source_surface (pCairoContext,
 						icon->pTextBuffer,
-						- (icon->iTextWidth + my_iParaboleTextGap),
-						(-icon->fHeight * icon->fScale - icon->iTextHeight)/2);
+						- (icon->label.iWidth + my_iParaboleTextGap),
+						(-icon->fHeight * icon->fScale - icon->label.iHeight)/2);*/
+					cairo_dock_apply_image_buffer_surface_with_offset (&icon->label, pCairoContext,
+						- (icon->label.iWidth + my_iParaboleTextGap),
+						(-icon->fHeight * icon->fScale - icon->label.iHeight)/2,
+						fAlpha);
 				}
 			}
-			if (pDock->fFoldingFactor != 0)
+			/**if (pDock->fFoldingFactor != 0)
 				cairo_paint_with_alpha (pCairoContext, (1 - pDock->fFoldingFactor) * (1 - pDock->fFoldingFactor));
 			else
-				cairo_paint (pCairoContext);
+				cairo_paint (pCairoContext);*/
 			
 			cairo_restore (pCairoContext);
 		}
@@ -416,12 +437,12 @@ static void cd_rendering_render_parabole (cairo_t *pCairoContext, CairoDock *pDo
 
 static double cd_rendering_project_cursor_on_curve_x (double x0, double y0, double lambda, double alpha)
 {
-	//cd_debug ("%s (%.2f;%.2f)\n", __func__, x0, y0);
+	//cd_debug ("%s (%.2f;%.2f)", __func__, x0, y0);
 	if (y0 < 0)
 		return 0;
 	double xM, yM;  // M se balade sur la courbe.
 	double x_inf = 0, x_max = fCurveInv (y0, lambda, alpha), x_sup = x_max;  // bornes de l'intervalle de xM.
-	double nx, ny=1;  // vecteur normal a la courbe.
+	double nx;  // vecteur normal a la courbe.
 	double k;  // parametre de la droite normale a la courbe.
 	double y_;
 	do
@@ -464,7 +485,7 @@ static double cd_rendering_project_cursor_on_curve_y (double x0, double y0, doub
 		y_sup = y0;
 		y_inf = (x0 > 0 ? fCurve (x0, lambda, alpha) : 0);
 	}
-	double nx, ny=1;  // verteur normal a la courbe.
+	double nx;  // verteur normal a la courbe.
 	double k;  // parametre de la droite normale a la courbe.
 	double y_;
 	//cd_debug ("  yM € [%.2f ; %.2f]", y_inf, y_sup);
@@ -491,7 +512,7 @@ static double cd_rendering_project_cursor_on_curve_y (double x0, double y0, doub
 	while (y_sup - y_inf > 1);
 	return (y_inf + y_sup) / 2;
 }
-static double cd_rendering_project_cursor_on_curve (double x0, double y0, double lambda, double alpha, double *fXOnCurve, double *fYOnCurve)
+static void cd_rendering_project_cursor_on_curve (double x0, double y0, double lambda, double alpha, double *fXOnCurve, double *fYOnCurve)
 {
 	double xM, yM;
 	if (my_fParaboleRatio > 1)
@@ -586,10 +607,9 @@ Icon *cd_rendering_calculate_icons_parabole (CairoDock *pDock)
 	
 	
 	//\____________________ On en deduit les position/etirements/alpha des icones.
-	Icon* icon, *prev_icon;
+	Icon* icon;
 	GList* ic;
-	double ds, s=0;
-	double x = 0, y = 0, theta = 0;
+	double s = 0;
 	double x_ = 0, y_ = 0, theta_ = G_PI/2 - atan (fCurve_(0, lambda, alpha));
 	if (pDock->fAlign == 1)
 		theta_ = -theta_;
@@ -598,8 +618,8 @@ Icon *cd_rendering_calculate_icons_parabole (CairoDock *pDock)
 	GList *pFirstDrawnElement = pDock->icons;
 	ic = pFirstDrawnElement;
 	Icon *pFirstIcon = pFirstDrawnElement->data;
-	double fOrientationMax = G_PI/2 - atan (my_fParaboleRatio * my_fParaboleCurvature);
-	double fTopMargin = pDock->iMaxLabelWidth * sin (fOrientationMax);
+	// double fOrientationMax = G_PI/2 - atan (my_fParaboleRatio * my_fParaboleCurvature);
+	// double fTopMargin = pDock->iMaxLabelWidth * sin (fOrientationMax);
 	gboolean bHorizontal = pDock->container.bIsHorizontal;
 	do
 	{
@@ -607,7 +627,6 @@ Icon *cd_rendering_calculate_icons_parabole (CairoDock *pDock)
 		
 		if (ic != pFirstDrawnElement)  // on ancre la 1ere icone a l'origine.
 		{
-			ds = icon->fX - prev_icon->fX;
 			s = icon->fX - pFirstIcon->fX;
 			//g_print (" %s : %.2f + %.2f (x %.2f)\n", icon->cName, s, ds, icon->fScale);
 			y_ = cd_rendering_interpol (s, s_pReferenceParaboleS, s_pReferenceParaboleY);
@@ -636,11 +655,7 @@ Icon *cd_rendering_calculate_icons_parabole (CairoDock *pDock)
 		icon->fWidthFactor = 1.;
 		icon->fHeightFactor = 1.;
 		
-		x = x_;
-		y = y_;
 		//g_print (" %s : (%.2f ; %.2f)\n", icon->cName, x, y);
-		theta = theta_;
-		prev_icon = icon;
 		
 		ic = cairo_dock_get_next_element (ic, pDock->icons);
 	} while (ic != pFirstDrawnElement);
@@ -694,6 +709,7 @@ static void cd_rendering_render_parabole_opengl (CairoDock *pDock)
 	
 	glPushMatrix ();
 	double fDockMagnitude = 1;  // pour le rendu des icones, on utilise la magnitude max.
+	double fAlpha = (1 - pDock->fFoldingFactor) * (1 - pDock->fFoldingFactor);
 	gboolean bHorizontal = pDock->container.bIsHorizontal;
 	Icon *icon;
 	GList *ic = pFirstDrawnElement;
@@ -703,7 +719,7 @@ static void cd_rendering_render_parabole_opengl (CairoDock *pDock)
 		
 		cairo_dock_render_one_icon_opengl (icon, pDock, fDockMagnitude, FALSE);
 		
-		if (icon->iLabelTexture != 0)  // en opengl on dessine les etiquettes meme pendant le depliage.
+		if (icon->label.iTexture != 0)  // en opengl on dessine les etiquettes meme pendant le depliage.
 		{
 			glPushMatrix ();
 			cairo_dock_translate_on_icon_opengl (icon, CAIRO_CONTAINER (pDock), 1.);
@@ -715,20 +731,20 @@ static void cd_rendering_render_parabole_opengl (CairoDock *pDock)
 			_cairo_dock_enable_texture ();
 			///_cairo_dock_set_blend_over ();
 			_cairo_dock_set_blend_alpha ();
-			_cairo_dock_set_alpha ((1 - pDock->fFoldingFactor) * (1 - pDock->fFoldingFactor));
+			_cairo_dock_set_alpha (fAlpha);
 			
 			if (pDock->fAlign == 1)
 			{
 				if (bHorizontal)
 				{
-					glTranslatef (icon->fWidth * icon->fScale/2 + my_iParaboleTextGap + icon->iTextWidth/2,
+					glTranslatef (icon->fWidth * icon->fScale/2 + my_iParaboleTextGap + icon->label.iWidth/2,
 						0.,
 						0.);
 				}
 				else
 				{
 					glRotatef (-90., 0., 0., 1.);
-					glTranslatef (icon->fWidth * icon->fScale/2 + my_iParaboleTextGap + icon->iTextWidth/2,
+					glTranslatef (icon->fWidth * icon->fScale/2 + my_iParaboleTextGap + icon->label.iWidth/2,
 						0.,
 						0.);
 				}
@@ -737,21 +753,22 @@ static void cd_rendering_render_parabole_opengl (CairoDock *pDock)
 			{
 				if (bHorizontal)
 				{
-					glTranslatef (- (icon->fWidth * icon->fScale/2 + my_iParaboleTextGap + icon->iTextWidth/2),
+					glTranslatef (- (icon->fWidth * icon->fScale/2 + my_iParaboleTextGap + icon->label.iWidth/2),
 						0.,
 						0.);
 				}
 				else
 				{
 					glRotatef (-90., 0., 0., 1.);
-					glTranslatef (- (icon->fWidth * icon->fScale/2 + my_iParaboleTextGap + icon->iTextWidth/2),
+					glTranslatef (- (icon->fWidth * icon->fScale/2 + my_iParaboleTextGap + icon->label.iWidth/2),
 						0.,
 						0.);
 				}
 			}
-			cairo_dock_apply_texture_at_size (icon->iLabelTexture,
-				icon->iTextWidth,
-				icon->iTextHeight);
+			/**cairo_dock_apply_texture_at_size (icon->iLabelTexture,
+				icon->label.iWidth,
+				icon->label.iHeight);*/
+			cairo_dock_apply_image_buffer_texture (&icon->label);
 			
 			_cairo_dock_disable_texture ();
 			glPopMatrix ();
