@@ -96,12 +96,11 @@ static gboolean _display_result (CDSharedMemory *pSharedMemory)
 	}
 	cairo_dock_discard_task (myData.pInfoTask);
 	myData.pInfoTask = NULL;
+
+	return FALSE;
 }
 static void _cd_dustbin_show_info (GtkMenuItem *menu_item, CairoDockModuleInstance *myApplet)
 {
-	gsize iSize, iNbFiles;
-	gint iCancel = 0;
-	
 	if (myData.pInfoDialog != NULL)
 	{
 		cairo_dock_dialog_unreference (myData.pInfoDialog);
@@ -132,18 +131,12 @@ static void _cd_dustbin_show_info (GtkMenuItem *menu_item, CairoDockModuleInstan
 }
 
 CD_APPLET_ON_BUILD_MENU_BEGIN
-	GtkWidget *pModuleSubMenu = CD_APPLET_CREATE_MY_SUB_MENU ();
-	
-	// Main Menu
 	CD_APPLET_ADD_IN_MENU_WITH_STOCK_AND_DATA (D_("Show Trash (click)"), GTK_STOCK_OPEN, _cd_dustbin_show_trash, CD_APPLET_MY_MENU, NULL);
 	gchar *cLabel = g_strdup_printf ("%s (%s)", D_("Empty Trash"), D_("middle-click"));
 	CD_APPLET_ADD_IN_MENU_WITH_STOCK_AND_DATA (cLabel, GTK_STOCK_DELETE, _cd_dustbin_delete_trash, CD_APPLET_MY_MENU, NULL);
 	g_free (cLabel);
 	
 	CD_APPLET_ADD_IN_MENU_WITH_STOCK (D_("Display dustbins information"), GTK_STOCK_INFO, _cd_dustbin_show_info, CD_APPLET_MY_MENU);
-	
-	// Sub-Menu
-	CD_APPLET_ADD_ABOUT_IN_MENU (pModuleSubMenu);
 CD_APPLET_ON_BUILD_MENU_END
 
 
