@@ -53,7 +53,7 @@ gboolean init_vfs_backend (void)
 		g_free,
 		(GDestroyNotify) _vfs_backend_free_monitor_data);
 	
-	GVfs *vfs = g_vfs_get_default ();
+	g_vfs_get_default ();
 	//return (vfs != NULL && g_vfs_is_active (vfs));
 	return TRUE;
 }
@@ -74,25 +74,25 @@ static gchar *_cd_get_icon_path (GIcon *pIcon)
 	if (G_IS_THEMED_ICON (pIcon))
 	{
 		const gchar * const *cFileNames = g_themed_icon_get_names (G_THEMED_ICON (pIcon));
-		//cd_message ("icones possibles : %s\n", g_strjoinv (":", (gchar **) cFileNames));
+		//cd_message ("icones possibles : %s", g_strjoinv (":", (gchar **) cFileNames));
 		int i;
 		for (i = 0; cFileNames[i] != NULL && cIconPath == NULL; i ++)
 		{
-			//cd_message (" une icone possible est : %s\n", cFileNames[i]);
+			//cd_message (" une icone possible est : %s", cFileNames[i]);
 			cIconPath = cairo_dock_search_icon_s_path (cFileNames[i], CAIRO_DOCK_DEFAULT_ICON_SIZE);
-			//cd_message ("  chemin trouve : %s\n", cIconPath);
+			//cd_message ("  chemin trouve : %s", cIconPath);
 		}
 	}
 	else if (G_IS_FILE_ICON (pIcon))
 	{
 		GFile *pFile = g_file_icon_get_file (G_FILE_ICON (pIcon));
 		cIconPath = g_file_get_basename (pFile);
-		//cd_message (" file_icon => %s\n", cIconPath);
+		//cd_message (" file_icon => %s", cIconPath);
 	}
 	return cIconPath;
 }
 
-
+/*
 static void _cd_find_mount_from_volume_name (const gchar *cVolumeName, GMount **pFoundMount, gchar **cURI, gchar **cIconName)
 {
 	g_return_if_fail (cVolumeName != NULL);
@@ -117,8 +117,6 @@ static void _cd_find_mount_from_volume_name (const gchar *cVolumeName, GMount **
 		return ;
 	}
 	
-	GList *pIconList = NULL;
-	Icon *icon;
 	GFileInfo *pFileInfo;
 	do
 	{
@@ -168,7 +166,7 @@ static void _cd_find_mount_from_volume_name (const gchar *cVolumeName, GMount **
 	} while (TRUE);
 	//g_object_unref (pFileEnum);
 }
-
+*/
 static GDrive *_cd_find_drive_from_name (const gchar *cName)
 {
 	g_return_val_if_fail (cName != NULL, NULL);
@@ -413,7 +411,7 @@ void vfs_backend_get_file_info (const gchar *cBaseURI, gchar **cName, gchar **cU
 	cd_message ("cIconName : %s", *cIconName);
 	
 	//*iVolumeID = g_file_info_get_attribute_uint32 (pFileInfo, G_FILE_ATTRIBUTE_MOUNTABLE_UNIX_DEVICE);
-	//cd_message ("ID : %d\n", *iVolumeID);
+	//cd_message ("ID : %d", *iVolumeID);
 	//g_object_unref (pFileInfo);
 }
 
@@ -520,7 +518,7 @@ GList *vfs_backend_list_volumes (void)
 		}
 		else
 		{
-			cd_message (" + volume '%s'\n", g_volume_get_name  (pVolume));
+			cd_message (" + volume '%s'", g_volume_get_name  (pVolume));
 			pNewIcon = _cd_get_icon_for_volume (pVolume, NULL);
 			pIconsList = g_list_prepend (pIconsList, pNewIcon);
 		}
@@ -761,7 +759,7 @@ GList *vfs_backend_list_directory (const gchar *cBaseURI, CairoDockFMSortType iS
 		if (pRootIcon == NULL)
 		{
 			pRootIcon = cairo_dock_get_first_icon (pIconList);
-			cd_debug ("domage ! (%s:%s)\n", pRootIcon->cCommand, pRootIcon->cName);
+			cd_debug ("domage ! (%s:%s)", pRootIcon->cCommand, pRootIcon->cName);
 		}
 		icon = cairo_dock_create_dummy_launcher (g_strdup ("home"),
 			g_strdup (pRootIcon->cFileName),
@@ -904,11 +902,20 @@ gboolean vfs_backend_eject_drive (const gchar *cURI)
 	GDrive *pDrive = _cd_find_drive_from_name (cDriveName);
 	if (pDrive != NULL)
 	{
+		#if GLIB_CHECK_VERSION (2, 22, 0)
+		g_drive_eject_with_operation (pDrive,
+			G_MOUNT_UNMOUNT_NONE,
+			NULL,
+			NULL,
+			NULL,
+			NULL);
+		#else
 		g_drive_eject (pDrive,
 			G_MOUNT_UNMOUNT_NONE,
 			NULL,
 			NULL,
 			NULL);
+		#endif
 	}
 	//g_object_unref (pDrive);
 	//g_free (cDriveName);
@@ -930,9 +937,17 @@ static void _vfs_backend_mount_callback (gpointer pObject, GAsyncResult *res, gp
 		bSuccess = (g_file_mount_mountable_finish (G_FILE (pObject), res, &erreur) != NULL);
 		//bSuccess = (g_volume_mount_finish (G_VOLUME (pObject), res, &erreur));
 	else if (GPOINTER_TO_INT (data[1]) == 0)
+		#if GLIB_CHECK_VERSION (2, 22, 0)
+		bSuccess = g_mount_unmount_with_operation_finish (G_MOUNT (pObject), res, &erreur);
+		#else
 		bSuccess = g_mount_unmount_finish (G_MOUNT (pObject), res, &erreur);
+		#endif
 	else
+		#if GLIB_CHECK_VERSION (2, 22, 0)
+		bSuccess = g_mount_eject_with_operation_finish (G_MOUNT (pObject), res, &erreur);
+		#else
 		bSuccess = g_mount_eject_finish (G_MOUNT (pObject), res, &erreur);
+		#endif
 	if (erreur != NULL)
 	{
 		cd_warning ("gnome-integration : %s", erreur->message);
@@ -987,7 +1002,7 @@ void vfs_backend_unmount (const gchar *cURI, int iVolumeID, CairoDockFMMountCall
 	
 	gboolean bCanEject = g_mount_can_eject (pMount);
 	gboolean bCanUnmount = g_mount_can_unmount (pMount);
-	cd_message ("eject:%d / unmount:%d\n", bCanEject, bCanUnmount);
+	cd_message ("eject:%d / unmount:%d", bCanEject, bCanUnmount);
 	if (! bCanEject && ! bCanUnmount)
 	{
 		cd_warning ("can't unmount this volume (%s)", cURI);
@@ -1000,18 +1015,36 @@ void vfs_backend_unmount (const gchar *cURI, int iVolumeID, CairoDockFMMountCall
 	data[2] = g_mount_get_name (pMount);
 	data[3] = g_strdup (cURI);
 	data[4] = user_data;
-	if (bCanEject)
+		if (bCanEject)
+		#if GLIB_CHECK_VERSION (2, 22, 0)
+		g_mount_eject_with_operation (pMount,
+			G_MOUNT_UNMOUNT_NONE,
+			NULL,
+			NULL,
+			(GAsyncReadyCallback) _vfs_backend_mount_callback,
+			data);
+		#else
 		g_mount_eject (pMount,
 			G_MOUNT_UNMOUNT_NONE,
 			NULL,
 			(GAsyncReadyCallback) _vfs_backend_mount_callback,
 			data);
+		#endif
 	else
-		g_mount_unmount (pMount,
-			G_MOUNT_UNMOUNT_NONE ,
+		#if GLIB_CHECK_VERSION (2, 22, 0)
+		g_mount_unmount_with_operation (pMount,
+			G_MOUNT_UNMOUNT_NONE,
+			NULL,
 			NULL,
 			(GAsyncReadyCallback) _vfs_backend_mount_callback,
 			data);
+		#else
+		g_mount_unmount (pMount,
+			G_MOUNT_UNMOUNT_NONE,
+			NULL,
+			(GAsyncReadyCallback) _vfs_backend_mount_callback,
+			data);
+		#endif
 }
 
 
