@@ -42,12 +42,27 @@ static void _select_group (GtkMenuItem *menu_item, gpointer data)
 }
 static void _open_keyboard_properties (GtkMenuItem *menu_item, gpointer data)
 {
-	cairo_dock_launch_command ("gnome-keyboard-properties");
+	const gchar *cCommand = NULL;
+	gchar *cResult = cairo_dock_launch_command_sync ("which gnome-control-center");  // Gnome3
+	if (cResult != NULL && *cResult == '/')
+	{
+		cCommand = "gnome-control-center region";
+	}
+	else
+	{
+		g_free (cResult);
+		cResult = cairo_dock_launch_command_sync ("which gnome-keyboard-properties");  // Gnome2
+		if (cResult != NULL && *cResult == '/')
+			cCommand = "gnome-keyboard-properties";
+	}  /// TODO: handle other DE ...
+	g_free (cResult);
+	
+	if (cCommand)
+	{
+		cairo_dock_launch_command (cCommand);
+	}
 }
 CD_APPLET_ON_BUILD_MENU_BEGIN
-	GtkWidget *pSubMenu = CD_APPLET_CREATE_MY_SUB_MENU ();
-	
-	// Main Menu
 	XklEngine *pEngine = xkl_engine_get_instance (cairo_dock_get_Xdisplay ());  // singleton.
 	const gchar **pGroupNames = xkl_engine_get_groups_names (pEngine);
 	int i;
@@ -56,15 +71,20 @@ CD_APPLET_ON_BUILD_MENU_BEGIN
 		CD_APPLET_ADD_IN_MENU_WITH_DATA (pGroupNames[i], _select_group, CD_APPLET_MY_MENU, GINT_TO_POINTER (i));
 	}
 	
-	// Sub-Menu
-	if (pSubMenu == CD_APPLET_MY_MENU)
-		CD_APPLET_ADD_SEPARATOR_IN_MENU (CD_APPLET_MY_MENU);
 	if (g_iDesktopEnv == CAIRO_DOCK_GNOME)
-		CD_APPLET_ADD_IN_MENU_WITH_STOCK (D_("Keyboard preferences"), GTK_STOCK_PROPERTIES, _open_keyboard_properties, pSubMenu);
-	CD_APPLET_ADD_ABOUT_IN_MENU (pSubMenu);
+	{
+		CD_APPLET_ADD_SEPARATOR_IN_MENU (CD_APPLET_MY_MENU);
+		CD_APPLET_ADD_IN_MENU_WITH_STOCK (D_("Keyboard preferences"), GTK_STOCK_PROPERTIES, _open_keyboard_properties, CD_APPLET_MY_MENU);
+	}
 CD_APPLET_ON_BUILD_MENU_END
 
 
 CD_APPLET_ON_SCROLL_BEGIN
 	cd_xkbd_set_prev_next_group (CD_APPLET_SCROLL_UP ? +1 : -1);
 CD_APPLET_ON_SCROLL_END
+
+
+void cd_xkbd_on_keybinding_pull (const gchar *keystring, gpointer user_data)
+{
+	cd_xkbd_set_prev_next_group (+1);
+}
