@@ -42,13 +42,14 @@ static void cd_logout_hibernate (void);
 static void cd_logout_close_session (void);
 static void cd_logout_switch_to_user (const gchar *cUser);
 static void cd_logout_switch_to_guest (void);
-static gboolean cd_logout_switch_to_greeter (void);
+//static gboolean cd_logout_switch_to_greeter (void);
 
 static void _free_user (CDUser *pUser);
 static GList *cd_logout_get_users_list (void);
 
 static void _display_menu (void);
 
+#define CD_LOGOUT_MESSAGE_SEPARATOR " | "
 
   ////////////////////
  /// CAPABILITIES ///
@@ -335,7 +336,7 @@ static gboolean _timer (gpointer data)
 	}
 	else
 	{
-		cd_debug ("shutdown in %d minutes\n", (int) (myConfig.iShutdownTime - t_cur) / 60);
+		cd_debug ("shutdown in %d minutes", (int) (myConfig.iShutdownTime - t_cur) / 60);
 		CD_APPLET_SET_QUICK_INFO_ON_MY_ICON_PRINTF ("%dmn", (int) ceil ((double)(myConfig.iShutdownTime - t_cur) / 60.));
 		CD_APPLET_REDRAW_MY_ICON;
 		if (t_cur >= myConfig.iShutdownTime - 60)
@@ -388,7 +389,15 @@ void cd_logout_program_shutdown (void)
  /// REBOOT NEEDED ///
 /////////////////////
 
-static void _set_reboot_message (void)
+static const gchar * _get_default_message (void)
+{
+	if (myConfig.cDefaultLabel) // has another default name
+		return myConfig.cDefaultLabel;
+	else
+		return myApplet->pModule->pVisitCard->cTitle;
+}
+
+static gchar * _get_reboot_message (void)
 {
 	gchar *cMessage = NULL;
 	gsize length = 0;
@@ -401,73 +410,160 @@ static void _set_reboot_message (void)
 		int len = strlen (cMessage);
 		if (cMessage[len-1] == '\n')
 			cMessage[len-1] = '\0';
-		CD_APPLET_SET_NAME_FOR_MY_ICON (cMessage);
+	}
+
+	return (cMessage);
+}
+
+// it seems the file only contains a timestamp
+/* static const gchar * _get_logout_message (void) {}*/
+#define _get_logout_message() _("Your session needs to be restarted in order to update new configuration files.")
+
+// yes, it's not a good idea to reboot the computer before the end of the update ;)
+#define CD_LOGOUT_UPDATE_MESSAGE _("Please do that at the end of the update.")
+
+static void _notify_action_required (void)
+{
+	CD_APPLET_DEMANDS_ATTENTION ("pulse", 20);
+	cairo_dock_remove_dialog_if_any (myIcon);
+
+	gchar *cName;
+	if (/*myData.bLogoutNeeded && */myData.bRebootNeeded)
+	{
+		gchar *cTmpName = g_strdup (myIcon->cName); // Icon's name contains the message for the reboot and then for the logout
+		gchar *cTmpPtr = g_strrstr (cTmpName, CD_LOGOUT_MESSAGE_SEPARATOR);
+		if (cTmpPtr)
+			*cTmpPtr = '\0';
+		cName = g_strdup_printf ("%s\n%s", cTmpName, CD_LOGOUT_UPDATE_MESSAGE);
+		g_free (cTmpName);
 	}
 	else
+		cName = g_strdup_printf ("%s\n%s", myIcon->cName, CD_LOGOUT_UPDATE_MESSAGE);
+
+	cairo_dock_show_temporary_dialog_with_icon (cName, myIcon, myContainer, 15e3, "same icon");
+
+	g_free (cName);
+
+	gint iIconSize = MAX (myIcon->iImageWidth, myIcon->iImageHeight);
+	gchar *cImagePath = _check_icon (myConfig.cEmblemPath,
+		(myConfig.iRebootNeededImage == CD_DISPLAY_EMBLEM ?
+				iIconSize / 2 :
+				iIconSize));
+	if (! cImagePath)
 	{
-		if (myConfig.cDefaultLabel) // has another default name
-			CD_APPLET_SET_NAME_FOR_MY_ICON (myConfig.cDefaultLabel);
-		else
-			CD_APPLET_SET_NAME_FOR_MY_ICON (myApplet->pModule->pVisitCard->cTitle);
+		cImagePath = _check_icon (GTK_STOCK_REFRESH,
+			(myConfig.iRebootNeededImage == CD_DISPLAY_EMBLEM ?
+				iIconSize / 2 :
+				iIconSize));
+		if (! cImagePath)
+			cImagePath = g_strdup (MY_APPLET_SHARE_DATA_DIR"/system-restart.svg");
 	}
-	g_free (cMessage);
+
+	if (myConfig.iRebootNeededImage == CD_DISPLAY_EMBLEM)
+		CD_APPLET_PRINT_OVERLAY_ON_MY_ICON (cImagePath, CAIRO_OVERLAY_UPPER_RIGHT);
+	else
+		CD_APPLET_SET_IMAGE_ON_MY_ICON (cImagePath);
+	g_free (cImagePath);
 }
-void cd_logout_check_reboot_required (CairoDockFMEventType iEventType, const gchar *cURI, gpointer data)
+
+static void _stop_notify_action_required (void)
 {
+	 // should not happen... mainly for the tests.
+	cairo_dock_remove_dialog_if_any (myIcon);
+	if (myConfig.iRebootNeededImage == CD_DISPLAY_EMBLEM)
+		CD_APPLET_PRINT_OVERLAY_ON_MY_ICON (NULL, CAIRO_OVERLAY_UPPER_RIGHT);
+	else
+		CD_APPLET_SET_IMAGE_ON_MY_ICON (myConfig.cDefaultIcon);
+	CD_APPLET_STOP_DEMANDING_ATTENTION;
+}
+
+// complete the string with the right message
+static GString * _get_message (CDActionsNeededEnum iAction)
+{
+	GString *sMessage = g_string_new ("");
+	if (iAction == CD_REBOOT_NEEDED || myData.bRebootNeeded) // reboot is now needed or reboot is still needed
+	{
+		myData.bRebootNeeded = TRUE;
+		gchar *cRebootMessage = _get_reboot_message ();
+		if (cRebootMessage && *cRebootMessage != '\0')
+			g_string_printf (sMessage, "%s", cRebootMessage);
+		g_free (cRebootMessage);
+	}
+/*
+	if (iAction == CD_LOGOUT_NEEDED || myData.bLogoutNeeded)
+	{
+		myData.bLogoutNeeded = TRUE;
+		g_string_append_printf (sMessage, "%s%s",
+			sMessage->len == 0 ? "" : CD_LOGOUT_MESSAGE_SEPARATOR,
+			_get_logout_message ());
+	}*/
+
+	return sMessage;
+}
+
+void cd_logout_check_reboot_logout_required (CairoDockFMEventType iEventType, const gchar *cURI, CDActionsNeededEnum iAction)
+{
+	// maybe check if logout or reboot message is already available  => merge both messages
+	GString *sMessage = NULL;
+
 	switch (iEventType)
 	{
-		case CAIRO_DOCK_FILE_MODIFIED:  // new message
-			_set_reboot_message ();
+		case CAIRO_DOCK_FILE_MODIFIED: // new message
+		case CAIRO_DOCK_FILE_CREATED:  // reboot/logout required
+			sMessage = _get_message (iAction);
 		break;
 		
-		case CAIRO_DOCK_FILE_DELETED:  // reboot no more required (shouldn't happen)
-			myData.bRebootNeeded = FALSE;
-			if (myConfig.cDefaultLabel) // has another default name
-				CD_APPLET_SET_NAME_FOR_MY_ICON (myConfig.cDefaultLabel);
-			else
-				CD_APPLET_SET_NAME_FOR_MY_ICON (myApplet->pModule->pVisitCard->cTitle);
-			CD_APPLET_STOP_DEMANDING_ATTENTION;
-		break;
-		
-		case CAIRO_DOCK_FILE_CREATED:  // reboot required
-			myData.bRebootNeeded = TRUE;
-			_set_reboot_message ();
-			CD_APPLET_DEMANDS_ATTENTION ("pulse", 20);
-			cairo_dock_show_temporary_dialog_with_icon (myIcon->cName, myIcon, myContainer, 5e3, "same icon");
-
-			gint iIconSize = MAX (myIcon->iImageWidth, myIcon->iImageHeight);
-			gchar *cImagePath = _check_icon (myConfig.cEmblemPath,
-				(myConfig.iRebootNeededImage == CD_DISPLAY_EMBLEM ?
-						iIconSize / 2 :
-						iIconSize));
-			if (! cImagePath)
-			{
-				cImagePath = _check_icon (GTK_STOCK_REFRESH,
-					(myConfig.iRebootNeededImage == CD_DISPLAY_EMBLEM ?
-						iIconSize / 2 :
-						iIconSize));
-				if (! cImagePath)
-					cImagePath = g_strdup (MY_APPLET_SHARE_DATA_DIR"/system-restart.svg");
-			}
-
-			if (myConfig.iRebootNeededImage == CD_DISPLAY_EMBLEM)
-				CD_APPLET_PRINT_OVERLAY_ON_MY_ICON (cImagePath, CAIRO_OVERLAY_UPPER_RIGHT);
-			else
-				CD_APPLET_SET_IMAGE_ON_MY_ICON (cImagePath);
-			g_free (cImagePath);
+		case CAIRO_DOCK_FILE_DELETED:  // reboot/logout no more required (shouldn't happen)
+			if (iAction == CD_REBOOT_NEEDED)
+				myData.bRebootNeeded = FALSE;
+			/*else if (iAction == CD_LOGOUT_NEEDED)
+				myData.bLogoutNeeded = FALSE;*/
+			sMessage = _get_message (CD_REMOVE_MESSAGE);
+			if (! myData.bRebootNeeded/* && ! myData.bLogoutNeeded*/)
+				_stop_notify_action_required (); // default icon
 		break;
 		default:
 		break;
 	}
+	if (sMessage && sMessage->len > 0)
+		CD_APPLET_SET_NAME_FOR_MY_ICON (sMessage->str);
+	else
+		CD_APPLET_SET_NAME_FOR_MY_ICON (_get_default_message ());
+	if (iEventType == CAIRO_DOCK_FILE_CREATED)
+		_notify_action_required ();
+
+	g_string_free (sMessage, TRUE);
 }
 
 void cd_logout_check_reboot_required_init (void)
 {
 	if (g_file_test (CD_REBOOT_NEEDED_FILE, G_FILE_TEST_EXISTS))
 	{
-		cd_logout_check_reboot_required (CAIRO_DOCK_FILE_CREATED, CD_REBOOT_NEEDED_FILE, NULL);
+		cd_logout_check_reboot_logout_required (CAIRO_DOCK_FILE_CREATED, CD_REBOOT_NEEDED_FILE, CD_REBOOT_NEEDED);
 	}
 }
+/*
+const gchar *cd_logout_get_session_migration_filename (void)
+{
+	if (! myData.cSessionMigrationFileName)
+	{
+		// according to this bzr branch lp:session-migration
+		gchar *cSessionBaseName = g_strdup_printf ("session_migration-%s", g_getenv("DESKTOP_SESSION"));
+		myData.cSessionMigrationFileName = g_build_filename (g_get_user_data_dir (), cSessionBaseName, NULL); // ~/.local/share/session_migration-cairo-dock
+		g_free (cSessionBaseName);
+	}
+
+	return myData.cSessionMigrationFileName;
+}
+
+void cd_logout_check_logout_required_init (void)
+{
+	const gchar *cFileName = cd_logout_get_session_migration_filename ();
+	if (g_file_test (cFileName, G_FILE_TEST_EXISTS))
+	{
+		cd_logout_check_reboot_logout_required (CAIRO_DOCK_FILE_CREATED, cFileName, CD_LOGOUT_NEEDED);
+	}
+}*/
 
 
   ///////////////
@@ -690,7 +786,7 @@ static void cd_logout_switch_to_guest (void)
 		g_object_unref (pProxy);
 	}
 }
-
+/*
 static gboolean cd_logout_switch_to_greeter (void)  // not really sure how to use it.
 {
 	const gchar *seat = g_getenv ("XDG_SEAT_PATH");
@@ -715,7 +811,7 @@ static gboolean cd_logout_switch_to_greeter (void)  // not really sure how to us
 	g_object_unref (pProxy);
 	return TRUE;
 }
-
+*/
 
   //////////////////
  /// USERS LIST ///
@@ -750,7 +846,6 @@ static GList* _get_users_list_fallback (void)
 	gchar **cUserProps;
 	CDUser *pUser;
 	char *str;
-	int uid, gid;
 	int i;
 	for (i = 0; cUsers[i] != NULL; i ++)
 	{
