@@ -36,12 +36,12 @@
 	pMailAccount->icon = pIcon;
 
 // Translation Hack:
-const char *strings_to_translate[20] = {N_("Server address:"), N_("myLogin"), N_("myHost"), N_("Username:"), N_("Password:"), N_("The password will be crypted."), N_("Port:"), N_("Enter 0 to use the default port. Default ports are 110 for POP3 or APOP and 995 for POP3S."), N_("Enter 0 to use the default port. Default ports are 143 for IMAP4 and 993 for IMAP4 over SSL."), N_("Use a secure connection (SSL)"), N_("Refresh time:"), N_("In minutes."), N_("Specific mail application"), N_("Leave empty to use the default mail application."), N_("Directory on server:"), N_("Path of mbox file:"), N_("Path to Mail directory:"), N_("Address of feed:"), N_("Remove this account"), N_("Don't forget to enable IMAP (or POP) service from settings of your mail account.")};
+const char *strings_to_translate[20] = {N_("Server address:"), N_("myHost"), N_("Username:"), N_("Password:"), N_("The password will be crypted."), N_("Port:"), N_("Enter 0 to use the default port. Default ports are 110 for POP3 or APOP and 995 for POP3S."), N_("Enter 0 to use the default port. Default ports are 143 for IMAP4 and 993 for IMAP4 over SSL."), N_("Use a secure connection (SSL)"), N_("Refresh time:"), N_("In minutes."), N_("Specific mail application"), N_("Leave empty to use the default mail application."), N_("Directory on server:"), N_("Path of mbox file:"), N_("Path to Mail directory:"), N_("Address of feed:"), N_("Remove this account"), N_("Don't forget to enable IMAP (or POP) service from settings of your mail account.")};
 
 // Default parameters (to not copy these parameters each time)
 void _add_default_create_params( GKeyFile *pKeyFile, const gchar *pMailAccountName )
 {
-	g_key_file_set_string (pKeyFile, pMailAccountName, "username", N_("myLogin"));
+	g_key_file_set_string (pKeyFile, pMailAccountName, "username", pMailAccountName); // most of the time, the name of the account is the username
 	g_key_file_set_comment (pKeyFile, pMailAccountName, "username", "s0 Username:\n{Don't forget to enable IMAP (or POP) service from settings of your mail account.}", NULL);
 
 	g_key_file_set_string (pKeyFile, pMailAccountName, "password", "");
@@ -67,8 +67,7 @@ void _retrieve_user_password (CDMailAccount *mailaccount, GKeyFile *pKeyFile, co
 		gchar *encryptedPassword = CD_CONFIG_GET_STRING (mailbox_name, "password");
 		cairo_dock_decrypt_string( encryptedPassword,  &(mailaccount->password) );
 
-		if( encryptedPassword )
-			g_free(encryptedPassword);
+		g_free (encryptedPassword);
 	}
 }
 
@@ -97,14 +96,7 @@ void cd_mail_retrieve_pop3_params (CDMailAccount *mailaccount, GKeyFile *pKeyFil
 
 	mailaccount->driver = POP3_STORAGE;
 	mailaccount->storage = mailstorage_new(NULL);
-	mailaccount->folder = NULL;
-	mailaccount->server = NULL;
-	mailaccount->port = 0;
-	mailaccount->connection_type = CONNECTION_TYPE_PLAIN;
-	mailaccount->user = NULL;
-	mailaccount->password = NULL;
 	mailaccount->auth_type = POP3_AUTH_TYPE_TRY_APOP;
-	mailaccount->path = NULL;
 	
 	if (g_key_file_has_key (pKeyFile, mailbox_name, "host", NULL))
 	{
@@ -113,7 +105,10 @@ void cd_mail_retrieve_pop3_params (CDMailAccount *mailaccount, GKeyFile *pKeyFil
 
 	_retrieve_user_password( mailaccount, pKeyFile, mailbox_name );
 
-	mailaccount->connection_type = CD_CONFIG_GET_BOOLEAN_WITH_DEFAULT (mailbox_name, "use secure connection", FALSE)?CONNECTION_TYPE_TLS:CONNECTION_TYPE_PLAIN;
+	mailaccount->connection_type = CD_CONFIG_GET_BOOLEAN_WITH_DEFAULT (
+		mailbox_name, "use secure connection", FALSE)
+		? CONNECTION_TYPE_TLS
+		: CONNECTION_TYPE_PLAIN;
 	mailaccount->port = CD_CONFIG_GET_INTEGER_WITH_DEFAULT (mailbox_name, "port", 0);
 }
 
@@ -146,14 +141,7 @@ void cd_mail_retrieve_imap_params (CDMailAccount *mailaccount, GKeyFile *pKeyFil
 
 	mailaccount->driver = IMAP_STORAGE;
 	mailaccount->storage = mailstorage_new(NULL);
-	mailaccount->folder = NULL;
-	mailaccount->server = NULL;
-	mailaccount->port = 0;
-	mailaccount->connection_type = CONNECTION_TYPE_PLAIN;
-	mailaccount->user = NULL;
-	mailaccount->password = NULL;
 	mailaccount->auth_type = IMAP_AUTH_TYPE_PLAIN;
-	mailaccount->path = g_strdup("/");
 	
 	if (g_key_file_has_key (pKeyFile, mailbox_name, "host", NULL))
 	{
@@ -164,14 +152,17 @@ void cd_mail_retrieve_imap_params (CDMailAccount *mailaccount, GKeyFile *pKeyFil
 
 	mailaccount->port = CD_CONFIG_GET_INTEGER_WITH_DEFAULT (mailbox_name, "port", 0);
 
-	mailaccount->connection_type = CD_CONFIG_GET_BOOLEAN_WITH_DEFAULT (mailbox_name, "use secure connection", FALSE)?CONNECTION_TYPE_TLS:CONNECTION_TYPE_PLAIN;
+	mailaccount->connection_type = CD_CONFIG_GET_BOOLEAN_WITH_DEFAULT (
+		mailbox_name, "use secure connection", FALSE)
+		? CONNECTION_TYPE_TLS
+		: CONNECTION_TYPE_PLAIN;
 
 	/* CONNECTION_TYPE_TLS ? CONNECTION_TYPE_STARTTLS ? */
 
 	if (g_key_file_has_key (pKeyFile, mailbox_name, "server_directory", NULL))
-	{
 		mailaccount->path = CD_CONFIG_GET_STRING (mailbox_name, "server_directory");
-	}
+	if (mailaccount->path == NULL)
+		mailaccount->path = g_strdup("/");
 }
 
 void cd_mail_create_mbox_params( GKeyFile *pKeyFile, const gchar *pMailAccountName )
@@ -198,12 +189,7 @@ void cd_mail_retrieve_mbox_params (CDMailAccount *mailaccount, GKeyFile *pKeyFil
 
 	mailaccount->driver = MBOX_STORAGE;
 	mailaccount->storage = mailstorage_new(NULL);
-	mailaccount->folder = NULL;
-	mailaccount->server = NULL;
-	mailaccount->port = 0;
 	mailaccount->connection_type = CONNECTION_TYPE_PLAIN;
-	mailaccount->user = NULL;
-	mailaccount->password = NULL;
 	mailaccount->auth_type = POP3_AUTH_TYPE_PLAIN;
 
 	if (g_key_file_has_key (pKeyFile, mailbox_name, "filename", NULL))
@@ -233,12 +219,7 @@ void cd_mail_retrieve_mh_params (CDMailAccount *mailaccount, GKeyFile *pKeyFile,
 
 	mailaccount->driver = MH_STORAGE;
 	mailaccount->storage = mailstorage_new(NULL);
-	mailaccount->folder = NULL;
-	mailaccount->server = NULL;
-	mailaccount->port = 0;
 	mailaccount->connection_type = CONNECTION_TYPE_PLAIN;
-	mailaccount->user = NULL;
-	mailaccount->password = NULL;
 	mailaccount->auth_type = POP3_AUTH_TYPE_PLAIN;
 	mailaccount->path = g_strdup("/");
 }
@@ -267,19 +248,13 @@ void cd_mail_retrieve_maildir_params (CDMailAccount *mailaccount, GKeyFile *pKey
 
 	mailaccount->driver = MAILDIR_STORAGE;
 	mailaccount->storage = mailstorage_new(NULL);
-	mailaccount->folder = NULL;
-	mailaccount->server = NULL;
-	mailaccount->port = 0;
 	mailaccount->connection_type = CONNECTION_TYPE_PLAIN;
-	mailaccount->user = NULL;
-	mailaccount->password = NULL;
 	mailaccount->auth_type = POP3_AUTH_TYPE_PLAIN;
-	mailaccount->path = g_strdup("/");
 
 	if (g_key_file_has_key (pKeyFile, mailbox_name, "path", NULL))
-	{
 		mailaccount->path = CD_CONFIG_GET_STRING (mailbox_name, "path");
-	}
+	if (mailaccount->path == NULL)
+		mailaccount->path = g_strdup("/");
 	//{"path", "mtime", "interval", NULL, NULL, NULL, NULL}
 }
 
@@ -308,14 +283,9 @@ void cd_mail_retrieve_feed_params (CDMailAccount *mailaccount, GKeyFile *pKeyFil
 
 	mailaccount->driver = FEED_STORAGE;
 	mailaccount->storage = mailstorage_new(NULL);
-	mailaccount->folder = NULL;
-	mailaccount->server = NULL;
 	mailaccount->port = 443;
 	mailaccount->connection_type = CONNECTION_TYPE_PLAIN;
-	mailaccount->user = NULL;
-	mailaccount->password = NULL;
 	mailaccount->auth_type = POP3_AUTH_TYPE_PLAIN;
-	mailaccount->path = NULL;
 	
 	if (g_key_file_has_key (pKeyFile, mailbox_name, "path", NULL))
 	{
@@ -323,7 +293,7 @@ void cd_mail_retrieve_feed_params (CDMailAccount *mailaccount, GKeyFile *pKeyFil
 	}
 }
 
-	//  Some servers are pre-configured  =>  \\
+	//  Some servers are pre-configured
 
 void cd_mail_create_gmail_params( GKeyFile *pKeyFile, const gchar *pMailAccountName )
 {
@@ -338,19 +308,14 @@ void cd_mail_retrieve_gmail_params (CDMailAccount *mailaccount, GKeyFile *pKeyFi
 	if( !mailaccount || !pKeyFile || !mailbox_name )
 		return;
 
-	gboolean bFlushConfFileNeeded = FALSE;
-
 #if (1 || __WORDSIZE == 64 )  // RSS authentification seems to have changed, and doesn't work anymore here :-/ so use IMAP by default
 /* in 64bit libetpan crashes with RSS, so use the IMAP feature of GMail
  * instead of RSS. */
 	mailaccount->driver = IMAP_STORAGE;
 	mailaccount->storage = mailstorage_new(NULL);
-	mailaccount->folder = NULL;
 	mailaccount->server = g_strdup("imap.gmail.com");
 	mailaccount->port = 993;
 	mailaccount->connection_type = CONNECTION_TYPE_TLS;
-	mailaccount->user = NULL;
-	mailaccount->password = NULL;
 	mailaccount->auth_type = IMAP_AUTH_TYPE_PLAIN;
 	mailaccount->path = g_strdup("Inbox");
 	
@@ -358,14 +323,9 @@ void cd_mail_retrieve_gmail_params (CDMailAccount *mailaccount, GKeyFile *pKeyFi
 #else
 	mailaccount->driver = FEED_STORAGE;
 	mailaccount->storage = mailstorage_new(NULL);
-	mailaccount->folder = NULL;
-	mailaccount->server = NULL;
 	mailaccount->port = 443;
 	mailaccount->connection_type = CONNECTION_TYPE_STARTTLS;
-	mailaccount->user = NULL;
-	mailaccount->password = NULL;
 	mailaccount->auth_type = POP3_AUTH_TYPE_PLAIN;
-	mailaccount->path = NULL;
 	
 	if (g_key_file_has_key (pKeyFile, mailbox_name, "username", NULL))
 	{
@@ -422,16 +382,11 @@ void cd_mail_retrieve_yahoo_params (CDMailAccount *mailaccount, GKeyFile *pKeyFi
 	if( !mailaccount || !pKeyFile || !mailbox_name )
 		return;
 
-	gboolean bFlushConfFileNeeded = FALSE;
-
 	mailaccount->driver = IMAP_STORAGE;
 	mailaccount->storage = mailstorage_new(NULL);
-	mailaccount->folder = NULL;
 	mailaccount->server = g_strdup("imap.mail.yahoo.com");
 	mailaccount->port = 993;
 	mailaccount->connection_type = CONNECTION_TYPE_TLS;
-	mailaccount->user = NULL;
-	mailaccount->password = NULL;
 	mailaccount->auth_type = IMAP_AUTH_TYPE_PLAIN;
 	mailaccount->path = g_strdup("Inbox");
 	
@@ -451,18 +406,12 @@ void cd_mail_retrieve_hotmail_params (CDMailAccount *mailaccount, GKeyFile *pKey
 	if( !mailaccount || !pKeyFile || !mailbox_name )
 		return;
 
-	gboolean bFlushConfFileNeeded = FALSE;
-
 	mailaccount->driver = POP3_STORAGE;
 	mailaccount->storage = mailstorage_new(NULL);
-	mailaccount->folder = NULL;
 	mailaccount->server = g_strdup("pop3.live.com");
 	mailaccount->port = 995;
 	mailaccount->connection_type = CONNECTION_TYPE_TLS;
-	mailaccount->user = NULL;
-	mailaccount->password = NULL;
 	mailaccount->auth_type = POP3_AUTH_TYPE_TRY_APOP;
-	mailaccount->path = NULL;
 
 	_retrieve_user_password( mailaccount, pKeyFile, mailbox_name );
 }
@@ -480,16 +429,11 @@ void cd_mail_retrieve_free_params (CDMailAccount *mailaccount, GKeyFile *pKeyFil
 	if( !mailaccount || !pKeyFile || !mailbox_name )
 		return;
 
-	gboolean bFlushConfFileNeeded = FALSE;
-
 	mailaccount->driver = IMAP_STORAGE;
 	mailaccount->storage = mailstorage_new(NULL);
-	mailaccount->folder = NULL;
 	mailaccount->server = g_strdup("imap.free.fr");
 	mailaccount->port = 143;
 	mailaccount->connection_type = CONNECTION_TYPE_PLAIN;
-	mailaccount->user = NULL;
-	mailaccount->password = NULL;
 	mailaccount->auth_type = IMAP_AUTH_TYPE_PLAIN;
 	mailaccount->path = g_strdup("Inbox");
 	
@@ -509,16 +453,11 @@ void cd_mail_retrieve_neuf_params (CDMailAccount *mailaccount, GKeyFile *pKeyFil
 	if( !mailaccount || !pKeyFile || !mailbox_name )
 		return;
 
-	gboolean bFlushConfFileNeeded = FALSE;
-
 	mailaccount->driver = IMAP_STORAGE;
 	mailaccount->storage = mailstorage_new(NULL);
-	mailaccount->folder = NULL;
 	mailaccount->server = g_strdup("imap.neuf.fr");
 	mailaccount->port = 143;
 	mailaccount->connection_type = CONNECTION_TYPE_PLAIN;
-	mailaccount->user = NULL;
-	mailaccount->password = NULL;
 	mailaccount->auth_type = IMAP_AUTH_TYPE_PLAIN;
 	mailaccount->path = g_strdup("Inbox");
 	
@@ -538,16 +477,11 @@ void cd_mail_retrieve_sfr_params (CDMailAccount *mailaccount, GKeyFile *pKeyFile
 	if( !mailaccount || !pKeyFile || !mailbox_name )
 		return;
 
-	gboolean bFlushConfFileNeeded = FALSE;
-
 	mailaccount->driver = IMAP_STORAGE;
 	mailaccount->storage = mailstorage_new(NULL);
-	mailaccount->folder = NULL;
 	mailaccount->server = g_strdup("imap.sfr.fr");
 	mailaccount->port = 143;
 	mailaccount->connection_type = CONNECTION_TYPE_PLAIN;
-	mailaccount->user = NULL;
-	mailaccount->password = NULL;
 	mailaccount->auth_type = IMAP_AUTH_TYPE_PLAIN;
 	mailaccount->path = g_strdup("Inbox");
 	
@@ -567,16 +501,11 @@ void cd_mail_retrieve_orange_params (CDMailAccount *mailaccount, GKeyFile *pKeyF
 	if( !mailaccount || !pKeyFile || !mailbox_name )
 		return;
 
-	gboolean bFlushConfFileNeeded = FALSE;
-
 	mailaccount->driver = IMAP_STORAGE;
 	mailaccount->storage = mailstorage_new(NULL);
-	mailaccount->folder = NULL;
 	mailaccount->server = g_strdup("imap.orange.fr");
 	mailaccount->port = 143;
 	mailaccount->connection_type = CONNECTION_TYPE_PLAIN;
-	mailaccount->user = NULL;
-	mailaccount->password = NULL;
 	mailaccount->auth_type = IMAP_AUTH_TYPE_PLAIN;
 	mailaccount->path = g_strdup("Inbox");
 	
@@ -596,16 +525,11 @@ void cd_mail_retrieve_uclouvain_params (CDMailAccount *mailaccount, GKeyFile *pK
 	if( !mailaccount || !pKeyFile || !mailbox_name )
 		return;
 
-	gboolean bFlushConfFileNeeded = FALSE;
-
 	mailaccount->driver = IMAP_STORAGE;
 	mailaccount->storage = mailstorage_new(NULL);
-	mailaccount->folder = NULL;
 	mailaccount->server = g_strdup("mail.sipr.ucl.ac.be");
 	mailaccount->port = 993;
 	mailaccount->connection_type = CONNECTION_TYPE_TLS;
-	mailaccount->user = NULL;
-	mailaccount->password = NULL;
 	mailaccount->auth_type = IMAP_AUTH_TYPE_PLAIN;
 	mailaccount->path = g_strdup("Inbox");
 	
@@ -625,18 +549,12 @@ void cd_mail_retrieve_skynet_params (CDMailAccount *mailaccount, GKeyFile *pKeyF
 	if( !mailaccount || !pKeyFile || !mailbox_name )
 		return;
 
-	gboolean bFlushConfFileNeeded = FALSE;
-
 	mailaccount->driver = POP3_STORAGE;
 	mailaccount->storage = mailstorage_new(NULL);
-	mailaccount->folder = NULL;
 	mailaccount->server = g_strdup("pop.skynet.be");
 	mailaccount->port = 110;
 	mailaccount->connection_type = CONNECTION_TYPE_PLAIN;
-	mailaccount->user = NULL;
-	mailaccount->password = NULL;
 	mailaccount->auth_type = POP3_AUTH_TYPE_TRY_APOP;
-	mailaccount->path = NULL;
 
 	_retrieve_user_password( mailaccount, pKeyFile, mailbox_name );
 }
@@ -657,12 +575,13 @@ void cd_mail_init_accounts(CairoDockModuleInstance *myApplet)
 {
 	if (myData.pMailAccounts == NULL)
 		return ;
-	cd_debug ("%s (%d comptes)\n", __func__, myData.pMailAccounts->len);
+	cd_debug ("%s (%d comptes)", __func__, myData.pMailAccounts->len);
 	
 	//\_______________________ On initialise chaque compte.
 	CDMailAccount *pMailAccount;
 	GList *pIconList = NULL;
 	Icon *pIcon;
+	CairoContainer *pContainer;
 	int iNbIcons = 0;
 	int r;
 	gboolean bIsGettingMail = FALSE;
@@ -722,17 +641,19 @@ void cd_mail_init_accounts(CairoDockModuleInstance *myApplet)
 		if (myData.pMailAccounts->len == 1)  // 1 seul compte
 		{
 			pIcon = myIcon;
+			pContainer = myContainer;
 		}
 		else
 		{
 			_add_icon (pMailAccount);
+			pContainer = CD_APPLET_MY_ICONS_LIST_CONTAINER;
 		}
 		iNbIcons ++;
 		
 		//  if all is OK, then set a timeout for this mail account
 		if (r == MAIL_NO_ERROR)
 		{
-			CD_APPLET_SET_QUICK_INFO_ON_MY_ICON ("...");
+			cairo_dock_set_quick_info (pIcon, pContainer, "..."); // on the current icon
 			pMailAccount->pAccountMailTimer = cairo_dock_new_task (pMailAccount->timeout * 60,
 				(CairoDockGetDataAsyncFunc) cd_mail_get_folder_data,
 				(CairoDockUpdateSyncFunc) cd_mail_update_account_status,
@@ -760,7 +681,7 @@ void cd_mail_init_accounts(CairoDockModuleInstance *myApplet)
 	
 	//\_______________ On dessine l'icone principale initialement.
 	CD_APPLET_SET_IMAGE_ON_MY_ICON (myConfig.cNoMailUserImage);
-	if (bIsGettingMail)
+	if (bIsGettingMail && myData.iPrevNbUnreadMails == G_MAXUINT) // only at the init...
 		CD_APPLET_SET_QUICK_INFO_ON_MY_ICON ("...");
 }
 
