@@ -19,8 +19,6 @@
 
 #include <string.h>
 #include <math.h>
-#include <cairo-dock.h>
-#include <libetpan/libetpan.h>
 
 #include "cd-mail-applet-struct.h"
 #include "cd-mail-applet-accounts.h"
@@ -71,16 +69,19 @@ void cd_mail_get_folder_data (CDMailAccount *pMailAccount)  ///Extraire les donn
 	//if( MAIL_NO_ERROR == mailsession_unseen_number(pMailAccount->folder->fld_session, pMailAccount->name, &result_unseen) )
 	if( MAIL_NO_ERROR == mailfolder_status(pMailAccount->folder, &result_messages, &result_recent, &result_unseen) )
 	{
-		cd_debug ("mail : %d/%d/%d\n", result_messages, result_recent, result_unseen);
+		cd_debug ("mail : %d/%d/%d", result_messages, result_recent, result_unseen);
 		pMailAccount->iPrevNbUnseenMails = pMailAccount->iNbUnseenMails;
-		if( pMailAccount->iNbUnseenMails != (guint)result_unseen )  // nombre de messages non lus a change, on va supposer que cela provient soit de leur lecture, soit de leur arrivee, en excluant le cas ou arrivee = lecture, qui laisserait inchange le nombre de mails non lus.
+		CairoDockModuleInstance *myApplet = pMailAccount->pAppletInstance;
+		if (! myConfig.bShowMessageContent) // only if we want to show the message content...
+			pMailAccount->iNbUnseenMails = (guint)result_unseen;
+		else if ( pMailAccount->iNbUnseenMails != (guint)result_unseen )  // nombre de messages non lus a change, on va supposer que cela provient soit de leur lecture, soit de leur arrivee, en excluant le cas ou arrivee = lecture, qui laisserait inchange le nombre de mails non lus.
 		{
 			pMailAccount->iNbUnseenMails = (guint)result_unseen;
 			
 			// On recupere les messages non lus.
 			//if (myConfig.bShowMessageContent && pMailAccount->bInitialized)  // && pMailAccount->iNbUnseenMails > pMailAccount->iPrevNbUnseenMails
 			CairoDockModuleInstance *myApplet = pMailAccount->pAppletInstance;
-			cd_debug ("getting %d message body...\n", pMailAccount->iNbUnseenMails);
+			cd_debug ("getting %d message body...", pMailAccount->iNbUnseenMails);
 			g_list_foreach (pMailAccount->pUnseenMessageList, (GFunc) g_free, NULL);
 			g_list_free (pMailAccount->pUnseenMessageList);
 			g_list_foreach (pMailAccount->pUnseenMessageUid, (GFunc) g_free, NULL);
@@ -94,7 +95,6 @@ void cd_mail_get_folder_data (CDMailAccount *pMailAccount)  ///Extraire les donn
 			struct mailimf_single_fields *pSingleFields;
 			struct mailimf_from *pFrom;
 			struct mailimf_subject *pSubject;
-			struct mailimf_message_id *pUid;
 			struct mailimf_mailbox *pFromMailBox;
 			char *cRawBodyText, *cBodyText, *cFrom, *cSubject, *cMessage/**, *cUid*/;
 			size_t length;
@@ -142,6 +142,7 @@ void cd_mail_get_folder_data (CDMailAccount *pMailAccount)  ///Extraire les donn
 						if( (pFlags->fl_flags & MAIL_FLAG_NEW) == 0 &&
 							(pFlags->fl_flags & MAIL_FLAG_SEEN) != 0 )  // old unseen message.
 						{
+							cd_debug ("Not Fetching message number %d... (flag)", i);
 							continue;
 						}
 					}
@@ -230,7 +231,7 @@ void cd_mail_get_folder_data (CDMailAccount *pMailAccount)  ///Extraire les donn
 					{
 						cUid = pUid->mid_value;
 					}
-					cd_debug ("    cUid : %s\n", cUid);*/
+					cd_debug ("    cUid : %s", cUid);*/
 					
 					// finally, append the message to display to the list of unseen messages.
 					cMessage = g_strdup_printf ("From : %s\nSubject : %s\n%s", cFrom ? cFrom : D_("unknown"), cSubject ? cSubject : D_("no subject"), cBodyText ? cBodyText : "");
@@ -320,10 +321,12 @@ gboolean cd_mail_update_account_status( CDMailAccount *pUpdatedMailAccount )
 		}
 	}
 	cairo_destroy (pIconContext);
-	
-	//\_______________________ On met a jour l'icone principale.
-	if (pUpdatedMailAccount->iPrevNbUnseenMails != pUpdatedMailAccount->iNbUnseenMails &&
-	    !pUpdatedMailAccount->bError)  // des mails en plus ou en moins.
+
+	//\_______________________ We update the main icon
+	if ((pUpdatedMailAccount->iPrevNbUnseenMails != pUpdatedMailAccount->iNbUnseenMails// more or less mail(s)
+	    && !pUpdatedMailAccount->bError)
+	    || myData.iPrevNbUnreadMails == G_MAXUINT) // init => iPrevNbUnreadMails = G_MAXUINT
+	//  || strncmp (myIcon->cQuickInfo, "...", 3) == 0) // we can also check the cQuickInfo
 	{
 		myData.iPrevNbUnreadMails = myData.iNbUnreadMails;
 		myData.iNbUnreadMails += pUpdatedMailAccount->iNbUnseenMails - pUpdatedMailAccount->iPrevNbUnseenMails;
@@ -344,12 +347,10 @@ void cd_mail_mark_all_mails_as_read(CDMailAccount *pMailAccount)
 	/* Ensure the connection is alive */
 	mailfolder_connect(pMailAccount->folder);
 	GList *l, *l_Uid;
-	gchar *cMessage;
 	gchar *cMessageUid;
 	mailmessage *pMessage;
 	for (i = 1, l = pMailAccount->pUnseenMessageList, l_Uid = pMailAccount->pUnseenMessageUid; l != NULL && l_Uid != NULL; l = l->next, l_Uid = l_Uid->next, i++)
 	{
-		cMessage = l->data;
 		cMessageUid = l_Uid->data;
 		pMessage = NULL;
 		
@@ -389,7 +390,6 @@ void cd_mail_draw_main_icon (CairoDockModuleInstance *myApplet, gboolean bSignal
 	g_return_if_fail (myDrawContext != NULL);
 	cd_debug ("%s ()", __func__);
 	
-	gchar *cNewImage = NULL;
 	if (myData.iNbUnreadMails <= 0)  // plus de mail.
 	{
 		//Chargement de l'image "pas de mail"
