@@ -34,6 +34,8 @@ static DBusGProxyCall *s_pGetSongInfosCall = NULL;
 static DBusGProxyCall *s_pGetStatusCall = NULL;
 
 static void cd_mpris2_getSongInfos_async (void);
+static gboolean cd_mpris2_is_loop (void);
+static gboolean cd_mpris2_is_shuffle (void);
 
 /*
 Interface MediaPlayer2
@@ -97,6 +99,74 @@ Loop_Status Enum s
   /////////////////////////////////
  // Les Fonctions propres a MP. //
 /////////////////////////////////
+static gboolean s_bIsLoop = FALSE;
+static gboolean s_bGotLoopStatus = FALSE;
+static gboolean s_bIsShuffle = FALSE;
+static gboolean s_bGotShuffleStatus = FALSE;
+static gboolean s_bCanRaise = FALSE;
+static gboolean s_bGotCanRaise = FALSE;
+static gboolean s_bCanQuit = FALSE;
+static gboolean s_bGotCanQuit = FALSE;
+
+static gboolean get_loop_status (void)
+{
+	if (! s_bGotLoopStatus)
+	{
+		s_bIsLoop = cd_mpris2_is_loop ();
+		s_bGotLoopStatus = TRUE;
+	}
+	return s_bIsLoop;
+}
+
+static gboolean get_shuffle_status (void)
+{
+	if (! s_bGotShuffleStatus)
+	{
+		s_bIsShuffle = cd_mpris2_is_shuffle ();
+		s_bGotShuffleStatus = TRUE;
+	}
+	return s_bIsShuffle;
+}
+
+static gboolean _raise (void)
+{
+	if (! s_bGotCanRaise)
+	{
+		s_bCanRaise = cairo_dock_dbus_get_property_as_boolean (myData.dbus_proxy_shell, "org.mpris.MediaPlayer2", "CanRaise");
+		cd_debug ("s_bCanRaise : %d", s_bCanRaise);
+		s_bGotCanRaise = TRUE;
+	}
+	
+	if (s_bCanRaise)
+	{
+		cairo_dock_dbus_call (myData.dbus_proxy_shell, "Raise");
+		return TRUE;
+	}
+	else
+	{
+		return FALSE;
+	}
+}
+
+static gboolean _quit (void)
+{
+	if (! s_bGotCanQuit)
+	{
+		s_bCanQuit = cairo_dock_dbus_get_property_as_boolean (myData.dbus_proxy_shell, "org.mpris.MediaPlayer2", "CanQuit");
+		cd_debug ("s_bCanQuit : %d", s_bCanQuit);
+		s_bGotCanQuit = TRUE;
+	}
+	
+	if (s_bCanQuit)
+	{
+		cairo_dock_dbus_call (myData.dbus_proxy_shell, "Quit");
+		return TRUE;
+	}
+	else
+	{
+		return FALSE;
+	}
+}
 
 static MyPlayerStatus _extract_status (const gchar *cStatus)
 {
@@ -120,7 +190,7 @@ static void _on_got_playing_status (DBusGProxy *proxy, DBusGProxyCall *call_id,
 	gchar *cStatus = NULL;
 	GValue v = G_VALUE_INIT;
 	GError *erreur = NULL;
-	gboolean bSuccess = dbus_g_proxy_end_call (proxy,
+	dbus_g_proxy_end_call (proxy,
 		call_id,
 		&erreur,
 		G_TYPE_VALUE, &v,
@@ -183,9 +253,14 @@ static void cd_mpris2_get_time_elapsed (void)
 	{
 		myData.iCurrentTime =  g_value_get_uint64 (&v) / 1e6;
 	}
+	else if (G_VALUE_HOLDS_STRING (&v))  // this is bad ! (gmusicbrowser v1.1.7)
+	{
+		myData.iCurrentTime = atoi (g_value_get_string (&v)) / 1e6;
+	}
 	else
 	{
-		cd_warning ("wrong type for the 'Position' property, please report this bug to the %s team", myData.pCurrentHandler->appclass);
+		if (G_IS_VALUE(&v)) //  when changing song, we don't receive this value => no need to display a warning message each time
+			cd_warning ("wrong type for the 'Position' property, please report this bug to the %s team", myData.pCurrentHandler->appclass);
 		myData.iCurrentTime = -1;
 	}
 }
@@ -200,22 +275,32 @@ static double cd_mpris2_get_volume (void)
 	return cairo_dock_dbus_get_property_as_double (myData.dbus_proxy_player, "org.mpris.MediaPlayer2.Player", "Volume");
 }
 
+static gboolean _is_a_new_track (const gchar *cTrackID)
+{
+	cd_message ("  TrackId <- %s (was: %s)", cTrackID, myData.cTrackID);
+	if (cairo_dock_strings_differ (myData.cTrackID, cTrackID))  // track has changed.
+	{
+		g_free (myData.cTrackID);
+		myData.cTrackID = g_strdup (cTrackID);
+		return TRUE;
+	}
+	return FALSE;
+}
+
 static gboolean _extract_metadata (GHashTable *pMetadata)
 {
 	gboolean bTrackHasChanged = FALSE;
 	GValue *v;
-	const gchar *str;
+	const gchar *str = NULL;
 	
-	v = g_hash_table_lookup (pMetadata, "mpris:trackid");  // a string that uniquely identifies the track within the scope of the playlist
-	if (v != NULL && G_VALUE_HOLDS_STRING (v))
+	v = g_hash_table_lookup (pMetadata, "mpris:trackid");  // a string or a dbus object path that uniquely identifies the track within the scope of the playlist
+	if (v != NULL)
 	{
-		const gchar *cTrackID = g_value_get_string (v);
-		if (cairo_dock_strings_differ (myData.cTrackID, cTrackID))  // track has changed.
-		{
-			g_free (myData.cTrackID);
-			myData.cTrackID = g_strdup (cTrackID);
-			bTrackHasChanged = TRUE;
-		}
+		if (G_VALUE_HOLDS (v, DBUS_TYPE_G_OBJECT_PATH)) // now this attribute should be of D-Bus type "o"
+			str = (gchar*) g_value_get_boxed (v);
+		else if (G_VALUE_HOLDS_STRING (v)) // but can be a string... e.g. with Rhythmbox
+			str = g_value_get_string (v);
+		bTrackHasChanged = _is_a_new_track (str);
 	}
 
 	v = g_hash_table_lookup (pMetadata, "mpris:length");  // length of the track, in microseconds (signed 64-bit integer)
@@ -225,7 +310,7 @@ static gboolean _extract_metadata (GHashTable *pMetadata)
 		cd_debug ("Length: %d", myData.iSongLength);
 	}
 
-	g_free (myData.cArtist);
+	gchar *cOldArtist = myData.cArtist;
 	myData.cArtist = NULL;
 	v = (GValue *) g_hash_table_lookup(pMetadata, "xesam:artist");
 	if (v != NULL && G_VALUE_HOLDS(v, G_TYPE_STRV))
@@ -236,6 +321,11 @@ static gboolean _extract_metadata (GHashTable *pMetadata)
 	}
 	cd_message ("  cArtist <- %s", myData.cArtist);
 	
+	// maybe the user has renamed the tags of the current song...
+	if (! bTrackHasChanged && cairo_dock_strings_differ (myData.cArtist, cOldArtist))
+		bTrackHasChanged = TRUE;
+	g_free (cOldArtist);
+	
 	g_free (myData.cAlbum);
 	myData.cAlbum = NULL;
 	v = (GValue *) g_hash_table_lookup(pMetadata, "xesam:album");
@@ -246,8 +336,8 @@ static gboolean _extract_metadata (GHashTable *pMetadata)
 			myData.cAlbum = g_strdup (str);
 	}
 	cd_message ("  cAlbum <- %s", myData.cAlbum);
-	
-	g_free (myData.cTitle);
+
+	gchar *cOldTitle = myData.cTitle;
 	myData.cTitle = NULL;
 	v = (GValue *) g_hash_table_lookup(pMetadata, "xesam:title");
 	if (v != NULL && G_VALUE_HOLDS_STRING(v))
@@ -257,6 +347,13 @@ static gboolean _extract_metadata (GHashTable *pMetadata)
 			myData.cTitle = g_strdup (str);
 	}
 	cd_message ("  cTitle <- %s", myData.cTitle);
+
+	/* some players doesn't support (well) the trackid. Even if this is not our
+	 * problem, it can be interesting to also check if the title has changed.
+	 */
+	if (! bTrackHasChanged && cairo_dock_strings_differ (myData.cTitle, cOldTitle))
+		bTrackHasChanged = TRUE;
+	g_free (cOldTitle);
 	
 	g_free (myData.cPlayingUri);
 	myData.cPlayingUri = NULL;
@@ -302,7 +399,7 @@ static void _on_got_song_infos (DBusGProxy *proxy, DBusGProxyCall *call_id, Cair
 	GHashTable *pMetadata = NULL;
 	GValue v = G_VALUE_INIT;
 	GError *erreur = NULL;
-	gboolean bSuccess = dbus_g_proxy_end_call (proxy,
+	dbus_g_proxy_end_call (proxy,
 		call_id,
 		&erreur,
 		G_TYPE_VALUE, &v,
@@ -400,6 +497,23 @@ static void on_properties_changed (DBusGProxy *player_proxy, const gchar *cInter
 				cd_musicplayer_update_icon ();
 			}
 		}
+		
+		v = g_hash_table_lookup (pChangedProps, "LoopStatus");
+		if (v != NULL && G_VALUE_HOLDS_STRING (v))  // loop status has changed
+		{
+			const gchar *cStatus = g_value_get_string (v);  // "Playlist", "None"
+			s_bIsLoop = (cStatus && strcmp (cStatus, "Playlist") == 0);
+			cd_debug ("LoopStatus: %s, %d", cStatus, s_bIsLoop);
+			s_bGotLoopStatus = TRUE;
+		}
+		
+		v = g_hash_table_lookup (pChangedProps, "Shuffle");
+		if (v != NULL && G_VALUE_HOLDS_BOOLEAN (v))  // Shuffle status has changed
+		{
+			s_bIsShuffle = g_value_get_boolean (v);
+			cd_debug ("Shuffle: %d", s_bIsShuffle);
+			s_bGotShuffleStatus = TRUE;
+		}
 	}
 	/*else if (strcmp (cInterface, "org.mpris.MediaPlayer2.TrackList") == 0)
 	{
@@ -467,7 +581,7 @@ static void cd_mpris2_control (MyPlayerControl pControl, const char* song)
 		
 		case PLAYER_SHUFFLE :
 			bToggleValue = cd_mpris2_is_shuffle ();
-			cd_debug ("SetRandom <- %d\n", !bToggleValue);
+			cd_debug ("SetRandom <- %d", !bToggleValue);
 			g_value_init (&s_pValue, G_TYPE_BOOLEAN);
 			g_value_set_boolean (&s_pValue, !bToggleValue);
 			cairo_dock_dbus_set_property (myData.dbus_proxy_player, "org.mpris.MediaPlayer2.Player", "Shuffle", &s_pValue);
@@ -476,7 +590,7 @@ static void cd_mpris2_control (MyPlayerControl pControl, const char* song)
 		
 		case PLAYER_REPEAT :
 			bToggleValue = cd_mpris2_is_loop ();
-			cd_debug ("SetLoop <- %d\n", !bToggleValue);
+			cd_debug ("SetLoop <- %d", !bToggleValue);
 			g_value_init (&s_pValue, G_TYPE_STRING);
 			g_value_set_static_string (&s_pValue, bToggleValue ? "None" : "Playlist");
 			cairo_dock_dbus_set_property (myData.dbus_proxy_player, "org.mpris.MediaPlayer2.Player", "LoopStatus", &s_pValue);
@@ -485,7 +599,7 @@ static void cd_mpris2_control (MyPlayerControl pControl, const char* song)
 		
 		case PLAYER_ENQUEUE :
 		{
-			cd_debug ("enqueue %s\n", song);
+			cd_debug ("enqueue %s", song);
 			GError *erreur = NULL;
 			DBusGProxy *proxy = cairo_dock_create_new_session_proxy ("org.mpris.MediaPlayer2",
 				"/org/mpris/MediaPlayer2",
@@ -517,7 +631,7 @@ static void cd_mpris2_control (MyPlayerControl pControl, const char* song)
 				fVolume += .05;
 			else
 				fVolume -= .05;
-			cd_debug ("volume <- %f\n", fVolume);
+			cd_debug ("volume <- %f", fVolume);
 			g_value_init (&s_pValue, G_TYPE_DOUBLE);
 			g_value_set_double (&s_pValue, fVolume);
 			cairo_dock_dbus_set_property (myData.dbus_proxy_player, "org.mpris.MediaPlayer2.Player", "Volume", &s_pValue);
@@ -621,6 +735,8 @@ static void cd_mpris2_start (void)
 	// get the current state.
 	myData.iTrackListLength = 0;
 	myData.iTrackListIndex = 0;
+	s_bGotLoopStatus = FALSE;
+	s_bGotShuffleStatus = FALSE;
 	cd_mpris2_getPlaying_async ();  // will get song infos after playing status.
 }
 
@@ -633,6 +749,10 @@ void cd_musicplayer_register_mpris2_handler (void)
 	pHandler->stop = cd_mpris2_stop;
 	pHandler->start = cd_mpris2_start;
 	pHandler->control = cd_mpris2_control;
+	pHandler->get_loop_status = get_loop_status;
+	pHandler->get_shuffle_status = get_shuffle_status;
+	pHandler->raise = _raise;
+	pHandler->quit = _quit;
 	pHandler->bSeparateAcquisition = FALSE;
 	pHandler->iLevel = PLAYER_GOOD;
 	
