@@ -26,7 +26,7 @@
 #include "applet-init.h"
 
 
-CD_APPLET_DEFINITION (N_("Quick Browser"),
+CD_APPLET_DEFINE_BEGIN (N_("Quick Browser"),
 	2, 0, 0,
 	CAIRO_DOCK_CATEGORY_APPLET_FILES,
 	N_("This applet lets you browse a folder and its sub-folders very quickly.\n"
@@ -34,6 +34,9 @@ CD_APPLET_DEFINITION (N_("Quick Browser"),
 	"Midlle-click will open the main folder.\n"
 	"This applet can be instanciated several times, if you want to browse different folders."),
 	"Fabounet (Fabrice Rey)")
+	CD_APPLET_DEFINE_COMMON_APPLET_INTERFACE
+	CD_APPLET_ALLOW_EMPTY_TITLE
+CD_APPLET_DEFINE_END
 
 
 //\___________ Here is where you initiate your applet. myConfig is already set at this point, and also myIcon, myContainer, myDock, myDesklet (and myDrawContext if you're in dock mode). The macro CD_APPLET_MY_CONF_FILE and CD_APPLET_MY_KEY_FILE can give you access to the applet's conf-file and its corresponding key-file (also available during reload). If you're in desklet mode, myDrawContext is still NULL, and myIcon's buffers has not been filled, because you may not need them then (idem when reloading).
@@ -56,7 +59,11 @@ CD_APPLET_INIT_BEGIN
 	CD_APPLET_REGISTER_FOR_MIDDLE_CLICK_EVENT;
 	CD_APPLET_REGISTER_FOR_BUILD_MENU_EVENT;
 	
-	cd_keybinder_bind (myConfig.cMenuShortkey, (CDBindkeyHandler) cd_quick_browser_on_shortkey_menu, myApplet);
+	// keyboard events
+	myData.cKeyBinding = CD_APPLET_BIND_KEY (myConfig.cMenuShortkey,
+		D_("Show/hide the folder menu"),
+		"Configuration", "menu shortkey",
+		(CDBindkeyHandler) cd_quick_browser_on_shortkey_menu);
 CD_APPLET_INIT_END
 
 
@@ -65,6 +72,8 @@ CD_APPLET_STOP_BEGIN
 	CD_APPLET_UNREGISTER_FOR_CLICK_EVENT;
 	CD_APPLET_UNREGISTER_FOR_MIDDLE_CLICK_EVENT;
 	CD_APPLET_UNREGISTER_FOR_BUILD_MENU_EVENT;
+	
+	cd_keybinder_unbind (myData.cKeyBinding);
 CD_APPLET_STOP_END
 
 
@@ -86,6 +95,6 @@ CD_APPLET_RELOAD_BEGIN
 			g_free (cDirName);
 		}
 		
-		cd_keybinder_bind (myConfig.cMenuShortkey, (CDBindkeyHandler) cd_quick_browser_on_shortkey_menu, myApplet);  // shortkey were unbinded during reset_config.
+		cd_keybinder_rebind (myData.cKeyBinding, myConfig.cMenuShortkey, NULL);
 	}
 CD_APPLET_RELOAD_END
