@@ -23,13 +23,11 @@
 
 #include "applet-struct.h"
 #include "applet-load-icons.h"
+#include "applet-drives.h"
 #include "applet-bookmarks.h"
 
+#define CD_SHORTCUT_DEFAULT_DIRECTORY_ICON_FILENAME "inode-directory"
 
-static void _cd_shortcuts_mark_one_bookmark (Icon *icon, gpointer unused, int *pTime)
-{
-	icon->iLastCheckTime = *pTime;
-}
 void cd_shortcuts_on_bookmarks_event (CairoDockFMEventType iEventType, const gchar *cURI, CairoDockModuleInstance *myApplet)
 {
 	static int iTime = 0;
@@ -37,12 +35,21 @@ void cd_shortcuts_on_bookmarks_event (CairoDockFMEventType iEventType, const gch
 	CD_APPLET_ENTER;
 	//g_print ("%s (%d)\n", __func__, iEventType);
 	GList *pIconsList = CD_APPLET_MY_ICONS_LIST;
+	Icon *icon;
+	GList *ic;
+	for (ic = pIconsList; ic != NULL; ic = ic->next)  // optimization: skip the disks and networks, and point on the first bookmark.
+	{
+		icon = ic->data;
+		if (icon->iGroup == (CairoDockIconGroup) CD_BOOKMARK_GROUP)
+			break;
+	}
+	pIconsList = ic;  // Note that since the first bookmark is always the Home Folder, 'pIconsList' will never change when inserting/removing a bookmark.
 	CairoContainer *pContainer = CD_APPLET_MY_ICONS_LIST_CONTAINER;
 	CD_APPLET_LEAVE_IF_FAIL (pContainer != NULL);
 	
 	if (iEventType == CAIRO_DOCK_FILE_CREATED || iEventType == CAIRO_DOCK_FILE_MODIFIED)  // le fichier des bookmarks a ete modifie.
 	{
-		cd_message ("  un signet en plus ou en moins");
+		cd_message ("The bookmarks list has changed");
 		
 		//\____________________ On lit le fichier des signets.
 		gchar *cBookmarkFilePath = g_strdup_printf ("%s/.gtk-bookmarks", g_getenv ("HOME"));
@@ -61,12 +68,13 @@ void cd_shortcuts_on_bookmarks_event (CairoDockFMEventType iEventType, const gch
 			g_free (cContent);
 			
 			//\____________________ On parcourt le contenu.
+			double fCurrentOrder = 1.;  // bookmarks are listed in the order of the file; we need to reorder each icon in case a bookmark has changed its place, or if a new one appeared (the first one is always the Home Folder).
 			gchar *cOneBookmark;
 			Icon *pNewIcon;
 			gchar *cName, *cRealURI, *cIconName, *cUserName;
 			gboolean bIsDirectory;
 			int iVolumeID;
-			double fOrder, fCurrentOrder = 0;
+			double fOrder;
 			int i;
 			for (i = 0; cBookmarksList[i] != NULL; i ++)
 			{
@@ -99,14 +107,18 @@ void cd_shortcuts_on_bookmarks_event (CairoDockFMEventType iEventType, const gch
 				Icon *pExistingIcon = cairo_dock_get_icon_with_base_uri (pIconsList, cOneBookmark);
 				if (pExistingIcon != NULL)
 				{
-					if (cairo_dock_strings_differ (pExistingIcon->cName, cUserName) || cURI == NULL)  // signet inexistant ou qui a change => on le cree.
+					if ((cUserName && cairo_dock_strings_differ (pExistingIcon->cName, cUserName))
+					|| cURI == NULL)  // signet inexistant ou qui a change => on le cree. 'cUserName' may be NULL if the user has never set a user-name yet, but once he does, 'cUserName' is not NULL. so if 'cUserName' is NULL, it has not changed.
 					{
 						//g_print ("le signet '%s' a change, on le recree\n", pExistingIcon->cName);
 						CD_APPLET_REMOVE_ICON_FROM_MY_ICONS_LIST (pExistingIcon);
 						pExistingIcon = NULL;
 					}
 					else
+					{
 						pExistingIcon->iLastCheckTime = iTime;
+						pExistingIcon->fOrder = fCurrentOrder ++;
+					}
 				}
 				if (pExistingIcon == NULL)
 				{
@@ -117,7 +129,7 @@ void cd_shortcuts_on_bookmarks_event (CairoDockFMEventType iEventType, const gch
 					cIconName = NULL;
 					if (cairo_dock_fm_get_file_info (cOneBookmark, &cName, &cRealURI, &cIconName, &bIsDirectory, &iVolumeID, &fOrder, CAIRO_DOCK_FM_SORT_BY_NAME))
 					{
-						cd_message (" + 1 signet : %s", cOneBookmark);
+						cd_message (" + 1 bookmark : %s", cOneBookmark);
 						if (cUserName != NULL)
 						{
 							g_free (cName);
@@ -132,20 +144,19 @@ void cd_shortcuts_on_bookmarks_event (CairoDockFMEventType iEventType, const gch
 						}
 						if (cRealURI == NULL)
 							cRealURI = g_strdup ("none");
+						if (cIconName == NULL)
+							cIconName = cairo_dock_search_icon_s_path (CD_SHORTCUT_DEFAULT_DIRECTORY_ICON_FILENAME, CAIRO_DOCK_DEFAULT_ICON_SIZE);
 						
 						pNewIcon = cairo_dock_create_dummy_launcher (cName,
 							cIconName,
 							cRealURI,
 							NULL,
-							0);
+							fCurrentOrder++);
 						pNewIcon->iGroup = CD_BOOKMARK_GROUP;
 						pNewIcon->cBaseURI = cOneBookmark;
 						pNewIcon->iVolumeID = iVolumeID;
 						pNewIcon->iLastCheckTime = iTime;
 						
-						pIconsList = CD_APPLET_MY_ICONS_LIST;
-						cd_shortcuts_set_icon_order_by_name (pNewIcon, pIconsList);
-						
 						CD_APPLET_ADD_ICON_IN_MY_ICONS_LIST (pNewIcon);
 					}
 					else
@@ -157,41 +168,24 @@ void cd_shortcuts_on_bookmarks_event (CairoDockFMEventType iEventType, const gch
 			}
 			g_free (cBookmarksList);
 			
-			//\____________________ On supprime les vieux signets.
-			pIconsList = CD_APPLET_MY_ICONS_LIST;
-			gboolean bRemove = TRUE;
-			Icon *icon;
-			GList *ic;
-			while (bRemove)
+			//\____________________ remove the old bookmarks.
+			///pIconsList = CD_APPLET_MY_ICONS_LIST;
+			GList *next_ic;
+			for (ic = pIconsList; ic != NULL; ic = next_ic)
 			{
-				bRemove = FALSE;
-				for (ic = pIconsList; ic != NULL; ic = ic->next)
+				next_ic = ic->next;
+				icon = ic->data;
+				if (icon->iGroup == (CairoDockIconGroup) CD_BOOKMARK_GROUP)
 				{
-					icon = ic->data;
-					if (icon->iGroup == CD_BOOKMARK_GROUP)
+					if (icon->iLastCheckTime < iTime)
 					{
-						if (icon->iLastCheckTime != iTime)
-						{
-							//g_print ("this bookmark is too old (%s)\n", icon->cName);
-							CD_APPLET_REMOVE_ICON_FROM_MY_ICONS_LIST (icon);
-							bRemove = TRUE;
-							break;
-						}
+						cd_debug ("this bookmark is too old (%s)", icon->cName);
+						CD_APPLET_REMOVE_ICON_FROM_MY_ICONS_LIST (icon);
 					}
 				}
 			}
 			
-			//\____________________ On ajoute ou supprime un separateur.
-			/**if (myDock)
-			{
-				Icon *pFirstBookmarkIcon = cairo_dock_get_first_icon_of_type (myIcon->pSubDock->icons, 10);
-				if (pFirstBookmarkIcon == NULL && pSeparatorIcon != NULL)
-				{
-					cd_message ("on enleve l'ancien separateur");
-					cairo_dock_detach_icon_from_dock (pSeparatorIcon, myIcon->pSubDock, myConfig.bUseSeparator);
-					cairo_dock_free_icon (pSeparatorIcon);
-				}
-			}*/
+			cairo_dock_sort_icons_by_order (pIconsList);  // again, since 'Home Folder' is always the first bookmark, the head of the list won't change even if there are only bookmarks (so we don't need to re-assigne it to the container).
 		}
 		g_free (cBookmarkFilePath);
 	}
@@ -218,6 +212,7 @@ void cd_shortcuts_remove_one_bookmark (const gchar *cURI)
 		gchar **cBookmarksList = g_strsplit (cContent, "\n", -1);
 		g_free (cContent);
 		gchar *cOneBookmark, *str;
+		gboolean bFound = FALSE;
 		int i = 0;
 		for (i = 0; cBookmarksList[i] != NULL; i ++)
 		{
@@ -228,13 +223,21 @@ void cd_shortcuts_remove_one_bookmark (const gchar *cURI)
 			str = strchr (cOneBookmark, ' ');
 			if ((str && strncmp (cOneBookmark, cURI, str - cOneBookmark) == 0) || (!str && strcmp (cOneBookmark, cURI) == 0))
 			{
-				cBookmarksList[i] = g_strdup ("");
+				// remove this element from the array
+				int j;
+				for (j = i; cBookmarksList[j] != NULL; j ++)
+				{
+					cBookmarksList[j] = cBookmarksList[j+1];
+				}
+				// free the removed element.
 				g_free (cOneBookmark);
+				// quit the loop
+				bFound = TRUE;
 				break;
 			}
 		}
 		
-		if (cBookmarksList[i] == NULL)
+		if (! bFound)
 		{
 			cd_warning ("bookmark '%s' not found", cURI);
 		}
@@ -316,10 +319,22 @@ void cd_shortcuts_add_one_bookmark (const gchar *cURI)
 	cd_message ("%s (%s)", __func__, cURI);
 	
 	gchar *cBookmarkFilePath = g_strdup_printf ("%s/.gtk-bookmarks", g_getenv ("HOME"));
+	
+	// see if we need to add a new line before the new URI.
+	gchar *cContent = NULL;
+	gsize length = 0;
+	g_file_get_contents (cBookmarkFilePath,
+		&cContent,
+		&length,
+		NULL);
+	gboolean bAddNewLine = (cContent && length > 0 && cContent[length-1] != '\n');
+	g_free (cContent);
+	
+	// append the new URI to the file.
 	FILE *f = fopen (cBookmarkFilePath, "a");
 	if (f != NULL)
 	{
-		gchar *cNewLine = g_strconcat ("\n", cURI, NULL);
+		gchar *cNewLine = g_strdup_printf ("%s%s\n", bAddNewLine ? "\n" : "", cURI);
 		fputs(cNewLine, f);
 		g_free (cNewLine);
 		fclose (f);
@@ -327,31 +342,74 @@ void cd_shortcuts_add_one_bookmark (const gchar *cURI)
 	g_free (cBookmarkFilePath);
 }
 
-
-GList *cd_shortcuts_list_bookmarks (gchar *cBookmarkFilePath)
+Icon * _cd_shortcuts_get_icon (gchar *cFileName, const gchar *cUserName, double fCurrentOrder)
 {
+	cd_debug ("New icon: %s, %s, %f", cFileName, cUserName, fCurrentOrder);
+	gchar *cName, *cRealURI, *cIconName;
+	gboolean bIsDirectory;
+	gint iVolumeID;
+	gdouble fOrder;
+	if (! cairo_dock_fm_get_file_info (cFileName, &cName, &cRealURI, &cIconName,
+		&bIsDirectory, &iVolumeID, &fOrder, CAIRO_DOCK_FM_SORT_BY_NAME))
+		return NULL;
+	if (cUserName != NULL)
+	{
+		g_free (cName);
+		cName = g_strdup (cUserName);
+	}
+	else if (cName == NULL)  // a bookmark on a unmounted system
+	{
+		gchar *cGuessedName = g_path_get_basename (cFileName);
+		cairo_dock_remove_html_spaces (cGuessedName); // or: g_uri_unescape_string
+		cName = g_strdup_printf ("%s\n[%s]", cGuessedName, D_("Unmounted"));
+		g_free (cGuessedName);
+	}
+	if (cRealURI == NULL)
+		cRealURI = g_strdup ("none");
+	if (cIconName == NULL)
+		cIconName = cairo_dock_search_icon_s_path (
+			CD_SHORTCUT_DEFAULT_DIRECTORY_ICON_FILENAME,
+			CAIRO_DOCK_DEFAULT_ICON_SIZE); // should be the default icon
+
+	Icon *pNewIcon = cairo_dock_create_dummy_launcher (cName,
+		cIconName,
+		cRealURI,
+		NULL,
+		fCurrentOrder);
+	pNewIcon->iGroup = CD_BOOKMARK_GROUP;
+	pNewIcon->cBaseURI = cFileName;
+	pNewIcon->iVolumeID = iVolumeID;
+	return pNewIcon;
+}
+
+GList *cd_shortcuts_list_bookmarks (gchar *cBookmarkFilePath, CairoDockModuleInstance *myApplet)
+{
+	GList *pBookmarkIconList = NULL;
+	Icon *pNewIcon;
+	double fCurrentOrder = 0.;
+
+	// Home
+	gchar *cHome = g_strdup_printf ("file://%s", g_getenv ("HOME"));
+	pNewIcon = _cd_shortcuts_get_icon (cHome, D_("Home Folder"), fCurrentOrder++);
+	pNewIcon->iLastCheckTime = 1e9;  // so that this bookmark will never be considered old, and therefore removed.
+	_init_disk_usage (pNewIcon, myApplet);
+	pBookmarkIconList = g_list_append (pBookmarkIconList, pNewIcon);
+
 	gchar *cContent = NULL;
-	gsize length=0;
+	gsize length = 0;
 	GError *erreur = NULL;
 	g_file_get_contents  (cBookmarkFilePath, &cContent, &length, &erreur);
 	if (erreur != NULL)
 	{
 		cd_warning ("Attention : %s\n  no bookmark will be available", erreur->message);
 		g_error_free (erreur);
-		return NULL;
 	}
 	else
 	{
-		GList *pBookmarkIconList = NULL;
 		gchar **cBookmarksList = g_strsplit (cContent, "\n", -1);
 		g_free (cContent);
 		
-		gchar *cOneBookmark;
-		Icon *pNewIcon;
-		gchar *cName, *cRealURI, *cIconName, *cUserName;
-		gboolean bIsDirectory;
-		int iVolumeID;
-		double fOrder, fCurrentOrder = 0;
+		gchar *cOneBookmark, *cUserName;
 		int i = 0;
 		for (i = 0; cBookmarksList[i] != NULL; i ++)
 		{
@@ -372,36 +430,12 @@ GList *cd_shortcuts_list_bookmarks (gchar *cBookmarkFilePath)
 					*str = '\0';
 				}
 			}
-			cName = NULL;
-			cRealURI = NULL;
-			cIconName = NULL;
-			if (*cOneBookmark != '\0' && *cOneBookmark != '#' && cairo_dock_fm_get_file_info (cOneBookmark, &cName, &cRealURI, &cIconName, &bIsDirectory, &iVolumeID, &fOrder, CAIRO_DOCK_FM_SORT_BY_NAME))
+			if (*cOneBookmark != '\0' && *cOneBookmark != '#')
 			{
 				cd_message (" + 1 bookmark : %s", cOneBookmark);
-				if (cUserName != NULL)
-				{
-					g_free (cName);
-					cName = g_strdup (cUserName);
-				}
-				else if (cName == NULL)  // cas d'un bookmark situe sur un volume non monte.
-				{
-					gchar *cGuessedName = g_path_get_basename (cOneBookmark);
-					cairo_dock_remove_html_spaces (cGuessedName);
-					cName = g_strdup_printf ("%s\n[%s]", cGuessedName, D_("Unmounted"));
-					g_free (cGuessedName);
-				}
-				if (cRealURI == NULL)
-					cRealURI = g_strdup ("none");
-				
-				pNewIcon = pNewIcon = cairo_dock_create_dummy_launcher (cName,
-					cIconName,
-					cRealURI,
-					NULL,
-					fCurrentOrder ++);
-				pNewIcon->iGroup = CD_BOOKMARK_GROUP;
-				pNewIcon->cBaseURI = cOneBookmark;
-				pNewIcon->iVolumeID = iVolumeID;
-				pBookmarkIconList = g_list_append (pBookmarkIconList, pNewIcon);
+				pNewIcon = _cd_shortcuts_get_icon (cOneBookmark, cUserName, fCurrentOrder++);
+				if (pNewIcon)
+					pBookmarkIconList = g_list_append (pBookmarkIconList, pNewIcon);
 			}
 			else
 			{
@@ -409,6 +443,6 @@ GList *cd_shortcuts_list_bookmarks (gchar *cBookmarkFilePath)
 			}
 		}
 		g_free (cBookmarksList);
-		return pBookmarkIconList;
 	}
+	return pBookmarkIconList;
 }
