@@ -105,7 +105,7 @@ static void _cd_shortcuts_on_network_event (CairoDockFMEventType iEventType, con
 			CD_APPLET_REMOVE_ICON_FROM_MY_ICONS_LIST (pConcernedIcon);
 		}
 		break ;
-		
+
 		case CAIRO_DOCK_FILE_CREATED :  // un reseau a ete connecte.
 		{
 			//\_______________________ on verifie qu'elle n'existe pas deja.
@@ -140,7 +140,8 @@ static void _cd_shortcuts_on_network_event (CairoDockFMEventType iEventType, con
 				NULL,  // son icone n'est pas encore chargee
 				pNewIcon->cName);
 		}
-		
+		break ;
+
 		case CAIRO_DOCK_FILE_MODIFIED :  // un point de montage a ete (de)monte
 		{
 			//\_______________________ on cherche l'icone concernee.
@@ -180,6 +181,10 @@ static void _cd_shortcuts_on_network_event (CairoDockFMEventType iEventType, con
 				cairo_dock_free_icon (pNewIcon);
 			}
 		}
+		break ;
+
+		case CAIRO_DOCK_NB_EVENT_ON_FILES :
+		break ;
 	}
 	CD_APPLET_LEAVE();
 }
@@ -214,7 +219,7 @@ static inline GList * _load_icons (CDSharedMemory *pSharedMemory)
 			fclose (f);
 		}
 		
-		GList *pIconList2 = cd_shortcuts_list_bookmarks (cBookmarkFilePath);
+		GList *pIconList2 = cd_shortcuts_list_bookmarks (cBookmarkFilePath, pSharedMemory->pApplet);
 		
 		pIconList = g_list_concat (pIconList, pIconList2);
 		
@@ -277,7 +282,18 @@ static gboolean cd_shortcuts_build_shortcuts_from_data (CDSharedMemory *pSharedM
 			cDeskletRendererName = "Tree";
 		break ;
 	}
-	CD_APPLET_LOAD_MY_ICONS_LIST (pIconList, myConfig.cRenderer, cDeskletRendererName, NULL);
+	CD_APPLET_LOAD_MY_ICONS_LIST (pIconList, myConfig.cRenderer, cDeskletRendererName, NULL);  // takes ownership of 'pIconList'
+	
+	//\_______________________ add a progress bar on disk volumes (must be done after inserting the icons into a container)
+	pIconList = CD_APPLET_MY_ICONS_LIST;
+	Icon *pIcon;
+	GList *ic;
+	for (ic = pIconList; ic != NULL; ic = ic->next)
+	{
+		pIcon = ic->data;
+		if (CD_APPLET_GET_MY_ICON_DATA (pIcon) != NULL)  // drive
+			cd_shortcuts_add_progress_bar (pIcon, myApplet);
+	}
 	
 	//\_______________________ On lance la tache de mesure des disques.
 	cd_shortcuts_launch_disk_periodic_task (myApplet);
