@@ -29,7 +29,6 @@
 static void _on_volume_mounted (gboolean bMounting, gboolean bSuccess, const gchar *cName, const gchar *cURI, CairoDockModuleInstance *myApplet)
 {
 	CD_APPLET_ENTER;
-	GList *pIconsList = CD_APPLET_MY_ICONS_LIST;
 	CairoContainer *pContainer = CD_APPLET_MY_ICONS_LIST_CONTAINER;
 	CD_APPLET_LEAVE_IF_FAIL (pContainer != NULL);
 	
@@ -53,7 +52,6 @@ static void _on_volume_mounted (gboolean bMounting, gboolean bSuccess, const gch
 static void _open_on_mount (gboolean bMounting, gboolean bSuccess, const gchar *cName, const gchar *cURI, CairoDockModuleInstance *myApplet)
 {
 	CD_APPLET_ENTER;
-	GList *pIconsList = CD_APPLET_MY_ICONS_LIST;
 	CairoContainer *pContainer = CD_APPLET_MY_ICONS_LIST_CONTAINER;
 	CD_APPLET_LEAVE_IF_FAIL (pContainer != NULL);
 	
@@ -93,7 +91,7 @@ CD_APPLET_ON_CLICK_BEGIN
 	}
 	else if (CD_APPLET_CLICKED_ICON != NULL)  // clic sur une des icones de la liste.
 	{
-		if (CD_APPLET_CLICKED_ICON->iGroup == CD_DRIVE_GROUP && CD_APPLET_CLICKED_ICON->iVolumeID)  // clic sur un point de montage.
+		if (CD_APPLET_CLICKED_ICON->iGroup == (CairoDockIconGroup) CD_DRIVE_GROUP && CD_APPLET_CLICKED_ICON->iVolumeID)  // clic sur un point de montage.
 		{
 			gboolean bIsMounted = FALSE;
 			gchar *cActivationURI = cairo_dock_fm_is_mounted (CD_APPLET_CLICKED_ICON->cBaseURI, &bIsMounted);
@@ -107,10 +105,8 @@ CD_APPLET_ON_CLICK_BEGIN
 				cairo_dock_fm_mount_full (CD_APPLET_CLICKED_ICON->cBaseURI, CD_APPLET_CLICKED_ICON->iVolumeID, (CairoDockFMMountCallback) _open_on_mount, myApplet);
 			}
 		}
-		else if (CD_APPLET_CLICKED_ICON->iGroup == CD_BOOKMARK_GROUP)  // clic sur un signet, il peut etre place sur un volume non monte.
+		else if (CD_APPLET_CLICKED_ICON->iGroup == (CairoDockIconGroup) CD_BOOKMARK_GROUP)  // clic sur un signet, il peut etre place sur un volume non monte.
 		{
-			GList *pIconsList = CD_APPLET_MY_ICONS_LIST;
-			CairoContainer *pContainer = CD_APPLET_MY_ICONS_LIST_CONTAINER;
 			
 			/// chercher un volume contenant le signet
 			
@@ -173,7 +169,7 @@ CD_APPLET_ON_MIDDLE_CLICK_BEGIN
 	{
 		cairo_dock_fm_launch_uri (g_getenv ("HOME"));
 	}
-	else if (CD_APPLET_CLICKED_ICON != NULL && (CD_APPLET_CLICKED_ICON->iGroup == CD_DRIVE_GROUP || CD_APPLET_CLICKED_ICON->iVolumeID > 0))  // clic sur une icone du sous-dock ou du desklet, et de type 'point de montage'.
+	else if (CD_APPLET_CLICKED_ICON != NULL && (CD_APPLET_CLICKED_ICON->iGroup == (CairoDockIconGroup) CD_DRIVE_GROUP || CD_APPLET_CLICKED_ICON->iVolumeID > 0))  // clic sur une icone du sous-dock ou du desklet, et de type 'point de montage'.
 	{
 		_mount_unmount (CD_APPLET_CLICKED_ICON, CD_APPLET_CLICKED_CONTAINER, myApplet);
 	}
@@ -205,7 +201,7 @@ static void _cd_shortcuts_eject (GtkMenuItem *menu_item, gpointer *data)
 	CairoDockModuleInstance *myApplet = data[0];
 	CD_APPLET_ENTER;
 	Icon *pIcon = data[1];
-	CairoContainer *pContainer = data[2];
+	// CairoContainer *pContainer = data[2];
 	
 	cairo_dock_fm_eject_drive (pIcon->cBaseURI);
 	CD_APPLET_LEAVE ();
@@ -232,10 +228,29 @@ static void _cd_shortcuts_show_disk_info (GtkMenuItem *menu_item, gpointer *data
 	g_free (cInfo);
 	CD_APPLET_LEAVE ();
 }
+
 static void _open_home_dir (GtkMenuItem *menu_item, gpointer data)
 {
 	cairo_dock_fm_launch_uri (g_getenv ("HOME"));
 }
+
+static gboolean s_bNCSChecked = FALSE;
+static gboolean s_bNCSAvailable = FALSE;
+
+static void _check_ncs (void)
+{
+	gchar *cResult = cairo_dock_launch_command_sync ("which nautilus-connect-server");
+	if (cResult != NULL && *cResult == '/')
+		s_bNCSAvailable = TRUE;
+	g_free (cResult);
+	s_bNCSChecked = TRUE;
+}
+
+static void _open_ncs (GtkMenuItem *menu_item, gpointer data)
+{
+	cairo_dock_launch_command ("nautilus-connect-server");
+}
+
 CD_APPLET_ON_BUILD_MENU_BEGIN
 	static gpointer *data = NULL;
 	if (data == NULL)
@@ -246,21 +261,23 @@ CD_APPLET_ON_BUILD_MENU_BEGIN
 	
 	if (CD_APPLET_CLICKED_ICON == myIcon)  // clic sur l'icone principale (mode dock donc).
 	{
-		GtkWidget *pSubMenu = CD_APPLET_CREATE_MY_SUB_MENU ();
 		gchar *cLabel = g_strdup_printf ("%s (%s)", D_("Open Home directory"), D_("middle-click"));
 		CD_APPLET_ADD_IN_MENU_WITH_STOCK (cLabel, GTK_STOCK_OPEN, _open_home_dir, CD_APPLET_MY_MENU);
 		g_free (cLabel);
-		CD_APPLET_ADD_ABOUT_IN_MENU (pSubMenu);
+		if (! s_bNCSChecked)
+			_check_ncs ();
+		if (s_bNCSAvailable)
+			CD_APPLET_ADD_IN_MENU_WITH_STOCK (D_("Connect to Server..."), GTK_STOCK_OPEN, _open_ncs, CD_APPLET_MY_MENU);
 	}
 	else if (CD_APPLET_CLICKED_ICON != NULL)  // clic sur un item.
 	{
-		if (CD_APPLET_CLICKED_ICON->iGroup == CD_BOOKMARK_GROUP)  // clic sur un signet.
+		if (CD_APPLET_CLICKED_ICON->iGroup == (CairoDockIconGroup) CD_BOOKMARK_GROUP)  // clic sur un signet.
 		{
 			CD_APPLET_ADD_IN_MENU_WITH_STOCK_AND_DATA (D_("Rename this bookmark"),  GTK_STOCK_SAVE_AS, _cd_shortcuts_rename_bookmark, CD_APPLET_MY_MENU, data);
 			CD_APPLET_ADD_IN_MENU_WITH_STOCK_AND_DATA (D_("Remove this bookmark"), GTK_STOCK_REMOVE, _cd_shortcuts_remove_bookmark, CD_APPLET_MY_MENU, CD_APPLET_CLICKED_ICON->cBaseURI);
 			CD_APPLET_LEAVE (CAIRO_DOCK_INTERCEPT_NOTIFICATION);
 		}
-		else if (CD_APPLET_CLICKED_ICON->iGroup == CD_DRIVE_GROUP && CD_APPLET_CLICKED_ICON->cBaseURI != NULL)  // clic sur un volume.
+		else if (CD_APPLET_CLICKED_ICON->iGroup == (CairoDockIconGroup) CD_DRIVE_GROUP && CD_APPLET_CLICKED_ICON->cBaseURI != NULL)  // clic sur un volume.
 		{
 			if (cairo_dock_fm_can_eject (CD_APPLET_CLICKED_ICON->cBaseURI))
 				CD_APPLET_ADD_IN_MENU_WITH_STOCK_AND_DATA (D_("Eject"), GTK_STOCK_DISCONNECT, _cd_shortcuts_eject, CD_APPLET_MY_MENU, data);
