@@ -77,7 +77,7 @@ void term_on_keybinding_pull(const char *keystring, gpointer user_data)
 				}
 				bHasFocus |= (gldi_container_get_Xid (myContainer) == cairo_dock_get_current_active_window ());
 			}
-			cd_debug ("%s (%d)\n", __func__, bHasFocus);
+			cd_debug ("%s (%d)", __func__, bHasFocus);
 			
 			if (bHasFocus)
 			{
@@ -108,12 +108,14 @@ void term_on_keybinding_pull(const char *keystring, gpointer user_data)
 	}
 }
 
-
+#if GTK_CHECK_VERSION (3, 4, 0)
+static gchar *_get_label_and_color (const gchar *cLabel, GdkRGBA *pColor, gboolean *bColorSet)
+#else
 static gchar *_get_label_and_color (const gchar *cLabel, GdkColor *pColor, gboolean *bColorSet)
+#endif
 {
 	gchar *cUsefulLabel;
 	gchar *str = strchr (cLabel, '>');
-	//g_print ("%s (%s)\n", __func__, cLabel);
 	if (cLabel != NULL && strncmp (cLabel, "<span color='", 13) == 0 && str != NULL)  // approximatif mais devrait suffire.
 	{
 		const gchar *col = cLabel+13;
@@ -121,8 +123,11 @@ static gchar *_get_label_and_color (const gchar *cLabel, GdkColor *pColor, gbool
 		if (col_end)
 		{
 			gchar *cColor = g_strndup (col, col_end - col);
-			//g_print ("cColor : %s\n", cColor);
+			#if GTK_CHECK_VERSION (3, 4, 0)
+			*bColorSet = gdk_rgba_parse (pColor, cColor);
+			#else
 			*bColorSet = gdk_color_parse (cColor, pColor);
+			#endif
 			g_free (cColor);
 		}
 		cUsefulLabel = g_strdup (str+1);
@@ -147,13 +152,15 @@ void terminal_rename_tab (GtkWidget *vterm)
 	}
 	GtkWidget *pTabLabelWidget = gtk_notebook_get_tab_label (GTK_NOTEBOOK(myData.tab), vterm);
 	GList *pTabWidgetList = gtk_container_get_children (GTK_CONTAINER (pTabLabelWidget));
-	GtkLabel *pLabel;
-	const gchar *cCurrentName;
 	if (pTabWidgetList != NULL && pTabWidgetList->data != NULL)
 	{
 		GtkLabel *pLabel = pTabWidgetList->data;
 		const gchar *cCurrentName = gtk_label_get_label (pLabel);
+		#if GTK_CHECK_VERSION (3, 4, 0)
+		GdkRGBA color;
+		#else
 		GdkColor color;
+		#endif
 		gboolean bColorSet = FALSE;
 		gchar *cUsefulLabel = _get_label_and_color (cCurrentName, &color, &bColorSet);
 		
@@ -164,7 +171,11 @@ void terminal_rename_tab (GtkWidget *vterm)
 		{
 			if (bColorSet)
 			{
+				#if GTK_CHECK_VERSION (3, 4, 0)
+				gchar *cColor = gdk_rgba_to_string (&color);
+				#else
 				gchar *cColor = gdk_color_to_string (&color);
+				#endif
 				gchar *cNewColoredName = g_strdup_printf ("<span color='%s'>%s</span>", cColor, cNewName);
 				gtk_label_set_markup (pLabel, cNewColoredName);
 				g_free (cNewColoredName);
@@ -180,12 +191,30 @@ void terminal_rename_tab (GtkWidget *vterm)
 	}
 }
 
+#if GTK_CHECK_VERSION (3, 4, 0) // now we have a GtkColorChooserDialog which impliments GtkColorChooser
+static void _set_color (GtkDialog *pColorSelection, gint iAnswer, GtkLabel *pLabel)
+{
+	if (iAnswer != GTK_RESPONSE_OK)
+		return gtk_widget_destroy (GTK_WIDGET (pColorSelection));
+
+	GdkRGBA color;
+	gtk_color_chooser_get_rgba (GTK_COLOR_CHOOSER (pColorSelection), &color);
+	gtk_widget_destroy (GTK_WIDGET (pColorSelection)); // we can close the dialog.
+
+	/* 'gdk_rgba_to_string' returns a string like that: 'rgb(r, g, b)'
+	 * but it's not supported by span's color specification...
+	 */
+	gchar *cColor = g_strdup_printf ("#%X%X%X",
+		(guint) (color.red * 65535),
+		(guint) (color.green * 65535),
+		(guint) (color.blue * 65535));
+#else
 static void _set_color (GtkColorSelection *pColorSelection, GtkLabel *pLabel)
 {
 	GdkColor color;
 	gtk_color_selection_get_current_color (pColorSelection, &color);
-	
 	gchar *cColor = gdk_color_to_string (&color);
+#endif
 	
 	const gchar *cCurrentLabel = gtk_label_get_text (pLabel);  // recupere le texte sans les balises pango.
 	//gchar *cUsefulLabel = _get_label_and_color (cCurrentLabel, NULL, NULL);
@@ -206,33 +235,46 @@ void terminal_change_color_tab (GtkWidget *vterm)
 	}
 	GtkWidget *pTabLabelWidget = gtk_notebook_get_tab_label (GTK_NOTEBOOK(myData.tab), vterm);
 	GList *pTabWidgetList = gtk_container_get_children (GTK_CONTAINER (pTabLabelWidget));
-	GtkLabel *pLabel;
-	const gchar *cCurrentName = NULL;
 	if (pTabWidgetList != NULL && pTabWidgetList->data != NULL)
 	{
 		GtkLabel *pLabel = pTabWidgetList->data;
 		
+		#if GTK_CHECK_VERSION (3, 4, 0)
+		GtkWidget *pColorDialog = gtk_color_chooser_dialog_new (D_("Select a color"), NULL);
+		#else
 		GtkWidget *pColorDialog = gtk_color_selection_dialog_new (D_("Select a color"));
 		GtkWidget *colorsel = gtk_color_selection_dialog_get_color_selection ((GtkColorSelectionDialog *) pColorDialog);
-		
+		#endif
+
 		const gchar *cCurrentLabel = gtk_label_get_text (pLabel);
+		#if GTK_CHECK_VERSION (3, 4, 0)
+		GdkRGBA color;
+		#else
 		GdkColor color;
+		#endif
 		gboolean bColorSet = FALSE;
 		gchar *cUsefulLabel = _get_label_and_color (cCurrentLabel, &color, &bColorSet);
+		g_free (cUsefulLabel);
 		if (bColorSet)
 		{
-			
+			#if GTK_CHECK_VERSION (3, 4, 0)
+			gtk_color_chooser_set_rgba (GTK_COLOR_CHOOSER (pColorDialog), &color);
+			#else
 			gtk_color_selection_set_current_color (GTK_COLOR_SELECTION (colorsel), &color);
+			#endif
 		}
-		
+
+		#if GTK_CHECK_VERSION (3, 4, 0)
+		gtk_color_chooser_set_use_alpha (GTK_COLOR_CHOOSER (pColorDialog), FALSE);
+		g_signal_connect (pColorDialog, "response", G_CALLBACK (_set_color), pLabel);
+		#else
 		gtk_color_selection_set_has_opacity_control (GTK_COLOR_SELECTION (colorsel), FALSE);
 		g_signal_connect (colorsel, "color-changed", G_CALLBACK (_set_color), pLabel);
+		#endif
 		#if (GTK_MAJOR_VERSION < 3)
 		gtk_widget_hide (((GtkColorSelectionDialog *) pColorDialog)->cancel_button);
 		gtk_widget_hide (((GtkColorSelectionDialog *) pColorDialog)->help_button);
 		g_signal_connect_swapped (((GtkColorSelectionDialog *) pColorDialog)->ok_button, "clicked", G_CALLBACK (gtk_widget_destroy), pColorDialog);
-		#else
-		/// TODO: alternative for GTK3?...
 		#endif
 		
 		gtk_window_present (GTK_WINDOW (pColorDialog));
@@ -440,7 +482,7 @@ static GtkWidget *_terminal_build_menu_tab (GtkWidget *vterm)
 
 static gboolean applet_on_terminal_press_cb(GtkWidget *vterm, GdkEventButton *event, gpointer user_data)
 {
-	cd_debug ("%s ()\n", __func__);
+	cd_debug ("%s ()", __func__);
 	if (event->button == 3)
 	{
 		GtkWidget *menu = _terminal_build_menu_tab (vterm);
@@ -529,8 +571,6 @@ static gchar * _terminal_get_tab_name (int iNumPage)
 	GtkWidget *vterm = gtk_notebook_get_nth_page (GTK_NOTEBOOK(myData.tab), iNumPage);
 	GtkWidget *pTabLabelWidget = gtk_notebook_get_tab_label (GTK_NOTEBOOK(myData.tab), vterm);
 	GList *pTabWidgetList = gtk_container_get_children (GTK_CONTAINER (pTabLabelWidget));
-	GtkLabel *pLabel;
-	const gchar *cCurrentName;
 	if (pTabWidgetList != NULL && pTabWidgetList->data != NULL)
 	{
 		GtkLabel *pLabel = pTabWidgetList->data;
@@ -657,6 +697,7 @@ void terminal_new_tab(void)
 	gtk_widget_show_all (pHBox);
 	gtk_widget_show(vterm);
 	int num_new_tab = gtk_notebook_append_page(GTK_NOTEBOOK(myData.tab), vterm, pHBox);
+	gtk_notebook_set_tab_reorderable (GTK_NOTEBOOK(myData.tab), vterm, TRUE);
 	
 	cd_message ("num_new_tab : %d", num_new_tab);
 	gtk_notebook_set_current_page (GTK_NOTEBOOK (myData.tab), num_new_tab);
@@ -711,7 +752,7 @@ static GtkWidget * _terminal_find_clicked_tab_child (int x, int y)  // x,y relat
 	//g_print ("iMaxTabHeight : %d\n", iMaxTabHeight);
 	
 	int i, iNbPages = gtk_notebook_get_n_pages (GTK_NOTEBOOK (myData.tab));
-	gint src_x, src_y, dest_x, dest_y;
+	gint dest_x, dest_y;
 	for (i = 0; i < iNbPages; ++i)
 	{
 		pPageChild = gtk_notebook_get_nth_page(GTK_NOTEBOOK(myData.tab), i);
@@ -739,7 +780,7 @@ static gboolean on_button_press_tab (GtkWidget* pWidget,
 	GdkEventButton* pButton,
 	gpointer data)
 {
-	cd_debug ("%s (%d;%d)\n", __func__, (int)pButton->x, (int)pButton->y);
+	cd_debug ("%s (%d;%d)", __func__, (int)pButton->x, (int)pButton->y);
 	GtkWidget *vterm = _terminal_find_clicked_tab_child (pButton->x, pButton->y);
 	if (pButton->type == GDK_2BUTTON_PRESS)
 	{
