@@ -28,7 +28,7 @@ const char *cMonthsWeeks[19] = { N_("Monday") , N_("Tuesday") , N_("Wednesday")
 #define _add_icon(i, j)\
 	if (myData.wdata.days[i].cName != NULL)\
 	{\
-		pIcon = cairo_dock_create_dummy_launcher (g_strdup (myData.wdata.days[i].cName),\
+		pIcon = cairo_dock_create_dummy_launcher (g_strdup ((gchar *)myData.wdata.days[i].cName),\
 			g_strdup_printf ("%s/%s.png", myConfig.cThemePath, myData.wdata.days[i].part[j].cIconNumber),\
 			NULL,\
 			(myConfig.bDisplayTemperature ? g_strdup_printf ("%s/%s", _display (myData.wdata.days[i].cTempMin), _display (myData.wdata.days[i].cTempMax)) : NULL),\
@@ -117,6 +117,12 @@ gboolean cd_weather_update_from_data (CDSharedMemory *pSharedMemory)
 	g_return_val_if_fail (myIcon != NULL, FALSE);  // paranoia
 	CD_APPLET_ENTER;
 	
+	if (myData.bBusy)
+	{
+		myData.bBusy = FALSE;
+		cairo_dock_request_icon_animation (myIcon, myContainer, NULL, 0);
+	}
+	
 	//\_______________________ in case an error occured, keep the current data, and just redraw the main icon.
 	if (pSharedMemory->bErrorInThread)
 	{
@@ -135,6 +141,7 @@ gboolean cd_weather_update_from_data (CDSharedMemory *pSharedMemory)
 			
 		}
 		cd_weather_reset_weather_data (&pSharedMemory->wdata);  // discard the results, since they are probably empty or incomplete.
+		memset (&pSharedMemory->wdata, 0, sizeof (CDWeatherData));
 		
 		CD_APPLET_LEAVE (TRUE);  // don't recreate the icons, since data have not changed.
 	}
@@ -166,8 +173,11 @@ gboolean cd_weather_update_from_data (CDSharedMemory *pSharedMemory)
 	//\_______________________ On charge la nouvelle liste.
 	if (pIconList != NULL)
 	{
-		gpointer pConfig[2] = {GINT_TO_POINTER (myConfig.bDesklet3D), GINT_TO_POINTER (FALSE)};
-		CD_APPLET_LOAD_MY_ICONS_LIST (pIconList, myConfig.cRenderer, "Caroussel", pConfig);
+		///gpointer pConfig[2] = {GINT_TO_POINTER (myConfig.bDesklet3D), GINT_TO_POINTER (FALSE)};
+		///CD_APPLET_LOAD_MY_ICONS_LIST (pIconList, myConfig.cRenderer, "Caroussel", pConfig);
+		gdouble white[4] = {1., 1., 1., .4};
+		gpointer pConfig[3] = {GINT_TO_POINTER (myConfig.bDisplayNights ? 2 : 1), GINT_TO_POINTER (FALSE), white};
+		CD_APPLET_LOAD_MY_ICONS_LIST (pIconList, myConfig.cRenderer, "Panel", pConfig);
 	}
 	else if (myDock)  // sinon on ne veut pas du sous-dock vide.
 	{
